@@ -1,20 +1,11 @@
-# -*- coding: utf-8 -*-
 """
 Beacon to emit system load averages
 """
-
-# Import Python libs
-from __future__ import absolute_import, unicode_literals
-
 import logging
 import os
 
-# Import Salt libs
 import salt.utils.platform
 
-# Import Py3 compat
-from salt.ext.six.moves import map, zip
-
 log = logging.getLogger(__name__)
 
 __virtualname__ = "load"
