@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 The cp module is used to execute the logic used by the salt-cp command
 line application, salt-cp is NOT intended to broadcast large files, it is
@@ -6,9 +5,6 @@ intended to handle text files.
 Salt-cp can be used to distribute configuration files
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import base64
 import errno
 import logging
@@ -16,7 +12,6 @@ import os
 import re
 import sys
 
-# Import salt libs
 import salt.client
 import salt.output
 import salt.utils.files
@@ -28,9 +23,6 @@ import salt.utils.platform
 import salt.utils.stringutils
 import salt.utils.verify
 
-# Import 3rd party libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 
@@ -53,7 +45,7 @@ class SaltCPCli(salt.utils.parsers.SaltCPOptionParser):
         cp_.run()
 
 
-class SaltCP(object):
+class SaltCP:
     """
     Create a salt cp object, used to distribute simple files with salt
     """
@@ -81,7 +73,7 @@ class SaltCP(object):
         except OSError as exc:
             if exc.errno == errno.ENOENT:
                 # Path does not exist
-                sys.stderr.write("{0} does not exist\n".format(path))
+                sys.stderr.write("{} does not exist\n".format(path))
                 sys.exit(42)
             elif exc.errno in (errno.EINVAL, errno.ENOTDIR):
                 # Path is a file (EINVAL on Windows, ENOTDIR otherwise)
@@ -110,7 +102,7 @@ class SaltCP(object):
         Take a path and return the contents of the file as a string
         """
         if not os.path.isfile(fn_):
-            err = "The referenced file, {0} is not available.".format(fn_)
+            err = "The referenced file, {} is not available.".format(fn_)
             sys.stderr.write(err + "\n")
             sys.exit(42)
         with salt.utils.files.fopen(fn_, "r") as fp_:
@@ -151,7 +143,6 @@ class SaltCP(object):
         Make the salt client call in old-style all-in-one call method
         """
         arg = [self._load_files(), self.opts["dest"]]
-        local = salt.client.get_local_client(self.opts["conf_file"])
         args = [
             self.opts["tgt"],
             "cp.recv",
@@ -163,7 +154,8 @@ class SaltCP(object):
         if selected_target_option is not None:
             args.append(selected_target_option)
 
-        return local.cmd(*args)
+        with salt.client.get_local_client(self.opts["conf_file"]) as local:
+            return local.cmd(*args)
 
     def run_chunked(self):
         """
@@ -191,8 +183,6 @@ class SaltCP(object):
         )
         minions = _res["minions"]
 
-        local = salt.client.get_local_client(self.opts["conf_file"])
-
         def _get_remote_path(fn_):
             if fn_ in self.opts["src"]:
                 # This was a filename explicitly passed on the CLI
@@ -213,79 +203,81 @@ class SaltCP(object):
 
         ret = {}
         parent = ".." + os.sep
-        for fn_, mode in six.iteritems(files):
-            remote_path = _get_remote_path(fn_)
 
-            index = 1
-            failed = {}
-            for chunk in reader(fn_, chunk_size=self.opts["salt_cp_chunk_size"]):
-                chunk = base64.b64encode(salt.utils.stringutils.to_bytes(chunk))
-                append = index > 1
+        with salt.client.get_local_client(self.opts["conf_file"]) as local:
+            for fn_, mode in files.items():
+                remote_path = _get_remote_path(fn_)
+
+                index = 1
+                failed = {}
+                for chunk in reader(fn_, chunk_size=self.opts["salt_cp_chunk_size"]):
+                    chunk = base64.b64encode(salt.utils.stringutils.to_bytes(chunk))
+                    append = index > 1
+                    log.debug(
+                        "Copying %s to %starget '%s' as %s%s",
+                        fn_,
+                        "{} ".format(selected_target_option)
+                        if selected_target_option
+                        else "",
+                        tgt,
+                        remote_path,
+                        " (chunk #{})".format(index) if append else "",
+                    )
+                    args = [
+                        tgt,
+                        "cp.recv_chunked",
+                        [remote_path, chunk, append, gzip, mode],
+                        timeout,
+                    ]
+                    if selected_target_option is not None:
+                        args.append(selected_target_option)
+
+                    result = local.cmd(*args)
+
+                    if not result:
+                        # Publish failed
+                        msg = (
+                            "Publish failed.{} It may be necessary to "
+                            "decrease salt_cp_chunk_size (current value: "
+                            "{})".format(
+                                " File partially transferred." if index > 1 else "",
+                                self.opts["salt_cp_chunk_size"],
+                            )
+                        )
+                        for minion in minions:
+                            ret.setdefault(minion, {})[remote_path] = msg
+                        break
+
+                    for minion_id, minion_ret in result.items():
+                        ret.setdefault(minion_id, {})[remote_path] = minion_ret
+                        # Catch first error message for a given minion, we will
+                        # rewrite the results after we're done iterating through
+                        # the chunks.
+                        if minion_ret is not True and minion_id not in failed:
+                            failed[minion_id] = minion_ret
+
+                    index += 1
+
+                for minion_id, msg in failed.items():
+                    ret[minion_id][remote_path] = msg
+
+            for dirname in empty_dirs:
+                remote_path = _get_remote_path(dirname)
                 log.debug(
-                    "Copying %s to %starget '%s' as %s%s",
-                    fn_,
-                    "{0} ".format(selected_target_option)
+                    "Creating empty dir %s on %starget '%s'",
+                    dirname,
+                    "{} ".format(
+                        selected_target_option
+                    )  # pylint: disable=str-format-in-logging
                     if selected_target_option
                     else "",
                     tgt,
-                    remote_path,
-                    " (chunk #{0})".format(index) if append else "",
                 )
-                args = [
-                    tgt,
-                    "cp.recv_chunked",
-                    [remote_path, chunk, append, gzip, mode],
-                    timeout,
-                ]
+                args = [tgt, "cp.recv_chunked", [remote_path, None], timeout]
                 if selected_target_option is not None:
                     args.append(selected_target_option)
 
-                result = local.cmd(*args)
-
-                if not result:
-                    # Publish failed
-                    msg = (
-                        "Publish failed.{0} It may be necessary to "
-                        "decrease salt_cp_chunk_size (current value: "
-                        "{1})".format(
-                            " File partially transferred." if index > 1 else "",
-                            self.opts["salt_cp_chunk_size"],
-                        )
-                    )
-                    for minion in minions:
-                        ret.setdefault(minion, {})[remote_path] = msg
-                    break
-
-                for minion_id, minion_ret in six.iteritems(result):
+                for minion_id, minion_ret in local.cmd(*args).items():
                     ret.setdefault(minion_id, {})[remote_path] = minion_ret
-                    # Catch first error message for a given minion, we will
-                    # rewrite the results after we're done iterating through
-                    # the chunks.
-                    if minion_ret is not True and minion_id not in failed:
-                        failed[minion_id] = minion_ret
 
-                index += 1
-
-            for minion_id, msg in six.iteritems(failed):
-                ret[minion_id][remote_path] = msg
-
-        for dirname in empty_dirs:
-            remote_path = _get_remote_path(dirname)
-            log.debug(
-                "Creating empty dir %s on %starget '%s'",
-                dirname,
-                "{0} ".format(
-                    selected_target_option
-                )  # pylint: disable=str-format-in-logging
-                if selected_target_option
-                else "",
-                tgt,
-            )
-            args = [tgt, "cp.recv_chunked", [remote_path, None], timeout]
-            if selected_target_option is not None:
-                args.append(selected_target_option)
-
-            for minion_id, minion_ret in six.iteritems(local.cmd(*args)):
-                ret.setdefault(minion_id, {})[remote_path] = minion_ret
-
-        return ret
+            return ret
