@@ -1,15 +1,11 @@
-# coding: utf-8 -*-
 """
 Make me some salt!
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import os
 import warnings
 
-# Import salt libs
 # We import log ASAP because we NEED to make sure that any logger instance salt
 # instantiates is using salt.log.setup.SaltLoggingClass
 import salt.log.setup
@@ -19,6 +15,7 @@ from salt.exceptions import SaltClientError, SaltSystemExit, get_error_message
 # the try block below bypasses an issue at build time so that modules don't
 # cause the build to fail
 from salt.utils import migrations
+from salt.utils.platform import is_junos
 from salt.utils.process import HAS_PSUTIL
 from salt.utils.verify import verify_log
 
@@ -28,6 +25,7 @@ warnings.filterwarnings(
     "",  # No deprecation message matchHAS_PSUTIL
     DeprecationWarning,  # This filter is for DeprecationWarnings
     r"^(salt|salt\.(.*))$",  # Match module(s) 'salt' and 'salt.<whatever>'
+    append=True,
 )
 
 # While we are supporting Python2.6, hide nested with-statements warnings
@@ -35,6 +33,7 @@ warnings.filterwarnings(
     "ignore",
     "With-statements now directly support multiple context managers",
     DeprecationWarning,
+    append=True,
 )
 
 # Filter the backports package UserWarning about being re-imported
@@ -42,13 +41,14 @@ warnings.filterwarnings(
     "ignore",
     "^Module backports was already imported from (.*), but (.*) is being added to sys.path$",
     UserWarning,
+    append=True,
 )
 
 
 try:
-    from salt.utils.zeromq import ip_bracket
     import salt.utils.parsers
     from salt.utils.verify import check_user, verify_env, verify_socket
+    from salt.utils.zeromq import ip_bracket
 except ImportError as exc:
     if exc.args[0] != "No module named _msgpack":
         raise
@@ -59,7 +59,7 @@ except ImportError as exc:
 log = salt.log.setup.logging.getLogger(__name__)
 
 
-class DaemonsMixin(object):  # pylint: disable=no-init
+class DaemonsMixin:  # pylint: disable=no-init
     """
     Uses the same functions for all daemons
     """
@@ -132,7 +132,7 @@ class Master(
             self.master.process_manager.send_signal_to_processes(signum)
             # kill any remaining processes
             self.master.process_manager.kill_children()
-        super(Master, self)._handle_signals(signum, sigframe)
+        super()._handle_signals(signum, sigframe)
 
     def prepare(self):
         """
@@ -142,7 +142,7 @@ class Master(
 
             super(YourSubClass, self).prepare()
         """
-        super(Master, self).prepare()
+        super().prepare()
 
         try:
             if self.config["verify_env"]:
@@ -207,7 +207,7 @@ class Master(
 
         NOTE: Run any required code before calling `super()`.
         """
-        super(Master, self).start()
+        super().start()
         if check_user(self.config["user"]):
             self.action_log_info("Starting up")
             self.verify_hash_type()
@@ -223,7 +223,7 @@ class Master(
             exitmsg = msg + exitmsg
         else:
             exitmsg = msg.strip()
-        super(Master, self).shutdown(exitcode, exitmsg)
+        super().shutdown(exitcode, exitmsg)
 
 
 class Minion(
@@ -237,7 +237,7 @@ class Minion(
         # escalate signal to the process manager processes
         if hasattr(self.minion, "stop"):
             self.minion.stop(signum)
-        super(Minion, self)._handle_signals(signum, sigframe)
+        super()._handle_signals(signum, sigframe)
 
     # pylint: disable=no-member
     def prepare(self):
@@ -248,7 +248,7 @@ class Minion(
 
             super(YourSubClass, self).prepare()
         """
-        super(Minion, self).prepare()
+        super().prepare()
 
         try:
             if self.config["verify_env"]:
@@ -334,7 +334,7 @@ class Minion(
 
         NOTE: Run any required code before calling `super()`.
         """
-        super(Minion, self).start()
+        super().start()
         while True:
             try:
                 self._real_start()
@@ -400,10 +400,10 @@ class Minion(
         self.action_log_info("Shutting down")
         if hasattr(self, "minion") and hasattr(self.minion, "destroy"):
             self.minion.destroy()
-        super(Minion, self).shutdown(
+        super().shutdown(
             exitcode,
             (
-                "The Salt {0} is shutdown. {1}".format(
+                "The Salt {} is shutdown. {}".format(
                     self.__class__.__name__, (exitmsg or "")
                 ).strip()
             ),
@@ -422,7 +422,7 @@ class ProxyMinion(
     def _handle_signals(self, signum, sigframe):  # pylint: disable=unused-argument
         # escalate signal to the process manager processes
         self.minion.stop(signum)
-        super(ProxyMinion, self)._handle_signals(signum, sigframe)
+        super()._handle_signals(signum, sigframe)
 
     # pylint: disable=no-member
     def prepare(self):
@@ -433,10 +433,12 @@ class ProxyMinion(
 
             super(YourSubClass, self).prepare()
         """
-        super(ProxyMinion, self).prepare()
+        super().prepare()
 
-        if not self.values.proxyid:
-            self.error("salt-proxy requires --proxyid")
+        ## allow for native minion
+        if not is_junos():
+            if not self.values.proxyid:
+                self.error("salt-proxy requires --proxyid")
 
         # Proxies get their ID from the command line.  This may need to change in
         # the future.
@@ -484,7 +486,7 @@ class ProxyMinion(
 
         self.setup_logfile_logger()
         verify_log(self.config)
-        self.action_log_info('Setting up "{0}"'.format(self.config["id"]))
+        self.action_log_info('Setting up "{}"'.format(self.config["id"]))
 
         migrations.migrate_paths(self.config)
 
@@ -517,7 +519,7 @@ class ProxyMinion(
 
         NOTE: Run any required code before calling `super()`.
         """
-        super(ProxyMinion, self).start()
+        super().start()
         try:
             if check_user(self.config["user"]):
                 self.action_log_info("The Proxy Minion is starting up")
@@ -545,10 +547,10 @@ class ProxyMinion(
             proxy_fn = self.minion.opts["proxymodule"].loaded_base_name + ".shutdown"
             self.minion.opts["proxymodule"][proxy_fn](self.minion.opts)
         self.action_log_info("Shutting down")
-        super(ProxyMinion, self).shutdown(
+        super().shutdown(
             exitcode,
             (
-                "The Salt {0} is shutdown. {1}".format(
+                "The Salt {} is shutdown. {}".format(
                     self.__class__.__name__, (exitmsg or "")
                 ).strip()
             ),
@@ -572,7 +574,7 @@ class Syndic(
 
             super(YourSubClass, self).prepare()
         """
-        super(Syndic, self).prepare()
+        super().prepare()
         try:
             if self.config["verify_env"]:
                 verify_env(
@@ -592,7 +594,7 @@ class Syndic(
 
         self.setup_logfile_logger()
         verify_log(self.config)
-        self.action_log_info('Setting up "{0}"'.format(self.config["id"]))
+        self.action_log_info('Setting up "{}"'.format(self.config["id"]))
 
         # Late import so logging works correctly
         import salt.minion
@@ -611,7 +613,7 @@ class Syndic(
 
         NOTE: Run any required code before calling `super()`.
         """
-        super(Syndic, self).start()
+        super().start()
         if check_user(self.config["user"]):
             self.action_log_info("Starting up")
             self.verify_hash_type()
@@ -629,10 +631,10 @@ class Syndic(
         :param exitmsg
         """
         self.action_log_info("Shutting down")
-        super(Syndic, self).shutdown(
+        super().shutdown(
             exitcode,
             (
-                "The Salt {0} is shutdown. {1}".format(
+                "The Salt {} is shutdown. {}".format(
                     self.__class__.__name__, (exitmsg or "")
                 ).strip()
             ),
