@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Azure ARM Cloud Module
 ======================
@@ -89,10 +88,6 @@ Example ``/etc/salt/cloud.providers`` or
       scope to a resource group or individual resources.
 """
 
-
-# pylint: disable=wrong-import-position,wrong-import-order
-from __future__ import absolute_import, print_function, unicode_literals
-
 import importlib
 import logging
 import os
@@ -106,6 +101,7 @@ from multiprocessing.pool import ThreadPool
 import salt.cache
 import salt.config as config
 import salt.loader
+import salt.utils.azurearm
 import salt.utils.cloud
 import salt.utils.files
 import salt.utils.stringutils
@@ -118,10 +114,6 @@ from salt.exceptions import (
     SaltCloudSystemExit,
 )
 
-# Salt libs
-from salt.ext import six
-
-# Import 3rd-party libs
 HAS_LIBS = False
 try:
     import azure.mgmt.compute.models as compute_models
@@ -157,6 +149,13 @@ def __virtual__():
     return __virtualname__
 
 
+def _get_active_provider_name():
+    try:
+        return __active_provider_name__.value()
+    except AttributeError:
+        return __active_provider_name__
+
+
 def get_api_versions(call=None, kwargs=None):  # pylint: disable=unused-argument
     """
     Get a resource type api versions
@@ -179,11 +178,11 @@ def get_api_versions(call=None, kwargs=None):  # pylint: disable=unused-argument
         )
 
         for resource in provider_query.resource_types:
-            if six.text_type(resource.resource_type) == kwargs["resource_type"]:
+            if str(resource.resource_type) == kwargs["resource_type"]:
                 resource_dict = resource.as_dict()
                 api_versions = resource_dict["api_versions"]
     except CloudError as exc:
-        __utils__["azurearm.log_cloud_error"]("resource", exc.message)
+        salt.utils.azurearm.log_cloud_error("resource", exc.message)
 
     return api_versions
 
@@ -205,7 +204,7 @@ def get_resource_by_id(resource_id, api_version, extract_value=None):
         else:
             ret = resource_dict
     except CloudError as exc:
-        __utils__["azurearm.log_cloud_error"]("resource", exc.message)
+        salt.utils.azurearm.log_cloud_error("resource", exc.message)
         ret = {"Error": exc.message}
 
     return ret
@@ -223,7 +222,7 @@ def get_configured_provider():
 
     for combo in key_combos:
         provider = config.is_provider_configured(
-            __opts__, __active_provider_name__ or __virtualname__, combo,
+            __opts__, _get_active_provider_name() or __virtualname__, combo,
         )
 
         if provider:
@@ -281,7 +280,7 @@ def get_conn(client_type):
         )
         conn_kwargs.update({"username": username, "password": password})
 
-    client = __utils__["azurearm.get_client"](client_type=client_type, **conn_kwargs)
+    client = salt.utils.azurearm.get_client(client_type=client_type, **conn_kwargs)
 
     return client
 
@@ -319,14 +318,14 @@ def avail_locations(call=None):
         )
         locations = []
         for resource in provider_query.resource_types:
-            if six.text_type(resource.resource_type) == "virtualMachines":
+            if str(resource.resource_type) == "virtualMachines":
                 resource_dict = resource.as_dict()
                 locations = resource_dict["locations"]
         for location in locations:
             lowercase = location.lower().replace(" ", "")
             ret["locations"].append(lowercase)
     except CloudError as exc:
-        __utils__["azurearm.log_cloud_error"]("resource", exc.message)
+        salt.utils.azurearm.log_cloud_error("resource", exc.message)
         ret = {"Error": exc.message}
 
     return ret
@@ -380,7 +379,7 @@ def avail_images(call=None):
                             "version": version["name"],
                         }
         except CloudError as exc:
-            __utils__["azurearm.log_cloud_error"]("compute", exc.message)
+            salt.utils.azurearm.log_cloud_error("compute", exc.message)
             data = {publisher: exc.message}
 
         return data
@@ -393,13 +392,13 @@ def avail_images(call=None):
             publisher = publisher_obj.as_dict()
             publishers.append(publisher["name"])
     except CloudError as exc:
-        __utils__["azurearm.log_cloud_error"]("compute", exc.message)
+        salt.utils.azurearm.log_cloud_error("compute", exc.message)
 
     pool = ThreadPool(cpu_count() * 6)
     results = pool.map_async(_get_publisher_images, publishers)
     results.wait()
 
-    ret = {k: v for result in results.get() for k, v in six.iteritems(result)}
+    ret = {k: v for result in results.get() for k, v in result.items()}
 
     return ret
 
@@ -425,7 +424,7 @@ def avail_sizes(call=None):
             size = size_obj.as_dict()
             ret[size["name"]] = size
     except CloudError as exc:
-        __utils__["azurearm.log_cloud_error"]("compute", exc.message)
+        salt.utils.azurearm.log_cloud_error("compute", exc.message)
         ret = {"Error": exc.message}
 
     return ret
@@ -529,7 +528,7 @@ def list_nodes_full(call=None):
         results = pool.map_async(_get_node_info, nodes)
         results.wait()
 
-        group_ret = {k: v for result in results.get() for k, v in six.iteritems(result)}
+        group_ret = {k: v for result in results.get() for k, v in result.items()}
         ret.update(group_ret)
 
     return ret
@@ -553,7 +552,7 @@ def list_resource_groups(call=None):
             group = group_obj.as_dict()
             ret[group["name"]] = group
     except CloudError as exc:
-        __utils__["azurearm.log_cloud_error"]("resource", exc.message)
+        salt.utils.azurearm.log_cloud_error("resource", exc.message)
         ret = {"Error": exc.message}
 
     return ret
@@ -573,7 +572,7 @@ def show_instance(name, call=None):
         log.debug("Failed to get data for node '%s'", name)
         node = {}
 
-    __utils__["cloud.cache_node"](node, __active_provider_name__, __opts__)
+    __utils__["cloud.cache_node"](node, _get_active_provider_name(), __opts__)
 
     return node
 
@@ -623,7 +622,7 @@ def _get_public_ip(name, resource_group):
         )
         pubip = pubip_query.as_dict()
     except CloudError as exc:
-        __utils__["azurearm.log_cloud_error"]("network", exc.message)
+        salt.utils.azurearm.log_cloud_error("network", exc.message)
         pubip = {"error": exc.message}
 
     return pubip
@@ -707,7 +706,7 @@ def create_network_interface(call=None, kwargs=None):
         )
 
     if kwargs.get("iface_name") is None:
-        kwargs["iface_name"] = "{0}-iface0".format(vm_["name"])
+        kwargs["iface_name"] = "{}-iface0".format(vm_["name"])
 
     try:
         subnet_obj = netconn.subnets.get(
@@ -717,7 +716,7 @@ def create_network_interface(call=None, kwargs=None):
         )
     except CloudError as exc:
         raise SaltCloudSystemExit(
-            '{0} (Resource Group: "{1}", VNET: "{2}", Subnet: "{3}")'.format(
+            '{} (Resource Group: "{}", VNET: "{}", Subnet: "{}")'.format(
                 exc.message,
                 kwargs["network_resource_group"],
                 kwargs["network"],
@@ -740,11 +739,11 @@ def create_network_interface(call=None, kwargs=None):
                         )
                         pool_ids.append({"id": lbbep_data.as_dict()["id"]})
                     except CloudError as exc:
-                        log.error("There was a cloud error: %s", six.text_type(exc))
+                        log.error("There was a cloud error: %s", str(exc))
                     except KeyError as exc:
                         log.error(
                             "There was an error getting the Backend Pool ID: %s",
-                            six.text_type(exc),
+                            str(exc),
                         )
             ip_kwargs["load_balancer_backend_address_pools"] = pool_ids
 
@@ -755,7 +754,7 @@ def create_network_interface(call=None, kwargs=None):
         ip_kwargs["private_ip_allocation_method"] = IPAllocationMethod.dynamic
 
     if kwargs.get("allocate_public_ip") is True:
-        pub_ip_name = "{0}-ip".format(kwargs["iface_name"])
+        pub_ip_name = "{}-ip".format(kwargs["iface_name"])
         poller = netconn.public_ip_addresses.create_or_update(
             resource_group_name=kwargs["resource_group"],
             public_ip_address_name=pub_ip_name,
@@ -773,11 +772,11 @@ def create_network_interface(call=None, kwargs=None):
                 )
                 if pub_ip_data.ip_address:  # pylint: disable=no-member
                     ip_kwargs["public_ip_address"] = PublicIPAddress(
-                        id=six.text_type(pub_ip_data.id),  # pylint: disable=no-member
+                        id=str(pub_ip_data.id),  # pylint: disable=no-member
                     )
                     ip_configurations = [
                         NetworkInterfaceIPConfiguration(
-                            name="{0}-ip".format(kwargs["iface_name"]),
+                            name="{}-ip".format(kwargs["iface_name"]),
                             subnet=subnet_obj,
                             **ip_kwargs
                         )
@@ -790,7 +789,7 @@ def create_network_interface(call=None, kwargs=None):
                 raise ValueError("Timed out waiting for public IP Address.")
             time.sleep(5)
     else:
-        priv_ip_name = "{0}-ip".format(kwargs["iface_name"])
+        priv_ip_name = "{}-ip".format(kwargs["iface_name"])
         ip_configurations = [
             NetworkInterfaceIPConfiguration(
                 name=priv_ip_name, subnet=subnet_obj, **ip_kwargs
@@ -900,7 +899,7 @@ def request_instance(vm_):
     )
     vm_["iface_id"] = iface_data["id"]
 
-    disk_name = "{0}-vol0".format(vm_["name"])
+    disk_name = "{}-vol0".format(vm_["name"])
 
     vm_username = config.get_cloud_config_value(
         "ssh_username",
@@ -922,8 +921,8 @@ def request_instance(vm_):
                 ssh_publickeyfile_contents = spkc_.read()
         except Exception as exc:  # pylint: disable=broad-except
             raise SaltCloudConfigError(
-                "Failed to read ssh publickey file '{0}': "
-                "{1}".format(ssh_publickeyfile, exc.args[-1])
+                "Failed to read ssh publickey file '{}': "
+                "{}".format(ssh_publickeyfile, exc.args[-1])
             )
 
     disable_password_authentication = config.get_cloud_config_value(
@@ -941,7 +940,7 @@ def request_instance(vm_):
     if not win_installer and ssh_publickeyfile_contents is not None:
         sshpublickey = SshPublicKey(
             key_data=ssh_publickeyfile_contents,
-            path="/home/{0}/.ssh/authorized_keys".format(vm_username),
+            path="/home/{}/.ssh/authorized_keys".format(vm_username),
         )
         sshconfiguration = SshConfiguration(public_keys=[sshpublickey],)
         linuxconfiguration = LinuxConfiguration(
@@ -991,9 +990,9 @@ def request_instance(vm_):
     availability_set = config.get_cloud_config_value(
         "availability_set", vm_, __opts__, search_global=False, default=None
     )
-    if availability_set is not None and isinstance(availability_set, six.string_types):
+    if availability_set is not None and isinstance(availability_set, str):
         availability_set = {
-            "id": "/subscriptions/{0}/resourceGroups/{1}/providers/Microsoft.Compute/availabilitySets/{2}".format(
+            "id": "/subscriptions/{}/resourceGroups/{}/providers/Microsoft.Compute/availabilitySets/{}".format(
                 subscription_id, vm_["resource_group"], availability_set
             )
         }
@@ -1004,7 +1003,7 @@ def request_instance(vm_):
 
     storage_endpoint_suffix = cloud_env.suffixes.storage_endpoint
 
-    if isinstance(vm_.get("volumes"), six.string_types):
+    if isinstance(vm_.get("volumes"), str):
         volumes = salt.utils.yaml.safe_load(vm_["volumes"])
     else:
         volumes = vm_.get("volumes")
@@ -1018,16 +1017,14 @@ def request_instance(vm_):
     lun = 0
     luns = []
     for volume in volumes:
-        if isinstance(volume, six.string_types):
+        if isinstance(volume, str):
             volume = {"name": volume}
 
         volume.setdefault(
             "name",
             volume.get(
                 "name",
-                volume.get(
-                    "name", "{0}-datadisk{1}".format(vm_["name"], six.text_type(lun))
-                ),
+                volume.get("name", "{}-datadisk{}".format(vm_["name"], str(lun))),
             ),
         )
 
@@ -1050,7 +1047,7 @@ def request_instance(vm_):
             del volume["media_link"]
         elif volume.get("vhd") == "unmanaged":
             volume["vhd"] = VirtualHardDisk(
-                uri="https://{0}.blob.{1}/vhds/{2}-datadisk{3}.vhd".format(
+                uri="https://{}.blob.{}/vhds/{}-datadisk{}.vhd".format(
                     vm_["storage_account"],
                     storage_endpoint_suffix,
                     vm_["name"],
@@ -1090,7 +1087,7 @@ def request_instance(vm_):
             create_option=DiskCreateOptionTypes.from_image,
             name=disk_name,
             vhd=VirtualHardDisk(
-                uri="https://{0}.blob.{1}/vhds/{2}.vhd".format(
+                uri="https://{}.blob.{}/vhds/{}.vhd".format(
                     vm_["storage_account"], storage_endpoint_suffix, disk_name,
                 ),
             ),
@@ -1209,7 +1206,7 @@ def request_instance(vm_):
     __utils__["cloud.fire_event"](
         "event",
         "requesting instance",
-        "salt/cloud/{0}/requesting".format(vm_["name"]),
+        "salt/cloud/{}/requesting".format(vm_["name"]),
         args=__utils__["cloud.filter_event"](
             "requesting", vm_, ["name", "profile", "provider", "driver"]
         ),
@@ -1229,7 +1226,7 @@ def request_instance(vm_):
         if custom_extension:
             create_or_update_vmextension(kwargs=custom_extension)
     except CloudError as exc:
-        __utils__["azurearm.log_cloud_error"]("compute", exc.message)
+        salt.utils.azurearm.log_cloud_error("compute", exc.message)
         vm_result = {}
 
     return vm_result
@@ -1244,7 +1241,7 @@ def create(vm_):
             vm_["profile"]
             and config.is_profile_configured(
                 __opts__,
-                __active_provider_name__ or "azurearm",
+                _get_active_provider_name() or "azurearm",
                 vm_["profile"],
                 vm_=vm_,
             )
@@ -1260,7 +1257,7 @@ def create(vm_):
     __utils__["cloud.fire_event"](
         "event",
         "starting create",
-        "salt/cloud/{0}/creating".format(vm_["name"]),
+        "salt/cloud/{}/creating".format(vm_["name"]),
         args=__utils__["cloud.filter_event"](
             "creating", vm_, ["name", "profile", "provider", "driver"]
         ),
@@ -1278,9 +1275,7 @@ def create(vm_):
     vm_request = request_instance(vm_=vm_)
 
     if not vm_request or "error" in vm_request:
-        err_message = "Error creating VM {0}! ({1})".format(
-            vm_["name"], six.text_type(vm_request)
-        )
+        err_message = "Error creating VM {}! ({})".format(vm_["name"], str(vm_request))
         log.error(err_message)
         raise SaltCloudSystemExit(err_message)
 
@@ -1322,7 +1317,7 @@ def create(vm_):
         try:
             log.warning(exc)
         finally:
-            raise SaltCloudSystemExit(six.text_type(exc))
+            raise SaltCloudSystemExit(str(exc))
 
     vm_["ssh_host"] = data
     if not vm_.get("ssh_username"):
@@ -1341,7 +1336,7 @@ def create(vm_):
     __utils__["cloud.fire_event"](
         "event",
         "created instance",
-        "salt/cloud/{0}/created".format(vm_["name"]),
+        "salt/cloud/{}/created".format(vm_["name"]),
         args=__utils__["cloud.filter_event"](
             "created", vm_, ["name", "profile", "provider", "driver"]
         ),
@@ -1386,7 +1381,7 @@ def destroy(name, call=None, kwargs=None):  # pylint: disable=unused-argument
 
     if __opts__.get("update_cachedir", False) is True:
         __utils__["cloud.delete_minion_cachedir"](
-            name, __active_provider_name__.split(":")[0], __opts__
+            name, _get_active_provider_name().split(":")[0], __opts__
         )
 
     cleanup_disks = config.get_cloud_config_value(
@@ -1526,11 +1521,11 @@ def list_storage_accounts(call=None):
     ret = {}
     try:
         accounts_query = storconn.storage_accounts.list()
-        accounts = __utils__["azurearm.paged_object_to_list"](accounts_query)
+        accounts = salt.utils.azurearm.paged_object_to_list(accounts_query)
         for account in accounts:
             ret[account["name"]] = account
     except CloudError as exc:
-        __utils__["azurearm.log_cloud_error"]("storage", exc.message)
+        salt.utils.azurearm.log_cloud_error("storage", exc.message)
         ret = {"Error": exc.message}
 
     return ret
@@ -1548,9 +1543,7 @@ def _get_cloud_environment():
         cloud_env = getattr(cloud_env_module, cloud_environment or "AZURE_PUBLIC_CLOUD")
     except (AttributeError, ImportError):
         raise SaltCloudSystemExit(
-            "The azure {0} cloud environment is not available.".format(
-                cloud_environment
-            )
+            "The azure {} cloud environment is not available.".format(cloud_environment)
         )
 
     return cloud_env
@@ -1585,7 +1578,7 @@ def _get_block_blob_service(kwargs=None):
             resource_group, storage_account
         )
         storage_keys = {v.key_name: v.value for v in storage_keys.keys}
-        storage_key = next(six.itervalues(storage_keys))
+        storage_key = next(iter(storage_keys.values()))
 
     cloud_env = _get_cloud_environment()
 
@@ -1620,7 +1613,7 @@ def list_blobs(call=None, kwargs=None):  # pylint: disable=unused-argument
                 "server_encrypted": blob.properties.server_encrypted,
             }
     except Exception as exc:  # pylint: disable=broad-except
-        log.warning(six.text_type(exc))
+        log.warning(str(exc))
 
     return ret
 
@@ -1655,9 +1648,7 @@ def delete_managed_disk(call=None, kwargs=None):  # pylint: disable=unused-argum
         compconn.disks.delete(kwargs["resource_group"], kwargs["blob"])
     except Exception as exc:  # pylint: disable=broad-except
         log.error(
-            "Error deleting managed disk %s - %s",
-            kwargs.get("blob"),
-            six.text_type(exc),
+            "Error deleting managed disk %s - %s", kwargs.get("blob"), str(exc),
         )
         return False
 
@@ -1832,9 +1823,9 @@ def create_or_update_vmextension(
         ret = ret.as_dict()
 
     except CloudError as exc:
-        __utils__["azurearm.log_cloud_error"](
+        salt.utils.azurearm.log_cloud_error(
             "compute",
-            "Error attempting to create the VM extension: {0}".format(exc.message),
+            "Error attempting to create the VM extension: {}".format(exc.message),
         )
         ret = {"error": exc.message}
 
@@ -1880,12 +1871,10 @@ def stop(name, call=None):
                 else:
                     ret = {"error": exc.message}
         if not ret:
-            __utils__["azurearm.log_cloud_error"](
-                "compute", "Unable to find virtual machine with name: {0}".format(name)
+            salt.utils.azurearm.log_cloud_error(
+                "compute", "Unable to find virtual machine with name: {}".format(name)
             )
-            ret = {
-                "error": "Unable to find virtual machine with name: {0}".format(name)
-            }
+            ret = {"error": "Unable to find virtual machine with name: {}".format(name)}
     else:
         try:
             instance = compconn.virtual_machines.deallocate(
@@ -1895,8 +1884,8 @@ def stop(name, call=None):
             vm_result = instance.result()
             ret = vm_result.as_dict()
         except CloudError as exc:
-            __utils__["azurearm.log_cloud_error"](
-                "compute", "Error attempting to stop {0}: {1}".format(name, exc.message)
+            salt.utils.azurearm.log_cloud_error(
+                "compute", "Error attempting to stop {}: {}".format(name, exc.message)
             )
             ret = {"error": exc.message}
 
@@ -1944,12 +1933,10 @@ def start(name, call=None):
                 else:
                     ret = {"error": exc.message}
         if not ret:
-            __utils__["azurearm.log_cloud_error"](
-                "compute", "Unable to find virtual machine with name: {0}".format(name)
+            salt.utils.azurearm.log_cloud_error(
+                "compute", "Unable to find virtual machine with name: {}".format(name)
             )
-            ret = {
-                "error": "Unable to find virtual machine with name: {0}".format(name)
-            }
+            ret = {"error": "Unable to find virtual machine with name: {}".format(name)}
     else:
         try:
             instance = compconn.virtual_machines.start(
@@ -1959,9 +1946,8 @@ def start(name, call=None):
             vm_result = instance.result()
             ret = vm_result.as_dict()
         except CloudError as exc:
-            __utils__["azurearm.log_cloud_error"](
-                "compute",
-                "Error attempting to start {0}: {1}".format(name, exc.message),
+            salt.utils.azurearm.log_cloud_error(
+                "compute", "Error attempting to start {}: {}".format(name, exc.message),
             )
             ret = {"error": exc.message}
 
