@@ -106,7 +106,6 @@ There are a few changes to note:
 
 import abc
 import datetime
-import ipaddress
 import json
 import logging
 import pprint
@@ -114,15 +113,14 @@ import re
 import time
 from pathlib import Path
 
-# Import Salt Libs
 import salt.config as config
+from salt._compat import ipaddress
 from salt.exceptions import (
     SaltCloudConfigError,
     SaltCloudException,
     SaltCloudNotFound,
     SaltCloudSystemExit,
 )
-from salt.ext.six.moves import range
 
 try:
     import requests
@@ -167,12 +165,21 @@ def __virtual__():
     return __virtualname__
 
 
+def _get_active_provider_name():
+    try:
+        return __active_provider_name__.value()
+    except AttributeError:
+        return __active_provider_name__
+
+
 def get_configured_provider():
     """
     Return the first configured instance.
     """
     return config.is_provider_configured(
-        __opts__, __active_provider_name__ or __virtualname__, ("apikey", "password",)
+        __opts__,
+        _get_active_provider_name() or __virtualname__,
+        ("apikey", "password",),
     )
 
 
@@ -820,7 +827,7 @@ class LinodeAPIv4(LinodeAPI):
 
         if __opts__.get("update_cachedir", False) is True:
             __utils__["cloud.delete_minion_cachedir"](
-                name, __active_provider_name__.split(":")[0], __opts__
+                name, _get_active_provider_name().split(":")[0], __opts__
             )
 
         instance = self._get_linode_by_name(name)
@@ -1668,7 +1675,7 @@ class LinodeAPIv3(LinodeAPI):
 
         if __opts__.get("update_cachedir", False) is True:
             __utils__["cloud.delete_minion_cachedir"](
-                name, __active_provider_name__.split(":")[0], __opts__
+                name, _get_active_provider_name().split(":")[0], __opts__
             )
 
         return response
@@ -2281,7 +2288,10 @@ def create(vm_):
         if (
             vm_["profile"]
             and config.is_profile_configured(
-                __opts__, __active_provider_name__ or "linode", vm_["profile"], vm_=vm_
+                __opts__,
+                _get_active_provider_name() or "linode",
+                vm_["profile"],
+                vm_=vm_,
             )
             is False
         ):
