@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 An engine that reads messages from Slack and can act on them
 
-.. versionadded: 2016.3.0
+.. versionadded:: 2016.3.0
 
 :depends: `slackclient <https://pypi.org/project/slackclient/>`_ Python module
 
@@ -146,9 +145,6 @@ must be quoted, or else PyYAML will fail to load the configuration.
 
 """
 
-# Import python libraries
-from __future__ import absolute_import, print_function, unicode_literals
-
 import ast
 import datetime
 import itertools
@@ -157,7 +153,6 @@ import re
 import time
 import traceback
 
-# Import salt libs
 import salt.client
 import salt.loader
 import salt.minion
@@ -169,9 +164,6 @@ import salt.utils.http
 import salt.utils.json
 import salt.utils.slack
 import salt.utils.yaml
-from salt.ext import six
-
-log = logging.getLogger(__name__)
 
 try:
     import slackclient
@@ -180,6 +172,7 @@ try:
 except ImportError:
     HAS_SLACKCLIENT = False
 
+log = logging.getLogger(__name__)
 
 __virtualname__ = "slack"
 
@@ -190,7 +183,7 @@ def __virtual__():
     return __virtualname__
 
 
-class SlackClient(object):
+class SlackClient:
     def __init__(self, token):
         self.master_minion = salt.minion.MasterMinion(__opts__)
 
@@ -614,7 +607,7 @@ class SlackClient(object):
                         continue
                     else:
                         channel.send_message(
-                            "{0} is not allowed to use command {1}.".format(
+                            "{} is not allowed to use command {}.".format(
                                 data["user_name"], cmdline
                             )
                         )
@@ -703,9 +696,7 @@ class SlackClient(object):
             except (StopIteration, AttributeError):
                 outputter = None
             return salt.output.string_format(
-                {x: y["return"] for x, y in six.iteritems(data)},
-                out=outputter,
-                opts=__opts__,
+                {x: y["return"] for x, y in data.items()}, out=outputter, opts=__opts__,
             )
         except Exception as exc:  # pylint: disable=broad-except
             import pprint
@@ -803,9 +794,7 @@ class SlackClient(object):
                 if fire_all:
                     log.debug("Firing message to the bus with tag: %s", tag)
                     log.debug("%s %s", tag, msg)
-                    self.fire(
-                        "{0}/{1}".format(tag, msg["message_data"].get("type")), msg
-                    )
+                    self.fire("{}/{}".format(tag, msg["message_data"].get("type")), msg)
                 if control and (len(msg) > 1) and msg.get("cmdline"):
                     channel = self.sc.server.channels.find(msg["channel"])
                     jid = self.run_command_async(msg)
@@ -846,7 +835,7 @@ class SlackClient(object):
                     channel.send_message(return_prefix)
                     ts = time.time()
                     st = datetime.datetime.fromtimestamp(ts).strftime("%Y%m%d%H%M%S%f")
-                    filename = "salt-results-{0}.yaml".format(st)
+                    filename = "salt-results-{}.yaml".format(st)
                     r = self.sc.api_call(
                         "files.upload",
                         channels=channel.id,
@@ -858,7 +847,7 @@ class SlackClient(object):
                     resp = salt.utils.yaml.safe_load(salt.utils.json.dumps(r))
                     if "ok" in resp and resp["ok"] is False:
                         this_job["channel"].send_message(
-                            "Error: {0}".format(resp["error"])
+                            "Error: {}".format(resp["error"])
                         )
                     del outstanding[jid]
 
@@ -905,19 +894,15 @@ class SlackClient(object):
 
         # Default to trying to run as a client module.
         else:
-            local = salt.client.LocalClient()
             log.debug(
                 "Command %s will run via local.cmd_async, targeting %s", cmd, target
             )
             log.debug("Running %s, %s, %s, %s, %s", target, cmd, args, kwargs, tgt_type)
             # according to https://github.com/saltstack/salt-api/issues/164, tgt_type has changed to expr_form
-            job_id = local.cmd_async(
-                six.text_type(target),
-                cmd,
-                arg=args,
-                kwarg=kwargs,
-                tgt_type=six.text_type(tgt_type),
-            )
+            with salt.client.LocalClient() as local:
+                job_id = local.cmd_async(
+                    str(target), cmd, arg=args, kwarg=kwargs, tgt_type=str(tgt_type),
+                )
             log.info("ret from local.cmd_async is %s", job_id)
         return job_id
 
