@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 File server pluggable modules and generic backend functions
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import errno
 import fnmatch
@@ -14,15 +11,12 @@ import re
 import time
 from collections.abc import Sequence
 
-# Import salt libs
 import salt.loader
 import salt.utils.data
 import salt.utils.files
 import salt.utils.path
 import salt.utils.url
 import salt.utils.versions
-
-# Import 3rd-party libs
 from salt.ext import six
 from salt.utils.args import get_function_argspec as _argspec
 from salt.utils.decorators import ensure_unicode_args
@@ -41,7 +35,7 @@ def _unlock_cache(w_lock):
             os.rmdir(w_lock)
         elif os.path.isfile(w_lock):
             os.unlink(w_lock)
-    except (OSError, IOError) as exc:
+    except OSError as exc:
         log.trace("Error removing lockfile %s: %s", w_lock, exc)
 
 
@@ -96,7 +90,7 @@ def wait_lock(lk_fn, dest, wait_timeout=0):
         if timeout:
             if time.time() > timeout:
                 raise ValueError(
-                    "Timeout({0}s) for {1} (lock: {2}) elapsed".format(
+                    "Timeout({}s) for {} (lock: {}) elapsed".format(
                         wait_timeout, dest, lk_fn
                     )
                 )
@@ -138,7 +132,7 @@ def check_file_list_cache(opts, form, list_cache, w_lock):
                             current_time,
                             file_mtime,
                         )
-                        age = 0
+                        age = -1
                     else:
                         age = current_time - file_mtime
                 else:
@@ -199,7 +193,7 @@ def check_env_cache(opts, env_cache):
             log.trace("Returning env cache data from %s", env_cache)
             serial = salt.payload.Serial(opts)
             return salt.utils.data.decode(serial.load(fp_))
-    except (IOError, OSError):
+    except OSError:
         pass
     return None
 
@@ -209,7 +203,7 @@ def generate_mtime_map(opts, path_map):
     Generate a dict of filename -> mtime
     """
     file_map = {}
-    for saltenv, path_list in six.iteritems(path_map):
+    for saltenv, path_list in path_map.items():
         for path in path_list:
             for directory, _, filenames in salt.utils.path.os_walk(path):
                 for item in filenames:
@@ -220,7 +214,7 @@ def generate_mtime_map(opts, path_map):
                         if is_file_ignored(opts, file_path):
                             continue
                         file_map[file_path] = os.path.getmtime(file_path)
-                    except (OSError, IOError):
+                    except OSError:
                         # skip dangling symlinks
                         log.info(
                             "Failed to get mtime on %s, dangling symlink?", file_path
@@ -239,7 +233,7 @@ def diff_mtime_map(map1, map2):
 
     # map1 and map2 are guaranteed to have same keys,
     # so compare mtimes
-    for filename, mtime in six.iteritems(map1):
+    for filename, mtime in map1.items():
         if map2[filename] != mtime:
             return True
 
@@ -329,14 +323,14 @@ def clear_lock(clear_func, role, remote=None, lock_type="update"):
 
     Returns the return data from ``clear_func``.
     """
-    msg = "Clearing {0} lock for {1} remotes".format(lock_type, role)
+    msg = "Clearing {} lock for {} remotes".format(lock_type, role)
     if remote:
-        msg += " matching {0}".format(remote)
+        msg += " matching {}".format(remote)
     log.debug(msg)
     return clear_func(remote=remote, lock_type=lock_type)
 
 
-class Fileserver(object):
+class Fileserver:
     """
     Create a fileserver wrapper object that wraps the fileserver functions and
     iterates over them to execute the desired function within the scope of the
@@ -358,7 +352,7 @@ class Fileserver(object):
                 try:
                     back = back.split(",")
                 except AttributeError:
-                    back = six.text_type(back).split(",")
+                    back = str(back).split(",")
 
         if isinstance(back, Sequence):
             # The test suite uses an ImmutableList type (based on
@@ -376,7 +370,7 @@ class Fileserver(object):
         # .keys() attribute rather than on the LazyDict itself.
         server_funcs = self.servers.keys()
         try:
-            subtract_only = all((x.startswith("-") for x in back))
+            subtract_only = all(x.startswith("-") for x in back)
         except AttributeError:
             pass
         else:
@@ -384,12 +378,12 @@ class Fileserver(object):
                 # Only subtracting backends from enabled ones
                 ret = self.opts["fileserver_backend"]
                 for sub in back:
-                    if "{0}.envs".format(sub[1:]) in server_funcs:
+                    if "{}.envs".format(sub[1:]) in server_funcs:
                         ret.remove(sub[1:])
                 return ret
 
         for sub in back:
-            if "{0}.envs".format(sub) in server_funcs:
+            if "{}.envs".format(sub) in server_funcs:
                 ret.append(sub)
         return ret
 
@@ -417,7 +411,7 @@ class Fileserver(object):
         cleared = []
         errors = []
         for fsb in back:
-            fstr = "{0}.clear_cache".format(fsb)
+            fstr = "{}.clear_cache".format(fsb)
             if fstr in self.servers:
                 log.debug("Clearing %s fileserver cache", fsb)
                 failed = self.servers[fstr]()
@@ -425,7 +419,7 @@ class Fileserver(object):
                     errors.extend(failed)
                 else:
                     cleared.append(
-                        "The {0} fileserver cache was successfully cleared".format(fsb)
+                        "The {} fileserver cache was successfully cleared".format(fsb)
                     )
         return cleared, errors
 
@@ -439,17 +433,17 @@ class Fileserver(object):
         locked = []
         errors = []
         for fsb in back:
-            fstr = "{0}.lock".format(fsb)
+            fstr = "{}.lock".format(fsb)
             if fstr in self.servers:
-                msg = "Setting update lock for {0} remotes".format(fsb)
+                msg = "Setting update lock for {} remotes".format(fsb)
                 if remote:
-                    if not isinstance(remote, six.string_types):
+                    if not isinstance(remote, str):
                         errors.append(
-                            "Badly formatted remote pattern '{0}'".format(remote)
+                            "Badly formatted remote pattern '{}'".format(remote)
                         )
                         continue
                     else:
-                        msg += " matching {0}".format(remote)
+                        msg += " matching {}".format(remote)
                 log.debug(msg)
                 good, bad = self.servers[fstr](remote=remote)
                 locked.extend(good)
@@ -472,24 +466,24 @@ class Fileserver(object):
         cleared = []
         errors = []
         for fsb in back:
-            fstr = "{0}.clear_lock".format(fsb)
+            fstr = "{}.clear_lock".format(fsb)
             if fstr in self.servers:
                 good, bad = clear_lock(self.servers[fstr], fsb, remote=remote)
                 cleared.extend(good)
                 errors.extend(bad)
         return cleared, errors
 
-    def update(self, back=None):
+    def update(self, back=None, **kwargs):
         """
         Update all of the enabled fileserver backends which support the update
-        function, or
+        function
         """
         back = self.backends(back)
         for fsb in back:
-            fstr = "{0}.update".format(fsb)
+            fstr = "{}.update".format(fsb)
             if fstr in self.servers:
                 log.debug("Updating %s fileserver cache", fsb)
-                self.servers[fstr]()
+                self.servers[fstr](**kwargs)
 
     def update_intervals(self, back=None):
         """
@@ -499,7 +493,7 @@ class Fileserver(object):
         back = self.backends(back)
         ret = {}
         for fsb in back:
-            fstr = "{0}.update_intervals".format(fsb)
+            fstr = "{}.update_intervals".format(fsb)
             if fstr in self.servers:
                 ret[fsb] = self.servers[fstr]()
         return ret
@@ -513,7 +507,7 @@ class Fileserver(object):
         if sources:
             ret = {}
         for fsb in back:
-            fstr = "{0}.envs".format(fsb)
+            fstr = "{}.envs".format(fsb)
             kwargs = (
                 {"ignore_cache": True}
                 if "ignore_cache" in _argspec(self.servers[fstr]).args
@@ -543,7 +537,7 @@ class Fileserver(object):
         """
         back = self.backends(back)
         for fsb in back:
-            fstr = "{0}.init".format(fsb)
+            fstr = "{}.init".format(fsb)
             if fstr in self.servers:
                 self.servers[fstr]()
 
@@ -602,11 +596,11 @@ class Fileserver(object):
         if "saltenv" in kwargs:
             saltenv = kwargs.pop("saltenv")
 
-        if not isinstance(saltenv, six.string_types):
-            saltenv = six.text_type(saltenv)
+        if not isinstance(saltenv, str):
+            saltenv = str(saltenv)
 
         for fsb in back:
-            fstr = "{0}.find_file".format(fsb)
+            fstr = "{}.find_file".format(fsb)
             if fstr in self.servers:
                 fnd = self.servers[fstr](path, saltenv, **kwargs)
                 if fnd.get("path"):
@@ -626,13 +620,13 @@ class Fileserver(object):
 
         if "path" not in load or "loc" not in load or "saltenv" not in load:
             return ret
-        if not isinstance(load["saltenv"], six.string_types):
-            load["saltenv"] = six.text_type(load["saltenv"])
+        if not isinstance(load["saltenv"], str):
+            load["saltenv"] = str(load["saltenv"])
 
         fnd = self.find_file(load["path"], load["saltenv"])
         if not fnd.get("back"):
             return ret
-        fstr = "{0}.serve_file".format(fnd["back"])
+        fstr = "{}.serve_file".format(fnd["back"])
         if fstr in self.servers:
             return self.servers[fstr](load, fnd)
         return ret
@@ -647,8 +641,8 @@ class Fileserver(object):
 
         if "path" not in load or "saltenv" not in load:
             return "", None
-        if not isinstance(load["saltenv"], six.string_types):
-            load["saltenv"] = six.text_type(load["saltenv"])
+        if not isinstance(load["saltenv"], str):
+            load["saltenv"] = str(load["saltenv"])
 
         fnd = self.find_file(
             salt.utils.stringutils.to_unicode(load["path"]), load["saltenv"]
@@ -656,7 +650,7 @@ class Fileserver(object):
         if not fnd.get("back"):
             return "", None
         stat_result = fnd.get("stat", None)
-        fstr = "{0}.file_hash".format(fnd["back"])
+        fstr = "{}.file_hash".format(fnd["back"])
         if fstr in self.servers:
             return self.servers[fstr](load, fnd), stat_result
         return "", None
@@ -693,11 +687,11 @@ class Fileserver(object):
                 try:
                     saltenv = [x.strip() for x in saltenv.split(",")]
                 except AttributeError:
-                    saltenv = [x.strip() for x in six.text_type(saltenv).split(",")]
+                    saltenv = [x.strip() for x in str(saltenv).split(",")]
 
             for idx, val in enumerate(saltenv):
-                if not isinstance(val, six.string_types):
-                    saltenv[idx] = six.text_type(val)
+                if not isinstance(val, str):
+                    saltenv[idx] = str(val)
 
         ret = {}
         fsb = self.backends(load.pop("fsbackend", None))
@@ -772,11 +766,11 @@ class Fileserver(object):
         ret = set()
         if "saltenv" not in load:
             return []
-        if not isinstance(load["saltenv"], six.string_types):
-            load["saltenv"] = six.text_type(load["saltenv"])
+        if not isinstance(load["saltenv"], str):
+            load["saltenv"] = str(load["saltenv"])
 
         for fsb in self.backends(load.pop("fsbackend", None)):
-            fstr = "{0}.file_list".format(fsb)
+            fstr = "{}.file_list".format(fsb)
             if fstr in self.servers:
                 ret.update(self.servers[fstr](load))
         # some *fs do not handle prefix. Ensure it is filtered
@@ -797,11 +791,11 @@ class Fileserver(object):
         ret = set()
         if "saltenv" not in load:
             return []
-        if not isinstance(load["saltenv"], six.string_types):
-            load["saltenv"] = six.text_type(load["saltenv"])
+        if not isinstance(load["saltenv"], str):
+            load["saltenv"] = str(load["saltenv"])
 
         for fsb in self.backends(None):
-            fstr = "{0}.file_list_emptydirs".format(fsb)
+            fstr = "{}.file_list_emptydirs".format(fsb)
             if fstr in self.servers:
                 ret.update(self.servers[fstr](load))
         # some *fs do not handle prefix. Ensure it is filtered
@@ -822,11 +816,11 @@ class Fileserver(object):
         ret = set()
         if "saltenv" not in load:
             return []
-        if not isinstance(load["saltenv"], six.string_types):
-            load["saltenv"] = six.text_type(load["saltenv"])
+        if not isinstance(load["saltenv"], str):
+            load["saltenv"] = str(load["saltenv"])
 
         for fsb in self.backends(load.pop("fsbackend", None)):
-            fstr = "{0}.dir_list".format(fsb)
+            fstr = "{}.dir_list".format(fsb)
             if fstr in self.servers:
                 ret.update(self.servers[fstr](load))
         # some *fs do not handle prefix. Ensure it is filtered
@@ -847,21 +841,21 @@ class Fileserver(object):
         ret = {}
         if "saltenv" not in load:
             return {}
-        if not isinstance(load["saltenv"], six.string_types):
-            load["saltenv"] = six.text_type(load["saltenv"])
+        if not isinstance(load["saltenv"], str):
+            load["saltenv"] = str(load["saltenv"])
 
         for fsb in self.backends(load.pop("fsbackend", None)):
-            symlstr = "{0}.symlink_list".format(fsb)
+            symlstr = "{}.symlink_list".format(fsb)
             if symlstr in self.servers:
                 ret = self.servers[symlstr](load)
         # some *fs do not handle prefix. Ensure it is filtered
         prefix = load.get("prefix", "").strip("/")
         if prefix != "":
-            ret = dict([(x, y) for x, y in six.iteritems(ret) if x.startswith(prefix)])
+            ret = {x: y for x, y in ret.items() if x.startswith(prefix)}
         return ret
 
 
-class FSChan(object):
+class FSChan:
     """
     A class that mimics the transport channels allowing for local access to
     to the fileserver class class structure
