@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 Grain that indicates the system is pending a reboot
 See functions in salt.utils.win_system to see what conditions would indicate
 a reboot is pending
 """
-from __future__ import absolute_import, print_function, unicode_literals
-
 # Import python libs
 import logging
 
@@ -26,6 +23,6 @@ def __virtual__():
 
 def pending_reboot():
     """
-    A grain that indicates that the system is pending a reboot.
+    A grain that indicates that a Windows system is pending a reboot.
     """
     return {"pending_reboot": salt.utils.win_system.get_pending_reboot()}
