@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Execute chef in server or solo mode
-'''
+"""
 
 # Import Python libs
 from __future__ import absolute_import, print_function, unicode_literals
+
 import logging
 import os
 import tempfile
 
+import salt.utils.decorators.path
+
 # Import Salt libs
 import salt.utils.path
 import salt.utils.platform
-import salt.utils.decorators.path
 
 # Import 3rd-party libs
 from salt.ext import six
@@ -21,43 +23,36 @@ log = logging.getLogger(__name__)
 
 
 def __virtual__():
-    '''
+    """
     Only load if chef is installed
-    '''
-    if not salt.utils.path.which('chef-client'):
-        return (False, 'Cannot load chef module: chef-client not found')
+    """
+    if not salt.utils.path.which("chef-client"):
+        return (False, "Cannot load chef module: chef-client not found")
     return True
 
 
 def _default_logfile(exe_name):
-    '''
+    """
     Retrieve the logfile name
-    '''
+    """
     if salt.utils.platform.is_windows():
-        tmp_dir = os.path.join(__opts__['cachedir'], 'tmp')
+        tmp_dir = os.path.join(__opts__["cachedir"], "tmp")
         if not os.path.isdir(tmp_dir):
             os.mkdir(tmp_dir)
-        logfile_tmp = tempfile.NamedTemporaryFile(dir=tmp_dir,
-                                                  prefix=exe_name,
-                                                  suffix='.log',
-                                                  delete=False)
+        logfile_tmp = tempfile.NamedTemporaryFile(
+            dir=tmp_dir, prefix=exe_name, suffix=".log", delete=False
+        )
         logfile = logfile_tmp.name
         logfile_tmp.close()
     else:
-        logfile = salt.utils.path.join(
-            '/var/log',
-            '{0}.log'.format(exe_name)
-        )
+        logfile = salt.utils.path.join("/var/log", "{0}.log".format(exe_name))
 
     return logfile
 
 
-@salt.utils.decorators.path.which('chef-client')
-def client(whyrun=False,
-           localmode=False,
-           logfile=None,
-           **kwargs):
-    '''
+@salt.utils.decorators.path.which("chef-client")
+def client(whyrun=False, localmode=False, logfile=None, **kwargs):
+    """
     Execute a chef client run and return a dict with the stderr, stdout,
     return code, and pid.
 
@@ -123,29 +118,29 @@ def client(whyrun=False,
     whyrun
         Enable whyrun mode when set to True
 
-    '''
+    """
     if logfile is None:
-        logfile = _default_logfile('chef-client')
-    args = ['chef-client',
-            '--no-color',
-            '--once',
-            '--logfile "{0}"'.format(logfile),
-            '--format doc']
+        logfile = _default_logfile("chef-client")
+    args = [
+        "chef-client",
+        "--no-color",
+        "--once",
+        '--logfile "{0}"'.format(logfile),
+        "--format doc",
+    ]
 
     if whyrun:
-        args.append('--why-run')
+        args.append("--why-run")
 
     if localmode:
-        args.append('--local-mode')
+        args.append("--local-mode")
 
     return _exec_cmd(*args, **kwargs)
 
 
-@salt.utils.decorators.path.which('chef-solo')
-def solo(whyrun=False,
-         logfile=None,
-         **kwargs):
-    '''
+@salt.utils.decorators.path.which("chef-solo")
+def solo(whyrun=False, logfile=None, **kwargs):
+    """
     Execute a chef solo run and return a dict with the stderr, stdout,
     return code, and pid.
 
@@ -192,16 +187,18 @@ def solo(whyrun=False,
 
     whyrun
         Enable whyrun mode when set to True
-    '''
+    """
     if logfile is None:
-        logfile = _default_logfile('chef-solo')
-    args = ['chef-solo',
-            '--no-color',
-            '--logfile "{0}"'.format(logfile),
-            '--format doc']
+        logfile = _default_logfile("chef-solo")
+    args = [
+        "chef-solo",
+        "--no-color",
+        '--logfile "{0}"'.format(logfile),
+        "--format doc",
+    ]
 
     if whyrun:
-        args.append('--why-run')
+        args.append("--why-run")
 
     return _exec_cmd(*args, **kwargs)
 
@@ -209,12 +206,15 @@ def solo(whyrun=False,
 def _exec_cmd(*args, **kwargs):
 
     # Compile the command arguments
-    cmd_args = ' '.join(args)
-    cmd_kwargs = ''.join([
-         ' --{0} {1}'.format(k, v)
-         for k, v in six.iteritems(kwargs) if not k.startswith('__')
-    ])
-    cmd_exec = '{0}{1}'.format(cmd_args, cmd_kwargs)
-    log.debug('Chef command: {0}'.format(cmd_exec))
+    cmd_args = " ".join(args)
+    cmd_kwargs = "".join(
+        [
+            " --{0} {1}".format(k, v)
+            for k, v in six.iteritems(kwargs)
+            if not k.startswith("__")
+        ]
+    )
+    cmd_exec = "{0}{1}".format(cmd_args, cmd_kwargs)
+    log.debug("Chef command: %s", cmd_exec)
 
-    return __salt__['cmd.run_all'](cmd_exec, python_shell=False)
+    return __salt__["cmd.run_all"](cmd_exec, python_shell=False)
