@@ -51,7 +51,6 @@ Module for handling openstack keystone calls.
         salt '*' keystone.tenant_list profile=openstack1
 """
 
-
 import logging
 
 import salt.utils.http
@@ -173,7 +172,7 @@ def auth(profile=None, **connection_args):
         salt '*' keystone.auth
     """
     __utils__["versions.warn_until"](
-        "Sodium",
+        "Phosphorus",
         (
             "The keystone module has been deprecated and will be removed in {version}.  "
             "Please update to using the keystoneng module"
@@ -494,7 +493,6 @@ def role_delete(role_id=None, name=None, profile=None, **connection_args):
     """
     Delete a role (keystone role-delete)
 
-
     CLI Examples:
 
     .. code-block:: bash
