@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
-
 """
 :maintainer:    Alberto Planas <aplanas@suse.com>
 :maturity:      new
 :depends:       None
 :platform:      Linux
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import json
 import logging
@@ -14,7 +11,6 @@ import re
 
 import salt.utils.files
 from salt.exceptions import CommandExecutionError
-from salt.ext.six.moves import zip
 
 ADMIN_CFG = "/etc/kubernetes/admin.conf"
 
@@ -92,7 +88,7 @@ def _discovery_token_ca_cert_hash():
 
 def join_params(create_if_needed=False):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Return the parameters required for joining into the cluster
 
@@ -119,7 +115,7 @@ def join_params(create_if_needed=False):
 
 def version(kubeconfig=None, rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Return the version of kubeadm
 
@@ -168,7 +164,7 @@ def token_create(
     rootfs=None,
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Create bootstrap tokens on the server
 
@@ -184,7 +180,7 @@ def token_create(
        A human friendly description of how this token is used
 
     groups
-       List of extra groups that this token will authenticate, defaut
+       List of extra groups that this token will authenticate, default
        to ['system:bootstrappers:kubeadm:default-node-token']
 
     ttl
@@ -193,7 +189,7 @@ def token_create(
        is 24h0m0s
 
     usages
-       Describes the ways in wich this token can be used. The default
+       Describes the ways in which this token can be used. The default
        value is ['signing', 'authentication']
 
     kubeconfig
@@ -238,7 +234,7 @@ def token_create(
 
 def token_delete(token, kubeconfig=None, rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Delete bootstrap tokens on the server
 
@@ -274,7 +270,7 @@ def token_delete(token, kubeconfig=None, rootfs=None):
 
 def token_generate(kubeconfig=None, rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Generate and return a bootstrap token, but do not create it on the
     server
@@ -305,7 +301,7 @@ def token_generate(kubeconfig=None, rootfs=None):
 
 def token_list(kubeconfig=None, rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     List bootstrap tokens on the server
 
@@ -332,26 +328,27 @@ def token_list(kubeconfig=None, rootfs=None):
 
     lines = _cmd(cmd).splitlines()
 
-    # Find the header and parse it.  We do not need to validate the
-    # content, as the regex will take care of future changes.
-    header = lines.pop(0)
-    header = [i.lower() for i in re.findall(r"(\w+(?:\s\w+)*)", header)]
-
     tokens = []
-    for line in lines:
-        # TODO(aplanas): descriptions with multiple spaces can break
-        # the parser.
-        values = re.findall(r"(\S+(?:\s\S+)*)", line)
-        if len(header) != len(values):
-            log.error("Error parsing line: {}".format(line))
-            continue
-        tokens.append({key: value for key, value in zip(header, values)})
+    if lines:
+        # Find the header and parse it.  We do not need to validate
+        # the content, as the regex will take care of future changes.
+        header = lines.pop(0)
+        header = [i.lower() for i in re.findall(r"(\w+(?:\s\w+)*)", header)]
+
+        for line in lines:
+            # TODO(aplanas): descriptions with multiple spaces can
+            # break the parser.
+            values = re.findall(r"(\S+(?:\s\S+)*)", line)
+            if len(header) != len(values):
+                log.error("Error parsing line: {}".format(line))
+                continue
+            tokens.append({key: value for key, value in zip(header, values)})
     return tokens
 
 
 def alpha_certs_renew(rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Renews certificates for a Kubernetes cluster
 
@@ -385,7 +382,7 @@ def alpha_kubeconfig_user(
     rootfs=None,
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Outputs a kubeconfig file for an additional user
 
@@ -439,7 +436,7 @@ def alpha_kubeconfig_user(
 
 def alpha_kubelet_config_download(kubeconfig=None, kubelet_version=None, rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Downloads the kubelet configuration from the cluster ConfigMap
     kubelet-config-1.X
@@ -480,7 +477,7 @@ def alpha_kubelet_config_enable_dynamic(
     node_name, kubeconfig=None, kubelet_version=None, rootfs=None
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Enables or updates dynamic kubelet configuration for a node
 
@@ -535,7 +532,7 @@ def alpha_selfhosting_pivot(
     rootfs=None,
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Converts a static Pod-hosted control plane into a selt-hosted one
 
@@ -589,7 +586,7 @@ def config_images_list(
     rootfs=None,
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Print a list of images kubeadm will use
 
@@ -643,7 +640,7 @@ def config_images_pull(
     rootfs=None,
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Pull images used by kubeadm
 
@@ -695,7 +692,7 @@ def config_images_pull(
 
 def config_migrate(old_config, new_config=None, kubeconfig=None, rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Read an older version of the kubeadm configuration API types from
     a file, and output the similar config object for the newer version
@@ -738,7 +735,7 @@ def config_migrate(old_config, new_config=None, kubeconfig=None, rootfs=None):
 
 def config_print_init_defaults(component_configs=None, kubeconfig=None, rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Return default init configuration, that can be used for 'kubeadm
     init'
@@ -778,7 +775,7 @@ def config_print_init_defaults(component_configs=None, kubeconfig=None, rootfs=N
 
 def config_print_join_defaults(component_configs=None, kubeconfig=None, rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Return default join configuration, that can be used for 'kubeadm
     join'
@@ -818,7 +815,7 @@ def config_print_join_defaults(component_configs=None, kubeconfig=None, rootfs=N
 
 def config_upload_from_file(config, kubeconfig=None, rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Upload a configuration file to the in-cluster ConfigMap for
     kubeadm configuration
@@ -866,7 +863,7 @@ def config_upload_from_flags(
     rootfs=None,
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Create the in-cluster configuration file for the first time using
     flags
@@ -949,7 +946,7 @@ def config_upload_from_flags(
 
 def config_view(kubeconfig=None, rootfs=None):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     View the kubeadm configuration stored inside the cluster
 
@@ -1002,7 +999,7 @@ def init(
     rootfs=None,
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Command to set up the Kubernetes control plane
 
@@ -1184,7 +1181,7 @@ def join(
     rootfs=None,
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Command to join to an existing cluster
 
@@ -1309,7 +1306,7 @@ def reset(
     rootfs=None,
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Revert any changes made to this host by 'kubeadm init' or 'kubeadm
     join'
