@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Module for handling kubernetes calls.
 
@@ -23,7 +22,7 @@ provided `kubeconfig` entry is preferred.
 
     salt '*' kubernetes.nodes kubeconfig=/etc/salt/k8s/kubeconfig context=minikube
 
-.. versionadded: 2017.7.0
+.. versionadded:: 2017.7.0
 .. versionchanged:: 2019.2.0
 
 .. warning::
@@ -44,9 +43,6 @@ provided `kubeconfig` entry is preferred.
 
 """
 
-# Import Python Futures
-from __future__ import absolute_import, print_function, unicode_literals
-
 import base64
 import errno
 import logging
@@ -54,18 +50,14 @@ import os.path
 import signal
 import sys
 import tempfile
+import time
 from contextlib import contextmanager
-from time import sleep
 
 import salt.utils.files
 import salt.utils.platform
 import salt.utils.templates
-import salt.utils.versions
 import salt.utils.yaml
 from salt.exceptions import CommandExecutionError, TimeoutError
-from salt.ext import six
-from salt.ext.six import iteritems
-from salt.ext.six.moves import range  # pylint: disable=import-error
 
 try:
     import kubernetes  # pylint: disable=import-self
@@ -217,11 +209,6 @@ def _setup_conn(**kwargs):
 
     if not (kubeconfig and context):
         if kwargs.get("api_url") or __salt__["config.option"]("kubernetes.api_url"):
-            salt.utils.versions.warn_until(
-                "Sodium",
-                "Kubernetes configuration via url, certificate, username and password will be removed in Sodiom. "
-                "Use 'kubeconfig' and 'context' instead.",
-            )
             try:
                 return _setup_conn_old(**kwargs)
             except Exception:  # pylint: disable=broad-except
@@ -270,7 +257,7 @@ def _cleanup(**kwargs):
         if kubeconfig and os.path.basename(kubeconfig).startswith("salt-kubeconfig-"):
             try:
                 os.unlink(kubeconfig)
-            except (IOError, OSError) as err:
+            except OSError as err:
                 if err.errno != errno.ENOENT:
                     log.exception(err)
 
@@ -281,6 +268,9 @@ def ping(**kwargs):
     Returns True if the connection can be established, False otherwise.
 
     CLI Example:
+
+    .. code-block:: bash
+
         salt '*' kubernetes.ping
     """
     status = True
@@ -296,7 +286,9 @@ def nodes(**kwargs):
     """
     Return the names of the nodes composing the kubernetes cluster
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.nodes
         salt '*' kubernetes.nodes kubeconfig=/etc/salt/k8s/kubeconfig context=minikube
@@ -324,7 +316,9 @@ def node(name, **kwargs):
     """
     Return the details of the node identified by the specified name
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.node name='minikube'
     """
@@ -352,7 +346,9 @@ def node_labels(name, **kwargs):
     """
     Return the labels of the node identified by the specified name
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.node_labels name="minikube"
     """
@@ -370,7 +366,9 @@ def node_add_label(node_name, label_name, label_value, **kwargs):
     the node identified by the name `node_name`.
     Creates the label if not present.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.node_add_label node_name="minikube" \
             label_name="foo" label_value="bar"
@@ -398,7 +396,9 @@ def node_remove_label(node_name, label_name, **kwargs):
     Removes the label identified by `label_name` from
     the node identified by the name `node_name`.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.node_remove_label node_name="minikube" \
             label_name="foo"
@@ -425,7 +425,9 @@ def namespaces(**kwargs):
     """
     Return the names of the available namespaces
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.namespaces
         salt '*' kubernetes.namespaces kubeconfig=/etc/salt/k8s/kubeconfig context=minikube
@@ -450,7 +452,9 @@ def deployments(namespace="default", **kwargs):
     """
     Return a list of kubernetes deployments defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.deployments
         salt '*' kubernetes.deployments namespace=default
@@ -478,7 +482,9 @@ def services(namespace="default", **kwargs):
     """
     Return a list of kubernetes services defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.services
         salt '*' kubernetes.services namespace=default
@@ -505,7 +511,9 @@ def pods(namespace="default", **kwargs):
     """
     Return a list of kubernetes pods defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.pods
         salt '*' kubernetes.pods namespace=default
@@ -530,7 +538,9 @@ def secrets(namespace="default", **kwargs):
     """
     Return a list of kubernetes secrets defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.secrets
         salt '*' kubernetes.secrets namespace=default
@@ -557,7 +567,9 @@ def configmaps(namespace="default", **kwargs):
     """
     Return a list of kubernetes configmaps defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.configmaps
         salt '*' kubernetes.configmaps namespace=default
@@ -586,7 +598,9 @@ def show_deployment(name, namespace="default", **kwargs):
     """
     Return the kubernetes deployment defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_deployment my-nginx default
         salt '*' kubernetes.show_deployment name=my-nginx namespace=default
@@ -614,7 +628,9 @@ def show_service(name, namespace="default", **kwargs):
     """
     Return the kubernetes service defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_service my-nginx default
         salt '*' kubernetes.show_service name=my-nginx namespace=default
@@ -641,7 +657,9 @@ def show_pod(name, namespace="default", **kwargs):
     """
     Return POD information for a given pod name defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_pod guestbook-708336848-fqr2x
         salt '*' kubernetes.show_pod guestbook-708336848-fqr2x namespace=default
@@ -666,7 +684,9 @@ def show_namespace(name, **kwargs):
     """
     Return information for a given namespace defined by the specified name
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_namespace kube-system
     """
@@ -692,7 +712,9 @@ def show_secret(name, namespace="default", decode=False, **kwargs):
     The secrets can be decoded if specified by the user. Warning: this has
     security implications.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_secret confidential default
         salt '*' kubernetes.show_secret name=confidential namespace=default
@@ -723,7 +745,9 @@ def show_configmap(name, namespace="default", **kwargs):
     """
     Return the kubernetes configmap defined by name and namespace.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_configmap game-config default
         salt '*' kubernetes.show_configmap name=game-config namespace=default
@@ -750,7 +774,9 @@ def delete_deployment(name, namespace="default", **kwargs):
     """
     Deletes the kubernetes deployment defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_deployment my-nginx
         salt '*' kubernetes.delete_deployment name=my-nginx namespace=default
@@ -768,7 +794,7 @@ def delete_deployment(name, namespace="default", **kwargs):
             try:
                 with _time_limit(POLLING_TIME_LIMIT):
                     while show_deployment(name, namespace) is not None:
-                        sleep(1)
+                        time.sleep(1)
                     else:  # pylint: disable=useless-else-on-loop
                         mutable_api_response["code"] = 200
             except TimeoutError:
@@ -781,7 +807,7 @@ def delete_deployment(name, namespace="default", **kwargs):
                     mutable_api_response["code"] = 200
                     break
                 else:
-                    sleep(1)
+                    time.sleep(1)
         if mutable_api_response["code"] != 200:
             log.warning(
                 "Reached polling time limit. Deployment is not yet "
@@ -806,7 +832,9 @@ def delete_service(name, namespace="default", **kwargs):
     """
     Deletes the kubernetes service defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_service my-nginx default
         salt '*' kubernetes.delete_service name=my-nginx namespace=default
@@ -834,7 +862,9 @@ def delete_pod(name, namespace="default", **kwargs):
     """
     Deletes the kubernetes pod defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_pod guestbook-708336848-5nl8c default
         salt '*' kubernetes.delete_pod name=guestbook-708336848-5nl8c namespace=default
@@ -863,7 +893,9 @@ def delete_namespace(name, **kwargs):
     """
     Deletes the kubernetes namespace defined by name
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_namespace salt
         salt '*' kubernetes.delete_namespace name=salt
@@ -889,7 +921,9 @@ def delete_secret(name, namespace="default", **kwargs):
     """
     Deletes the kubernetes secret defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_secret confidential default
         salt '*' kubernetes.delete_secret name=confidential namespace=default
@@ -918,7 +952,9 @@ def delete_configmap(name, namespace="default", **kwargs):
     """
     Deletes the kubernetes configmap defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_configmap settings default
         salt '*' kubernetes.delete_configmap name=settings namespace=default
@@ -1068,7 +1104,9 @@ def create_secret(
     """
     Creates the kubernetes secret as defined by the user.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt 'minion1' kubernetes.create_secret \
             passwords default '{"db": "letmein"}'
@@ -1116,7 +1154,9 @@ def create_configmap(
     """
     Creates the kubernetes configmap as defined by the user.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt 'minion1' kubernetes.create_configmap \
             settings default '{"example.conf": "# example file"}'
@@ -1159,6 +1199,9 @@ def create_namespace(name, **kwargs):
     Creates a namespace with the specified name.
 
     CLI Example:
+
+    .. code-block:: bash
+
         salt '*' kubernetes.create_namespace salt
         salt '*' kubernetes.create_namespace name=salt
     """
@@ -1289,7 +1332,9 @@ def replace_secret(
     Replaces an existing secret with a new one defined by name and namespace,
     having the specificed data.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt 'minion1' kubernetes.replace_secret \
             name=passwords data='{"db": "letmein"}'
@@ -1344,7 +1389,9 @@ def replace_configmap(
     Replaces an existing configmap with a new one defined by name and
     namespace with the specified data.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt 'minion1' kubernetes.replace_configmap \
             settings default '{"example.conf": "# example file"}'
@@ -1403,7 +1450,7 @@ def __create_object_body(
             or src_obj["kind"] != kind
         ):
             raise CommandExecutionError(
-                "The source file should define only " "a {0} object".format(kind)
+                "The source file should define only " "a {} object".format(kind)
             )
 
         if "metadata" in src_obj:
@@ -1424,7 +1471,7 @@ def __read_and_render_yaml_file(source, template, saltenv):
     """
     sfn = __salt__["cp.cache_file"](source, saltenv)
     if not sfn:
-        raise CommandExecutionError("Source file '{0}' not found".format(source))
+        raise CommandExecutionError("Source file '{}' not found".format(source))
 
     with salt.utils.files.fopen(sfn, "r") as src:
         contents = src.read()
@@ -1449,13 +1496,13 @@ def __read_and_render_yaml_file(source, template, saltenv):
                     # Failed to render the template
                     raise CommandExecutionError(
                         "Failed to render file path with error: "
-                        "{0}".format(data["data"])
+                        "{}".format(data["data"])
                     )
 
                 contents = data["data"].encode("utf-8")
             else:
                 raise CommandExecutionError(
-                    "Unknown template specified: {0}".format(template)
+                    "Unknown template specified: {}".format(template)
                 )
 
         return salt.utils.yaml.safe_load(contents)
@@ -1474,7 +1521,7 @@ def __dict_to_object_meta(name, namespace, metadata):
     if "kubernetes.io/change-cause" not in metadata["annotations"]:
         metadata["annotations"]["kubernetes.io/change-cause"] = " ".join(sys.argv)
 
-    for key, value in iteritems(metadata):
+    for key, value in metadata.items():
         if hasattr(meta_obj, key):
             setattr(meta_obj, key, value)
 
@@ -1493,7 +1540,7 @@ def __dict_to_deployment_spec(spec):
     Converts a dictionary into kubernetes AppsV1beta1DeploymentSpec instance.
     """
     spec_obj = AppsV1beta1DeploymentSpec(template=spec.get("template", ""))
-    for key, value in iteritems(spec):
+    for key, value in spec.items():
         if hasattr(spec_obj, key):
             setattr(spec_obj, key, value)
 
@@ -1505,7 +1552,7 @@ def __dict_to_pod_spec(spec):
     Converts a dictionary into kubernetes V1PodSpec instance.
     """
     spec_obj = kubernetes.client.V1PodSpec()
-    for key, value in iteritems(spec):
+    for key, value in spec.items():
         if hasattr(spec_obj, key):
             setattr(spec_obj, key, value)
 
@@ -1517,13 +1564,13 @@ def __dict_to_service_spec(spec):
     Converts a dictionary into kubernetes V1ServiceSpec instance.
     """
     spec_obj = kubernetes.client.V1ServiceSpec()
-    for key, value in iteritems(spec):  # pylint: disable=too-many-nested-blocks
+    for key, value in spec.items():  # pylint: disable=too-many-nested-blocks
         if key == "ports":
             spec_obj.ports = []
             for port in value:
                 kube_port = kubernetes.client.V1ServicePort()
                 if isinstance(port, dict):
-                    for port_key, port_value in iteritems(port):
+                    for port_key, port_value in port.items():
                         if hasattr(kube_port, port_key):
                             setattr(kube_port, port_key, port_value)
                 else:
@@ -1541,7 +1588,7 @@ def __enforce_only_strings_dict(dictionary):
     """
     ret = {}
 
-    for key, value in iteritems(dictionary):
-        ret[six.text_type(key)] = six.text_type(value)
+    for key, value in dictionary.items():
+        ret[str(key)] = str(value)
 
     return ret
