@@ -1,29 +1,24 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 The match module allows for match routines to be run and determine target specs
-'''
-from __future__ import absolute_import
+"""
 
-# Import python libs
+import copy
 import inspect
 import logging
 import sys
+from collections.abc import Mapping
 
-# Import salt libs
-import salt.minion
-import salt.utils
+import salt.loader
 from salt.defaults import DEFAULT_TARGET_DELIM
-from salt.ext.six import string_types
+from salt.exceptions import SaltException
 
-__func_alias__ = {
-    'list_': 'list'
-}
+__func_alias__ = {"list_": "list"}
 
 log = logging.getLogger(__name__)
 
 
 def compound(tgt, minion_id=None):
-    '''
+    """
     Return True if the minion ID matches the given compound target
 
     minion_id
@@ -36,24 +31,22 @@ def compound(tgt, minion_id=None):
     .. code-block:: bash
 
         salt '*' match.compound 'L@cheese,foo and *'
-    '''
-    opts = {'grains': __grains__, 'pillar': __pillar__}
+    """
     if minion_id is not None:
-        if not isinstance(minion_id, string_types):
+        if not isinstance(minion_id, str):
             minion_id = str(minion_id)
-    else:
-        minion_id = __grains__['id']
-    opts['id'] = minion_id
-    matcher = salt.minion.Matcher(opts, __salt__)
+    matchers = salt.loader.matchers(__opts__)
     try:
-        return matcher.compound_match(tgt)
-    except Exception as exc:
+        ret = matchers["compound_match.match"](tgt, opts=__opts__, minion_id=minion_id)
+    except Exception as exc:  # pylint: disable=broad-except
         log.exception(exc)
-        return False
+        ret = False
+
+    return ret
 
 
 def ipcidr(tgt):
-    '''
+    """
     Return True if the minion matches the given ipcidr target
 
     CLI Example:
@@ -71,17 +64,17 @@ def ipcidr(tgt):
          - match: ipcidr
          - nodeclass: internal
 
-    '''
-    matcher = salt.minion.Matcher({'grains': __grains__}, __salt__)
+    """
+    matchers = salt.loader.matchers(__opts__)
     try:
-        return matcher.ipcidr_match(tgt)
-    except Exception as exc:
+        return matchers["ipcidr_match.match"](tgt, opts=__opts__)
+    except Exception as exc:  # pylint: disable=broad-except
         log.exception(exc)
         return False
 
 
 def pillar_pcre(tgt, delimiter=DEFAULT_TARGET_DELIM):
-    '''
+    """
     Return True if the minion matches the given pillar_pcre target. The
     ``delimiter`` argument can be used to specify a different delimiter.
 
@@ -102,17 +95,19 @@ def pillar_pcre(tgt, delimiter=DEFAULT_TARGET_DELIM):
 
         .. versionadded:: 0.16.4
         .. deprecated:: 2015.8.0
-    '''
-    matcher = salt.minion.Matcher({'pillar': __pillar__}, __salt__)
+    """
+    matchers = salt.loader.matchers(__opts__)
     try:
-        return matcher.pillar_pcre_match(tgt, delimiter=delimiter)
-    except Exception as exc:
+        return matchers["pillar_pcre_match.match"](
+            tgt, delimiter=delimiter, opts=__opts__
+        )
+    except Exception as exc:  # pylint: disable=broad-except
         log.exception(exc)
         return False
 
 
 def pillar(tgt, delimiter=DEFAULT_TARGET_DELIM):
-    '''
+    """
     Return True if the minion matches the given pillar target. The
     ``delimiter`` argument can be used to specify a different delimiter.
 
@@ -133,17 +128,17 @@ def pillar(tgt, delimiter=DEFAULT_TARGET_DELIM):
 
         .. versionadded:: 0.16.4
         .. deprecated:: 2015.8.0
-    '''
-    matcher = salt.minion.Matcher({'pillar': __pillar__}, __salt__)
+    """
+    matchers = salt.loader.matchers(__opts__)
     try:
-        return matcher.pillar_match(tgt, delimiter=delimiter)
-    except Exception as exc:
+        return matchers["pillar_match.match"](tgt, delimiter=delimiter, opts=__opts__)
+    except Exception as exc:  # pylint: disable=broad-except
         log.exception(exc)
         return False
 
 
 def data(tgt):
-    '''
+    """
     Return True if the minion matches the given data target
 
     CLI Example:
@@ -151,17 +146,17 @@ def data(tgt):
     .. code-block:: bash
 
         salt '*' match.data 'spam:eggs'
-    '''
-    matcher = salt.minion.Matcher(__opts__, __salt__)
+    """
+    matchers = salt.loader.matchers(__opts__)
     try:
-        return matcher.data_match(tgt)
-    except Exception as exc:
+        return matchers["data_match.match"](tgt, opts=__opts__)
+    except Exception as exc:  # pylint: disable=broad-except
         log.exception(exc)
         return False
 
 
 def grain_pcre(tgt, delimiter=DEFAULT_TARGET_DELIM):
-    '''
+    """
     Return True if the minion matches the given grain_pcre target. The
     ``delimiter`` argument can be used to specify a different delimiter.
 
@@ -182,17 +177,19 @@ def grain_pcre(tgt, delimiter=DEFAULT_TARGET_DELIM):
 
         .. versionadded:: 0.16.4
         .. deprecated:: 2015.8.0
-    '''
-    matcher = salt.minion.Matcher({'grains': __grains__}, __salt__)
+    """
+    matchers = salt.loader.matchers(__opts__)
     try:
-        return matcher.grain_pcre_match(tgt, delimiter=delimiter)
-    except Exception as exc:
+        return matchers["grain_pcre_match.match"](
+            tgt, delimiter=delimiter, opts=__opts__
+        )
+    except Exception as exc:  # pylint: disable=broad-except
         log.exception(exc)
         return False
 
 
 def grain(tgt, delimiter=DEFAULT_TARGET_DELIM):
-    '''
+    """
     Return True if the minion matches the given grain target. The ``delimiter``
     argument can be used to specify a different delimiter.
 
@@ -213,17 +210,17 @@ def grain(tgt, delimiter=DEFAULT_TARGET_DELIM):
 
         .. versionadded:: 0.16.4
         .. deprecated:: 2015.8.0
-    '''
-    matcher = salt.minion.Matcher({'grains': __grains__}, __salt__)
+    """
+    matchers = salt.loader.matchers(__opts__)
     try:
-        return matcher.grain_match(tgt, delimiter=delimiter)
-    except Exception as exc:
+        return matchers["grain_match.match"](tgt, delimiter=delimiter, opts=__opts__)
+    except Exception as exc:  # pylint: disable=broad-except
         log.exception(exc)
         return False
 
 
 def list_(tgt, minion_id=None):
-    '''
+    """
     Return True if the minion ID matches the given list target
 
     minion_id
@@ -236,22 +233,20 @@ def list_(tgt, minion_id=None):
     .. code-block:: bash
 
         salt '*' match.list 'server1,server2'
-    '''
+    """
     if minion_id is not None:
-        if not isinstance(minion_id, string_types):
+        if not isinstance(minion_id, str):
             minion_id = str(minion_id)
-    else:
-        minion_id = __grains__['id']
-    matcher = salt.minion.Matcher({'id': minion_id}, __salt__)
+    matchers = salt.loader.matchers(__opts__)
     try:
-        return matcher.list_match(tgt)
-    except Exception as exc:
+        return matchers["list_match.match"](tgt, opts=__opts__, minion_id=minion_id)
+    except Exception as exc:  # pylint: disable=broad-except
         log.exception(exc)
         return False
 
 
 def pcre(tgt, minion_id=None):
-    '''
+    """
     Return True if the minion ID matches the given pcre target
 
     minion_id
@@ -264,22 +259,20 @@ def pcre(tgt, minion_id=None):
     .. code-block:: bash
 
         salt '*' match.pcre '.*'
-    '''
+    """
     if minion_id is not None:
-        if not isinstance(minion_id, string_types):
+        if not isinstance(minion_id, str):
             minion_id = str(minion_id)
-    else:
-        minion_id = __grains__['id']
-    matcher = salt.minion.Matcher({'id': minion_id}, __salt__)
+    matchers = salt.loader.matchers(__opts__)
     try:
-        return matcher.pcre_match(tgt)
-    except Exception as exc:
+        return matchers["pcre_match.match"](tgt, opts=__opts__, minion_id=minion_id)
+    except Exception as exc:  # pylint: disable=broad-except
         log.exception(exc)
         return False
 
 
 def glob(tgt, minion_id=None):
-    '''
+    """
     Return True if the minion ID matches the given glob target
 
     minion_id
@@ -292,26 +285,28 @@ def glob(tgt, minion_id=None):
     .. code-block:: bash
 
         salt '*' match.glob '*'
-    '''
+    """
     if minion_id is not None:
-        if not isinstance(minion_id, string_types):
+        if not isinstance(minion_id, str):
             minion_id = str(minion_id)
-    else:
-        minion_id = __grains__['id']
-    matcher = salt.minion.Matcher({'id': minion_id}, __salt__)
+    matchers = salt.loader.matchers(__opts__)
+
     try:
-        return matcher.glob_match(tgt)
-    except Exception as exc:
+        return matchers["glob_match.match"](tgt, opts=__opts__, minion_id=minion_id)
+    except Exception as exc:  # pylint: disable=broad-except
         log.exception(exc)
         return False
 
 
-def filter_by(lookup,
-              tgt_type='compound',
-              minion_id=None,
-              expr_form=None,
-              default='default'):
-    '''
+def filter_by(
+    lookup,
+    tgt_type="compound",
+    minion_id=None,
+    merge=None,
+    merge_lists=False,
+    default="default",
+):
+    """
     Return the first match in a dictionary of target patterns
 
     .. versionadded:: 2014.7.0
@@ -330,35 +325,38 @@ def filter_by(lookup,
         {% set roles = salt['match.filter_by']({
             'web*': ['app', 'caching'],
             'db*': ['db'],
-        }, default='web*') %}
+        }, minion_id=grains['id'], default='web*') %}
 
         # Make the filtered data available to Pillar:
         roles: {{ roles | yaml() }}
-    '''
-    # remember to remove the expr_form argument from this function when
-    # performing the cleanup on this deprecation.
-    if expr_form is not None:
-        salt.utils.warn_until(
-            'Fluorine',
-            'the target type should be passed using the \'tgt_type\' '
-            'argument instead of \'expr_form\'. Support for using '
-            '\'expr_form\' will be removed in Salt Fluorine.'
-        )
-        tgt_type = expr_form
-
-    expr_funcs = dict(inspect.getmembers(sys.modules[__name__],
-        predicate=inspect.isfunction))
+    """
+    expr_funcs = dict(
+        inspect.getmembers(sys.modules[__name__], predicate=inspect.isfunction)
+    )
 
     for key in lookup:
-        params = (key, minion_id) if minion_id else (key, )
+        params = (key, minion_id) if minion_id else (key,)
         if expr_funcs[tgt_type](*params):
+            if merge:
+                if not isinstance(merge, Mapping):
+                    raise SaltException(
+                        "filter_by merge argument must be a dictionary."
+                    )
+
+                if lookup[key] is None:
+                    return merge
+                else:
+                    salt.utils.dictupdate.update(
+                        lookup[key], copy.deepcopy(merge), merge_lists=merge_lists
+                    )
+
             return lookup[key]
 
     return lookup.get(default, None)
 
 
-def search_by(lookup, tgt_type='compound', minion_id=None):
-    '''
+def search_by(lookup, tgt_type="compound", minion_id=None):
+    """
     Search a dictionary of target strings for matching targets
 
     This is the inverse of :py:func:`match.filter_by
@@ -369,13 +367,13 @@ def search_by(lookup, tgt_type='compound', minion_id=None):
 
     CLI Example:
 
-    .. code-block:: base
+    .. code-block:: bash
 
         salt '*' match.search_by '{web: [node1, node2], db: [node2, node]}'
 
     Pillar Example:
 
-    .. code-block:: yaml
+    .. code-block:: jinja
 
         {% set roles = salt.match.search_by({
             'web': ['G@os_family:Debian not nodeX'],
@@ -385,14 +383,15 @@ def search_by(lookup, tgt_type='compound', minion_id=None):
 
         # Make the filtered data available to Pillar:
         roles: {{ roles | yaml() }}
-    '''
-    expr_funcs = dict(inspect.getmembers(sys.modules[__name__],
-        predicate=inspect.isfunction))
+    """
+    expr_funcs = dict(
+        inspect.getmembers(sys.modules[__name__], predicate=inspect.isfunction)
+    )
 
     matches = []
     for key, target_list in lookup.items():
         for target in target_list:
-            params = (target, minion_id) if minion_id else (target, )
+            params = (target, minion_id) if minion_id else (target,)
             if expr_funcs[tgt_type](*params):
                 matches.append(key)
 
