@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Module for sending messages to Mattermost
 
 .. versionadded:: 2017.7.0
@@ -13,10 +13,11 @@ Module for sending messages to Mattermost
         mattermost:
           hook: peWcBiMOS9HrZG15peWcBiMOS9HrZG15
           api_url: https://example.com
-'''
+"""
 
 # Import Python libs
 from __future__ import absolute_import, print_function, unicode_literals
+
 import logging
 
 # Import Salt libs
@@ -26,76 +27,76 @@ from salt.exceptions import SaltInvocationError
 
 log = logging.getLogger(__name__)
 
-__virtualname__ = 'mattermost'
+__virtualname__ = "mattermost"
 
 
 def __virtual__():
-    '''
+    """
     Return virtual name of the module.
 
     :return: The virtual name of the module.
-    '''
+    """
     return __virtualname__
 
 
 def _get_hook():
-    '''
+    """
     Retrieves and return the Mattermost's configured hook
 
     :return:            String: the hook string
-    '''
-    hook = __salt__['config.get']('mattermost.hook') or \
-        __salt__['config.get']('mattermost:hook')
+    """
+    hook = __salt__["config.get"]("mattermost.hook") or __salt__["config.get"](
+        "mattermost:hook"
+    )
     if not hook:
-        raise SaltInvocationError('No Mattermost Hook found')
+        raise SaltInvocationError("No Mattermost Hook found")
 
     return hook
 
 
 def _get_api_url():
-    '''
+    """
     Retrieves and return the Mattermost's configured api url
 
     :return:            String: the api url string
-    '''
-    api_url = __salt__['config.get']('mattermost.api_url') or \
-        __salt__['config.get']('mattermost:api_url')
+    """
+    api_url = __salt__["config.get"]("mattermost.api_url") or __salt__["config.get"](
+        "mattermost:api_url"
+    )
     if not api_url:
-        raise SaltInvocationError('No Mattermost API URL found')
+        raise SaltInvocationError("No Mattermost API URL found")
 
     return api_url
 
 
 def _get_channel():
-    '''
+    """
     Retrieves the Mattermost's configured channel
 
     :return:            String: the channel string
-    '''
-    channel = __salt__['config.get']('mattermost.channel') or \
-        __salt__['config.get']('mattermost:channel')
+    """
+    channel = __salt__["config.get"]("mattermost.channel") or __salt__["config.get"](
+        "mattermost:channel"
+    )
 
     return channel
 
 
 def _get_username():
-    '''
+    """
     Retrieves the Mattermost's configured username
 
     :return:            String: the username string
-    '''
-    username = __salt__['config.get']('mattermost.username') or \
-        __salt__['config.get']('mattermost:username')
+    """
+    username = __salt__["config.get"]("mattermost.username") or __salt__["config.get"](
+        "mattermost:username"
+    )
 
     return username
 
 
-def post_message(message,
-                 channel=None,
-                 username=None,
-                 api_url=None,
-                 hook=None):
-    '''
+def post_message(message, channel=None, username=None, api_url=None, hook=None):
+    """
     Send a message to a Mattermost channel.
 
     :param channel:     The channel name, either will work.
@@ -109,8 +110,8 @@ def post_message(message,
 
     .. code-block:: bash
 
-        salt '*' mattermost.post_message message='Build is done"
-    '''
+        salt '*' mattermost.post_message message='Build is done'
+    """
     if not api_url:
         api_url = _get_api_url()
 
@@ -124,16 +125,18 @@ def post_message(message,
         channel = _get_channel()
 
     if not message:
-        log.error('message is a required option.')
+        log.error("message is a required option.")
 
     parameters = dict()
     if channel:
-        parameters['channel'] = channel
+        parameters["channel"] = channel
     if username:
-        parameters['username'] = username
-    parameters['text'] = '```' + message + '```'  # pre-formatted, fixed-width text
-    log.debug('Parameters: %s', parameters)
-    data = str('payload={0}').format(salt.utils.json.dumps(parameters))  # pylint: disable=blacklisted-function
+        parameters["username"] = username
+    parameters["text"] = "```" + message + "```"  # pre-formatted, fixed-width text
+    log.debug("Parameters: %s", parameters)
+    data = str("payload={0}").format(
+        salt.utils.json.dumps(parameters)
+    )  # pylint: disable=blacklisted-function
     result = salt.utils.mattermost.query(api_url=api_url, hook=hook, data=data)
 
     return bool(result)
