@@ -1,10 +1,17 @@
-# encoding: utf-8
 """
 A REST API for Salt
 ===================
 
 .. py:currentmodule:: salt.netapi.rest_cherrypy.app
 
+.. note::
+
+    This module is Experimental on Windows platforms and supports limited
+    configurations:
+
+    - doesn't support PAM authentication (i.e. external_auth: auto)
+    - doesn't support SSL (i.e. disable_ssl: True)
+
 :depends:
     - CherryPy Python module.
 
@@ -68,12 +75,12 @@ A REST API for Salt
     debug : ``False``
         Starts the web server in development mode. It will reload itself when
         the underlying code is changed and will output more debugging info.
-    log.access_file
+    log_access_file
         Path to a file to write HTTP access logs.
 
         .. versionadded:: 2016.11.0
 
-    log.error_file
+    log_error_file
         Path to a file to write HTTP error logs.
 
         .. versionadded:: 2016.11.0
@@ -576,7 +583,6 @@ rest_cherrypy will remain the officially recommended REST API.
 .. |406| replace:: requested Content-Type not available
 
 """
-from __future__ import absolute_import
 
 import functools
 import io
@@ -587,6 +593,7 @@ import signal
 import tarfile
 from collections.abc import Iterator, Mapping
 from multiprocessing import Pipe, Process
+from urllib.parse import parse_qsl
 
 import cherrypy  # pylint: disable=import-error,3rd-party-module-not-gated
 import salt
@@ -684,7 +691,7 @@ def salt_api_acl_tool(username, request):
     in order to provide whitelisting for the API similar to the
     master, but over the API.
 
-    ..code-block:: yaml
+    .. code-block:: yaml
 
         rest_cherrypy:
             api_acl:
@@ -755,11 +762,11 @@ def salt_ip_verify_tool():
         if cherrypy_conf:
             auth_ip_list = cherrypy_conf.get("authorized_ips", None)
             if auth_ip_list:
-                logger.debug("Found IP list: {0}".format(auth_ip_list))
+                logger.debug("Found IP list: {}".format(auth_ip_list))
                 rem_ip = cherrypy.request.headers.get("Remote-Addr", None)
-                logger.debug("Request from IP: {0}".format(rem_ip))
+                logger.debug("Request from IP: {}".format(rem_ip))
                 if rem_ip not in auth_ip_list:
-                    logger.error("Blocked IP: {0}".format(rem_ip))
+                    logger.error("Blocked IP: {}".format(rem_ip))
                     raise cherrypy.HTTPError(403, "Bad IP")
 
 
@@ -887,7 +894,7 @@ def hypermedia_handler(*args, **kwargs):
 
         ret = {
             "status": cherrypy.response.status,
-            "return": "{0}".format(traceback.format_exc(exc))
+            "return": "{}".format(traceback.format_exc(exc))
             if cherrypy.config["debug"]
             else "An unexpected error occurred",
         }
@@ -937,8 +944,8 @@ def process_request_body(fn):
 
 def urlencoded_processor(entity):
     """
-    Accept x-www-form-urlencoded data (run through CherryPy's formatter)
-    and reformat it into a Low State data structure.
+    Accept x-www-form-urlencoded data and reformat it into a Low State
+    data structure.
 
     Since we can't easily represent complicated data structures with
     key-value pairs, any more complicated requirements (e.g. compound
@@ -953,11 +960,15 @@ def urlencoded_processor(entity):
 
     :param entity: raw POST data
     """
-    # First call out to CherryPy's default processor
-    cherrypy._cpreqbody.process_urlencoded(entity)
-    cherrypy._cpreqbody.process_urlencoded(entity)
-    cherrypy.serving.request.unserialized_data = entity.params
-    cherrypy.serving.request.raw_body = ""
+    # cherrypy._cpreqbody.process_urlencoded doesn't preserve the raw
+    # "body", so we have to handle parsing the tokens using parse_qsl
+    urlencoded = entity.read()
+    try:
+        urlencoded = urlencoded.decode("utf-8")
+    except (UnicodeDecodeError, AttributeError):
+        pass
+    cherrypy.serving.request.raw_body = urlencoded
+    cherrypy.serving.request.unserialized_data = dict(parse_qsl(urlencoded))
 
 
 @process_request_body
@@ -1115,7 +1126,7 @@ for hook, tool_list in tools_config.items():
 ###############################################################################
 
 
-class LowDataAdapter(object):
+class LowDataAdapter:
     """
     The primary entry point to Salt's REST API
 
@@ -1189,8 +1200,7 @@ class LowDataAdapter(object):
 
             # Sometimes Salt gives us a return and sometimes an iterator
             if isinstance(ret, Iterator):
-                for i in ret:
-                    yield i
+                yield from ret
             else:
                 yield ret
 
@@ -1409,7 +1419,7 @@ class Minions(LowDataAdapter):
         return {
             "return": job_data,
             "_links": {
-                "jobs": [{"href": "/jobs/{0}".format(i["jid"])} for i in job_data if i],
+                "jobs": [{"href": "/jobs/{}".format(i["jid"])} for i in job_data if i],
             },
         }
 
@@ -1516,8 +1526,8 @@ class Jobs(LowDataAdapter):
             minion_ret = {}
             returns = job_ret_info[0].get("Result")
             for minion in returns:
-                if u"return" in returns[minion]:
-                    minion_ret[minion] = returns[minion].get(u"return")
+                if "return" in returns[minion]:
+                    minion_ret[minion] = returns[minion].get("return")
                 else:
                     minion_ret[minion] = returns[minion].get("return")
             ret["return"] = [minion_ret]
@@ -1713,7 +1723,7 @@ class Keys(LowDataAdapter):
         headers = cherrypy.response.headers
         headers[
             "Content-Disposition"
-        ] = 'attachment; filename="saltkeys-{0}.tar"'.format(lowstate[0]["id_"])
+        ] = 'attachment; filename="saltkeys-{}.tar"'.format(lowstate[0]["id_"])
         headers["Content-Type"] = "application/x-tar"
         headers["Content-Length"] = len(fileobj.getvalue())
         headers["Cache-Control"] = "no-cache"
@@ -1730,7 +1740,7 @@ class Login(LowDataAdapter):
     """
 
     def __init__(self, *args, **kwargs):
-        super(Login, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self.auth = salt.auth.Resolver(self.opts)
 
@@ -1877,19 +1887,19 @@ class Login(LowDataAdapter):
 
                 if "groups" in token and token["groups"]:
                     user_groups = set(token["groups"])
-                    eauth_groups = set(
-                        [i.rstrip("%") for i in eauth.keys() if i.endswith("%")]
-                    )
+                    eauth_groups = {
+                        i.rstrip("%") for i in eauth.keys() if i.endswith("%")
+                    }
 
                     for group in user_groups & eauth_groups:
-                        perms.extend(eauth["{0}%".format(group)])
+                        perms.extend(eauth["{}%".format(group)])
 
             if not perms:
                 logger.debug("Eauth permission list not found.")
         except Exception:  # pylint: disable=broad-except
             logger.debug(
                 "Configuration for external_auth malformed for "
-                "eauth '{0}', and user '{1}'.".format(
+                "eauth '{}', and user '{}'.".format(
                     token.get("eauth"), token.get("name")
                 ),
                 exc_info=True,
@@ -2001,7 +2011,7 @@ class Token(LowDataAdapter):
 class Run(LowDataAdapter):
     """
     Run commands bypassing the :ref:`normal session handling
-    <rest_cherrypy-auth>`
+    <rest_cherrypy-auth>`.
 
     salt-api does not enforce authorization, Salt's eauth system does that.
     Local/Runner/WheelClient all accept ``username``/``password``/``eauth``
@@ -2022,7 +2032,7 @@ class Run(LowDataAdapter):
     def POST(self, **kwargs):
         """
         Run commands bypassing the :ref:`normal session handling
-        <rest_cherrypy-auth>` Other than that this URL is identical to the
+        <rest_cherrypy-auth>`.  Otherwise, this URL is identical to the
         :py:meth:`root URL (/) <LowDataAdapter.POST>`.
 
         .. http:post:: /run
@@ -2090,14 +2100,9 @@ class Run(LowDataAdapter):
               ms-3: true
               ms-4: true
 
-        The /run enpoint can also be used to issue commands using the salt-ssh
-        subsystem.
-
-        When using salt-ssh, eauth credentials should not be supplied. Instead,
-        authentication should be handled by the SSH layer itself. The use of
-        the salt-ssh client does not require a salt master to be running.
-        Instead, only a roster file must be present in the salt configuration
-        directory.
+        The /run endpoint can also be used to issue commands using the salt-ssh
+        subsystem.  When using salt-ssh, eauth credentials must also be
+        supplied, and are subject to :ref:`eauth access-control lists <acl>`.
 
         All SSH client requests are synchronous.
 
@@ -2109,6 +2114,9 @@ class Run(LowDataAdapter):
                 -H 'Accept: application/x-yaml' \\
                 -d client='ssh' \\
                 -d tgt='*' \\
+                -d username='saltdev' \\
+                -d password='saltdev' \\
+                -d eauth='auto' \\
                 -d fun='test.ping'
 
         .. code-block:: text
@@ -2119,28 +2127,26 @@ class Run(LowDataAdapter):
             Content-Length: 75
             Content-Type: application/x-www-form-urlencoded
 
-            client=ssh&tgt=*&fun=test.ping
-
         **Example SSH response:**
 
         .. code-block:: text
 
                 return:
                 - silver:
-                  fun: test.ping
-                  fun_args: []
-                  id: silver
-                  jid: '20141203103525666185'
-                  retcode: 0
-                  return: true
-                  success: true
+                    _stamp: '2020-09-08T23:04:28.912609'
+                    fun: test.ping
+                    fun_args: []
+                    id: silver
+                    jid: '20200908230427905565'
+                    retcode: 0
+                    return: true
         """
         return {
             "return": list(self.exec_lowstate()),
         }
 
 
-class Events(object):
+class Events:
     """
     Expose the Salt event bus
 
@@ -2348,30 +2354,30 @@ class Events(object):
             """
             An iterator to yield Salt events
             """
-            event = salt.utils.event.get_event(
+            with salt.utils.event.get_event(
                 "master",
                 sock_dir=self.opts["sock_dir"],
                 transport=self.opts["transport"],
                 opts=self.opts,
                 listen=True,
-            )
-            stream = event.iter_events(full=True, auto_reconnect=True)
+            ) as event:
+                stream = event.iter_events(full=True, auto_reconnect=True)
 
-            yield str("retry: 400\n")  # future lint: disable=blacklisted-function
+                yield "retry: 400\n"  # future lint: disable=blacklisted-function
 
-            while True:
-                data = next(stream)
-                yield str("tag: {0}\n").format(
-                    data.get("tag", "")
-                )  # future lint: disable=blacklisted-function
-                yield str("data: {0}\n\n").format(
-                    salt.utils.json.dumps(data)
-                )  # future lint: disable=blacklisted-function
+                while True:
+                    data = next(stream)
+                    yield "tag: {}\n".format(
+                        data.get("tag", "")
+                    )  # future lint: disable=blacklisted-function
+                    yield "data: {}\n\n".format(
+                        salt.utils.json.dumps(data)
+                    )  # future lint: disable=blacklisted-function
 
         return listen()
 
 
-class WebsocketEndpoint(object):
+class WebsocketEndpoint:
     """
     Open a WebSocket connection to Salt's event bus
 
@@ -2528,38 +2534,38 @@ class WebsocketEndpoint(object):
             # blocks until send is called on the parent end of this pipe.
             pipe.recv()
 
-            event = salt.utils.event.get_event(
+            with salt.utils.event.get_event(
                 "master",
                 sock_dir=self.opts["sock_dir"],
                 transport=self.opts["transport"],
                 opts=self.opts,
                 listen=True,
-            )
-            stream = event.iter_events(full=True, auto_reconnect=True)
-            SaltInfo = event_processor.SaltInfo(handler)
+            ) as event:
+                stream = event.iter_events(full=True, auto_reconnect=True)
+                SaltInfo = event_processor.SaltInfo(handler)
 
-            def signal_handler(signal, frame):
-                os._exit(0)
+                def signal_handler(signal, frame):
+                    os._exit(0)
 
-            signal.signal(signal.SIGTERM, signal_handler)
+                signal.signal(signal.SIGTERM, signal_handler)
 
-            while True:
-                data = next(stream)
-                if data:
-                    try:  # work around try to decode catch unicode errors
-                        if "format_events" in kwargs:
-                            SaltInfo.process(data, salt_token, self.opts)
-                        else:
-                            handler.send(
-                                str("data: {0}\n\n").format(
-                                    salt.utils.json.dumps(data)
-                                ),  # future lint: disable=blacklisted-function
-                                False,
+                while True:
+                    data = next(stream)
+                    if data:
+                        try:  # work around try to decode catch unicode errors
+                            if "format_events" in kwargs:
+                                SaltInfo.process(data, salt_token, self.opts)
+                            else:
+                                handler.send(
+                                    "data: {}\n\n".format(
+                                        salt.utils.json.dumps(data)
+                                    ),  # future lint: disable=blacklisted-function
+                                    False,
+                                )
+                        except UnicodeDecodeError:
+                            logger.error(
+                                "Error: Salt event has non UTF-8 data:\n{}".format(data)
                             )
-                    except UnicodeDecodeError:
-                        logger.error(
-                            "Error: Salt event has non UTF-8 data:\n{0}".format(data)
-                        )
 
         parent_pipe, child_pipe = Pipe()
         handler.pipe = parent_pipe
@@ -2570,7 +2576,7 @@ class WebsocketEndpoint(object):
         proc.start()
 
 
-class Webhook(object):
+class Webhook:
     """
     A generic web hook entry point that fires an event on Salt's event bus
 
@@ -2738,7 +2744,7 @@ class Webhook(object):
         return {"success": ret}
 
 
-class Stats(object):
+class Stats:
     """
     Expose statistics on the running CherryPy server
     """
@@ -2772,7 +2778,7 @@ class Stats(object):
         return {}
 
 
-class App(object):
+class App:
     """
     Class to serve HTML5 apps
     """
@@ -2786,7 +2792,7 @@ class App(object):
         This is useful in combination with a browser-based app using the HTML5
         history API.
 
-        .. http::get:: /app
+        .. http:get:: /app
 
             :reqheader X-Auth-Token: |req_token|
 
@@ -2802,7 +2808,7 @@ class App(object):
         return cherrypy.lib.static.serve_file(apiopts.get("app", default_index))
 
 
-class API(object):
+class API:
     """
     Collect configuration and URL map for building the CherryPy app
     """
