@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Allows you to manage assistive access on macOS minions with 10.9+
 =================================================================
 
@@ -10,13 +9,10 @@ Install, enable and disable assistive access on macOS minions
     /usr/bin/osacript:
       assistive.installed:
         - enabled: True
-'''
+"""
 
-# Import Python libs
-from __future__ import absolute_import, unicode_literals, print_function
 import logging
 
-# Import Salt libs
 import salt.utils.platform
 from salt.utils.versions import LooseVersion as _LooseVersion
 
@@ -26,17 +22,18 @@ __virtualname__ = "assistive"
 
 
 def __virtual__():
-    '''
+    """
     Only work on Mac OS
-    '''
-    if salt.utils.platform.is_darwin() \
-            and _LooseVersion(__grains__['osrelease']) >= _LooseVersion('10.9'):
+    """
+    if salt.utils.platform.is_darwin() and _LooseVersion(
+        __grains__["osrelease"]
+    ) >= _LooseVersion("10.9"):
         return True
-    return False
+    return (False, "Only supported on Mac OS 10.9+")
 
 
 def installed(name, enabled=True):
-    '''
+    """
     Make sure that we have the given bundle ID or path to command
     installed in the assistive access panel.
 
@@ -46,25 +43,22 @@ def installed(name, enabled=True):
     enable
         Should assistive access be enabled on this application?
 
-    '''
-    ret = {'name': name,
-           'result': True,
-           'comment': '',
-           'changes': {}}
+    """
+    ret = {"name": name, "result": True, "comment": "", "changes": {}}
 
-    is_installed = __salt__['assistive.installed'](name)
+    is_installed = __salt__["assistive.installed"](name)
 
     if is_installed:
-        is_enabled = __salt__['assistive.enabled'](name)
+        is_enabled = __salt__["assistive.enabled"](name)
 
         if enabled != is_enabled:
-            __salt__['assistive.enable'](name, enabled)
-            ret['comment'] = 'Updated enable to {0}'.format(enabled)
+            __salt__["assistive.enable"](name, enabled)
+            ret["comment"] = "Updated enable to {}".format(enabled)
         else:
-            ret['comment'] = 'Already in the correct state'
+            ret["comment"] = "Already in the correct state"
 
     else:
-        __salt__['assistive.install'](name, enabled)
-        ret['comment'] = 'Installed {0} into the assistive access panel'.format(name)
+        __salt__["assistive.install"](name, enabled)
+        ret["comment"] = "Installed {} into the assistive access panel".format(name)
 
     return ret
