@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 r"""
 Execution of Salt modules from within states
 ============================================
@@ -300,15 +299,12 @@ Windows system:
 
 .. _file_roots: https://docs.saltstack.com/en/latest/ref/configuration/master.html#file-roots
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import salt libs
 import salt.loader
 import salt.utils.args
 import salt.utils.functools
 import salt.utils.jid
 from salt.exceptions import SaltInvocationError
-from salt.ext import six
 from salt.ext.six.moves import range
 from salt.utils.decorators import with_deprecated
 
@@ -395,6 +391,11 @@ def run(**kwargs):
         elif __opts__["test"]:
             tests.append(func)
 
+    if not functions:
+        ret["comment"] = "No function provided."
+        ret["result"] = False
+        return ret
+
     if tests or missing:
         ret["comment"] = " ".join(
             [
@@ -412,40 +413,43 @@ def run(**kwargs):
                 or "",
             ]
         ).strip()
-        ret["result"] = not (missing or not tests)
 
-    if ret["result"] is None:
-        ret["result"] = True
+        if missing:
+            ret["result"] = False
 
-        failures = []
-        success = []
-        for func in functions:
-            _func = func.split(":")[0]
-            try:
-                func_ret = _call_function(
-                    _func, returner=kwargs.get("returner"), func_args=kwargs.get(func)
-                )
-                if not _get_result(func_ret, ret["changes"].get("ret", {})):
-                    if isinstance(func_ret, dict):
-                        failures.append(
-                            "'{0}' failed: {1}".format(
-                                func, func_ret.get("comment", "(error message N/A)")
-                            )
-                        )
-                else:
-                    success.append(
-                        "{0}: {1}".format(
-                            func,
-                            func_ret.get("comment", "Success")
-                            if isinstance(func_ret, dict)
-                            else func_ret,
+        return ret
+
+    failures = []
+    success = []
+    for func in functions:
+        _func = func.split(":")[0]
+        try:
+            func_ret = _call_function(
+                _func, returner=kwargs.get("returner"), func_args=kwargs.get(func)
+            )
+            if not _get_result(func_ret, ret["changes"].get("ret", {})):
+                if isinstance(func_ret, dict):
+                    failures.append(
+                        "'{}' failed: {}".format(
+                            func, func_ret.get("comment", "(error message N/A)")
                         )
                     )
-                    ret["changes"][func] = func_ret
-            except (SaltInvocationError, TypeError) as ex:
-                failures.append("'{0}' failed: {1}".format(func, ex))
-        ret["comment"] = ", ".join(failures + success)
-        ret["result"] = not bool(failures)
+                if func_ret is False:
+                    failures.append("'{}': {}".format(func, func_ret))
+            else:
+                success.append(
+                    "{}: {}".format(
+                        func,
+                        func_ret.get("comment", "Success")
+                        if isinstance(func_ret, dict)
+                        else func_ret,
+                    )
+                )
+                ret["changes"][func] = func_ret
+        except (SaltInvocationError, TypeError) as ex:
+            failures.append("'{}' failed: {}".format(func, ex))
+    ret["comment"] = ", ".join(failures + success)
+    ret["result"] = not bool(failures)
 
     return ret
 
@@ -499,12 +503,12 @@ def _run(name, **kwargs):
     """
     ret = {"name": name, "changes": {}, "comment": "", "result": None}
     if name not in __salt__:
-        ret["comment"] = "Module function {0} is not available".format(name)
+        ret["comment"] = "Module function {} is not available".format(name)
         ret["result"] = False
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "Module function {0} is set to execute".format(name)
+        ret["comment"] = "Module function {} is set to execute".format(name)
         return ret
 
     aspec = salt.utils.args.get_function_argspec(__salt__[name])
@@ -562,7 +566,7 @@ def _run(name, **kwargs):
     if missing:
         comment = "The following arguments are missing:"
         for arg in missing:
-            comment += " {0}".format(arg)
+            comment += " {}".format(arg)
         ret["comment"] = comment
         ret["result"] = False
         return ret
@@ -607,9 +611,9 @@ def _run(name, **kwargs):
         else:
             mret = __salt__[name](*args)
     except Exception as e:  # pylint: disable=broad-except
-        ret[
-            "comment"
-        ] = "Module function {0} threw an exception. Exception: {1}".format(name, e)
+        ret["comment"] = "Module function {} threw an exception. Exception: {}".format(
+            name, e
+        )
         ret["result"] = False
         return ret
     else:
@@ -626,7 +630,7 @@ def _run(name, **kwargs):
         returners = salt.loader.returners(__opts__, __salt__)
         if kwargs["returner"] in returners:
             returners[kwargs["returner"]](ret_ret)
-    ret["comment"] = "Module function {0} executed".format(name)
+    ret["comment"] = "Module function {} executed".format(name)
     ret["result"] = _get_result(mret, ret["changes"])
 
     return ret
@@ -658,7 +662,7 @@ def _get_result(func_ret, changes):
 
 def _get_dict_result(node):
     ret = True
-    for key, val in six.iteritems(node):
+    for key, val in node.items():
         if key == "result" and val is False:
             ret = False
             break
