@@ -1,29 +1,23 @@
-# -*- coding: utf-8 -*-
 """
 TCP transport classes
 
 Wire protocol: "len(payload) msgpack({'head': SOMEHEADER, 'body': SOMEBODY})"
 
 """
-
-# Import Python Libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import errno
 import logging
 import os
+import queue
 import socket
-import sys
 import threading
 import time
 import traceback
+import urllib.parse as urlparse
+import uuid
 import weakref
 
-# Import Salt Libs
 import salt.crypt
 import salt.exceptions
-
-# Import Tornado Libs
 import salt.ext.tornado
 import salt.ext.tornado.concurrent
 import salt.ext.tornado.gen
@@ -44,19 +38,10 @@ import salt.utils.msgpack
 import salt.utils.platform
 import salt.utils.process
 import salt.utils.verify
+import salt.utils.versions
 from salt.exceptions import SaltClientError, SaltReqTimeoutError
-from salt.ext import six
-from salt.ext.six.moves import queue  # pylint: disable=import-error
 from salt.transport import iter_transport_opts
 
-# pylint: disable=import-error,no-name-in-module
-if six.PY2:
-    import urlparse
-else:
-    import urllib.parse as urlparse
-# pylint: enable=import-error,no-name-in-module
-
-# Import third party libs
 try:
     from M2Crypto import RSA
 
@@ -66,9 +51,9 @@ except ImportError:
     try:
         from Cryptodome.Cipher import PKCS1_OAEP
     except ImportError:
-        from Crypto.Cipher import PKCS1_OAEP
+        from Crypto.Cipher import PKCS1_OAEP  # nosec
 
-if six.PY3 and salt.utils.platform.is_windows():
+if salt.utils.platform.is_windows():
     USE_LOAD_BALANCER = True
 else:
     USE_LOAD_BALANCER = False
@@ -160,7 +145,7 @@ if USE_LOAD_BALANCER:
         backlog = 128
 
         def __init__(self, opts, socket_queue, **kwargs):
-            super(LoadBalancerServer, self).__init__(**kwargs)
+            super().__init__(**kwargs)
             self.opts = opts
             self.socket_queue = socket_queue
             self._socket = None
@@ -217,7 +202,7 @@ if USE_LOAD_BALANCER:
                     # the connection into.
                     # Sockets are picklable on Windows in Python 3.
                     self.socket_queue.put((connection, address), True, None)
-                except socket.error as e:
+                except OSError as e:
                     # ECONNABORTED indicates that there was a connection
                     # but it was closed while still in the accept queue.
                     # (observed on FreeBSD).
@@ -290,6 +275,16 @@ class AsyncTCPReqChannel(salt.transport.client.ReqChannel):
             kwargs.get("crypt", "aes"),  # TODO: use the same channel for crypt
         )
 
+    @classmethod
+    def force_close_all_instances(cls):
+        """
+        Will force close all instances
+        :return: None
+        """
+        for weak_dict in list(cls.instance_map.values()):
+            for instance in list(weak_dict.values()):
+                instance.close()
+
     # has to remain empty for singletons, since __init__ will *always* be called
     def __init__(self, opts, **kwargs):
         pass
@@ -362,7 +357,7 @@ class AsyncTCPReqChannel(salt.transport.client.ReqChannel):
             self._refcount = 1
         try:
             self.close()
-        except socket.error as exc:
+        except OSError as exc:
             if exc.errno != errno.EBADF:
                 # If its not a bad file descriptor error, raise
                 raise
@@ -373,16 +368,21 @@ class AsyncTCPReqChannel(salt.transport.client.ReqChannel):
         return {
             "enc": self.crypt,
             "load": load,
+            "version": 2,
         }
 
     @salt.ext.tornado.gen.coroutine
     def crypted_transfer_decode_dictentry(
         self, load, dictkey=None, tries=3, timeout=60
     ):
+        nonce = uuid.uuid4().hex
+        load["nonce"] = nonce
         if not self.auth.authenticated:
             yield self.auth.authenticate()
         ret = yield self.message_client.send(
-            self._package_load(self.auth.crypticle.dumps(load)), timeout=timeout
+            self._package_load(self.auth.crypticle.dumps(load)),
+            timeout=timeout,
+            tries=tries,
         )
         key = self.auth.get_keys()
         if HAS_M2:
@@ -390,11 +390,29 @@ class AsyncTCPReqChannel(salt.transport.client.ReqChannel):
         else:
             cipher = PKCS1_OAEP.new(key)
             aes = cipher.decrypt(ret["key"])
+
+        # Decrypt using the public key.
         pcrypt = salt.crypt.Crypticle(self.opts, aes)
-        data = pcrypt.loads(ret[dictkey])
-        if six.PY3:
-            data = salt.transport.frame.decode_embedded_strs(data)
-        raise salt.ext.tornado.gen.Return(data)
+        signed_msg = pcrypt.loads(ret[dictkey])
+
+        # Validate the master's signature.
+        master_pubkey_path = os.path.join(self.opts["pki_dir"], "minion_master.pub")
+        if not salt.crypt.verify_signature(
+            master_pubkey_path, signed_msg["data"], signed_msg["sig"]
+        ):
+            raise salt.crypt.AuthenticationError(
+                "Pillar payload signature failed to validate."
+            )
+
+        # Make sure the signed key matches the key we used to decrypt the data.
+        data = salt.payload.Serial({}).loads(signed_msg["data"])
+        if data["key"] != ret["key"]:
+            raise salt.crypt.AuthenticationError("Key verification failed.")
+
+        # Validate the nonce.
+        if data["nonce"] != nonce:
+            raise salt.crypt.AuthenticationError("Pillar nonce verification failed.")
+        raise salt.ext.tornado.gen.Return(data["pillar"])
 
     @salt.ext.tornado.gen.coroutine
     def _crypted_transfer(self, load, tries=3, timeout=60):
@@ -404,20 +422,24 @@ class AsyncTCPReqChannel(salt.transport.client.ReqChannel):
         Indeed, we can fail too early in case of a master restart during a
         minion state execution call
         """
+        nonce = uuid.uuid4().hex
+        if load and isinstance(load, dict):
+            load["nonce"] = nonce
 
         @salt.ext.tornado.gen.coroutine
         def _do_transfer():
             data = yield self.message_client.send(
-                self._package_load(self.auth.crypticle.dumps(load)), timeout=timeout,
+                self._package_load(self.auth.crypticle.dumps(load)),
+                timeout=timeout,
+                tries=tries,
             )
             # we may not have always data
             # as for example for saltcall ret submission, this is a blind
             # communication, we do not subscribe to return events, we just
             # upload the results to the master
             if data:
-                data = self.auth.crypticle.loads(data)
-                if six.PY3:
-                    data = salt.transport.frame.decode_embedded_strs(data)
+                data = self.auth.crypticle.loads(data, nonce=nonce)
+                data = salt.transport.frame.decode_embedded_strs(data)
             raise salt.ext.tornado.gen.Return(data)
 
         if not self.auth.authenticated:
@@ -432,7 +454,10 @@ class AsyncTCPReqChannel(salt.transport.client.ReqChannel):
 
     @salt.ext.tornado.gen.coroutine
     def _uncrypted_transfer(self, load, tries=3, timeout=60):
-        ret = yield self.message_client.send(self._package_load(load), timeout=timeout)
+        ret = yield self.message_client.send(
+            self._package_load(load), timeout=timeout, tries=tries,
+        )
+
         raise salt.ext.tornado.gen.Return(ret)
 
     @salt.ext.tornado.gen.coroutine
@@ -474,14 +499,19 @@ class AsyncTCPPubChannel(
         self.connected = False
         self._closing = False
         self._reconnected = False
+        self.message_client = None
         self.event = salt.utils.event.get_event("minion", opts=self.opts, listen=False)
 
     def close(self):
         if self._closing:
             return
         self._closing = True
-        if hasattr(self, "message_client"):
+        if self.message_client is not None:
             self.message_client.close()
+            self.message_client = None
+        if self.event is not None:
+            self.event.destroy()
+            self.event = None
 
     # pylint: disable=W1701
     def __del__(self):
@@ -493,6 +523,7 @@ class AsyncTCPPubChannel(
         return {
             "enc": self.crypt,
             "load": load,
+            "version": 2,
         }
 
     @salt.ext.tornado.gen.coroutine
@@ -545,14 +576,10 @@ class AsyncTCPPubChannel(
             # On reconnects, fire a master event to notify that the minion is
             # available.
             if self.opts.get("__role") == "syndic":
-                data = "Syndic {0} started at {1}".format(
-                    self.opts["id"], time.asctime()
-                )
+                data = "Syndic {} started at {}".format(self.opts["id"], time.asctime())
                 tag = salt.utils.event.tagify([self.opts["id"], "start"], "syndic")
             else:
-                data = "Minion {0} started at {1}".format(
-                    self.opts["id"], time.asctime()
-                )
+                data = "Minion {} started at {}".format(self.opts["id"], time.asctime())
                 tag = salt.utils.event.tagify([self.opts["id"], "start"], "minion")
             load = {
                 "id": self.opts["id"],
@@ -602,7 +629,7 @@ class AsyncTCPPubChannel(
 
                 self.message_client = SaltMessageClientPool(
                     self.opts,
-                    args=(self.opts, self.opts["master_ip"], int(self.publish_port),),
+                    args=(self.opts, self.opts["master_ip"], int(self.publish_port)),
                     kwargs={
                         "io_loop": self.io_loop,
                         "connect_callback": self.connect_callback,
@@ -617,9 +644,9 @@ class AsyncTCPPubChannel(
         except KeyboardInterrupt:  # pylint: disable=try-except-raise
             raise
         except Exception as exc:  # pylint: disable=broad-except
-            if "-|RETRY|-" not in six.text_type(exc):
+            if "-|RETRY|-" not in str(exc):
                 raise SaltClientError(
-                    "Unable to sign_in to master: {0}".format(exc)
+                    "Unable to sign_in to master: {}".format(exc)
                 )  # TODO: better error message
 
     def on_recv(self, callback):
@@ -635,8 +662,7 @@ class AsyncTCPPubChannel(
                 # TODO: For some reason we need to decode here for things
                 #       to work. Fix this.
                 body = salt.utils.msgpack.loads(body)
-                if six.PY3:
-                    body = salt.transport.frame.decode_embedded_strs(body)
+                body = salt.transport.frame.decode_embedded_strs(body)
             ret = yield self._decode_payload(body)
             callback(ret)
 
@@ -652,6 +678,7 @@ class TCPReqServerChannel(
     def __init__(self, opts):
         salt.transport.server.ReqServerChannel.__init__(self, opts)
         self._socket = None
+        self.req_server = None
 
     @property
     def socket(self):
@@ -661,31 +688,31 @@ class TCPReqServerChannel(
         if self._socket is not None:
             try:
                 self._socket.shutdown(socket.SHUT_RDWR)
-            except socket.error as exc:
+            except OSError as exc:
                 if exc.errno == errno.ENOTCONN:
                     # We may try to shutdown a socket which is already disconnected.
                     # Ignore this condition and continue.
                     pass
                 else:
-                    six.reraise(*sys.exc_info())
-            self._socket.close()
+                    raise
+            if self.req_server is None:
+                # We only close the socket if we don't have a req_server instance.
+                # If we did, because the req_server is also handling this socket, when we call
+                # req_server.stop(), tornado will give us an AssertionError because it's trying to
+                # match the socket.fileno() (after close it's -1) to the fd it holds on it's _sockets cache
+                # so it can remove the socket from the IOLoop handlers
+                self._socket.close()
             self._socket = None
-        if hasattr(self.req_server, "shutdown"):
+        if self.req_server is not None:
             try:
-                self.req_server.shutdown()
-            except Exception as exc:  # pylint: disable=broad-except
-                log.exception(
-                    "TCPReqServerChannel close generated an exception: %s", str(exc)
-                )
-        elif hasattr(self.req_server, "stop"):
-            try:
-                self.req_server.stop()
-            except socket.error as exc:
+                self.req_server.close()
+            except OSError as exc:
                 if exc.errno != 9:
                     raise
                 log.exception(
                     "TCPReqServerChannel close generated an exception: %s", str(exc)
                 )
+            self.req_server = None
 
     # pylint: disable=W1701
     def __del__(self):
@@ -693,6 +720,12 @@ class TCPReqServerChannel(
 
     # pylint: enable=W1701
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.close()
+
     def pre_fork(self, process_manager):
         """
         Pre-fork we need to create the zmq router device
@@ -779,17 +812,25 @@ class TCPReqServerChannel(
 
             try:
                 id_ = payload["load"].get("id", "")
-                if str("\0") in id_:
+                if "\0" in id_:
                     log.error("Payload contains an id with a null byte: %s", payload)
                     stream.send(self.serial.dumps("bad load: id contains a null byte"))
                     raise salt.ext.tornado.gen.Return()
             except TypeError:
                 log.error("Payload contains non-string id: %s", payload)
                 stream.send(
-                    self.serial.dumps("bad load: id {0} is not a string".format(id_))
+                    self.serial.dumps("bad load: id {} is not a string".format(id_))
                 )
                 raise salt.ext.tornado.gen.Return()
 
+            version = 0
+            if "version" in payload:
+                version = payload["version"]
+
+            sign_messages = False
+            if version > 1:
+                sign_messages = True
+
             # intercept the "_auth" commands, since the main daemon shouldn't know
             # anything about our key auth
             if (
@@ -798,11 +839,15 @@ class TCPReqServerChannel(
             ):
                 yield stream.write(
                     salt.transport.frame.frame_msg(
-                        self._auth(payload["load"]), header=header
+                        self._auth(payload["load"], sign_messages), header=header
                     )
                 )
                 raise salt.ext.tornado.gen.Return()
 
+            nonce = None
+            if version > 1:
+                nonce = payload["load"].pop("nonce", None)
+
             # TODO: test
             try:
                 ret, req_opts = yield self.payload_handler(payload)
@@ -821,13 +866,15 @@ class TCPReqServerChannel(
             elif req_fun == "send":
                 stream.write(
                     salt.transport.frame.frame_msg(
-                        self.crypticle.dumps(ret), header=header
+                        self.crypticle.dumps(ret, nonce), header=header
                     )
                 )
             elif req_fun == "send_private":
                 stream.write(
                     salt.transport.frame.frame_msg(
-                        self._encrypt_private(ret, req_opts["key"], req_opts["tgt"],),
+                        self._encrypt_private(
+                            ret, req_opts["key"], req_opts["tgt"], nonce, sign_messages,
+                        ),
                         header=header,
                     )
                 )
@@ -850,7 +897,7 @@ class TCPReqServerChannel(
         raise salt.ext.tornado.gen.Return()
 
 
-class SaltMessageServer(salt.ext.tornado.tcpserver.TCPServer, object):
+class SaltMessageServer(salt.ext.tornado.tcpserver.TCPServer):
     """
     Raw TCP server which will receive all of the TCP streams and re-assemble
     messages that are sent through to us
@@ -860,11 +907,11 @@ class SaltMessageServer(salt.ext.tornado.tcpserver.TCPServer, object):
         io_loop = (
             kwargs.pop("io_loop", None) or salt.ext.tornado.ioloop.IOLoop.current()
         )
-        super(SaltMessageServer, self).__init__(*args, **kwargs)
+        self._closing = False
+        super().__init__(*args, **kwargs)
         self.io_loop = io_loop
         self.clients = []
         self.message_handler = message_handler
-        self._shutting_down = False
 
     @salt.ext.tornado.gen.coroutine
     def handle_stream(self, stream, address):
@@ -879,15 +926,11 @@ class SaltMessageServer(salt.ext.tornado.tcpserver.TCPServer, object):
                 wire_bytes = yield stream.read_bytes(4096, partial=True)
                 unpacker.feed(wire_bytes)
                 for framed_msg in unpacker:
-                    if six.PY3:
-                        framed_msg = salt.transport.frame.decode_embedded_strs(
-                            framed_msg
-                        )
+                    framed_msg = salt.transport.frame.decode_embedded_strs(framed_msg)
                     header = framed_msg["head"]
                     self.io_loop.spawn_callback(
                         self.message_handler, stream, header, framed_msg["body"]
                     )
-
         except salt.ext.tornado.iostream.StreamClosedError:
             log.trace("req client disconnected %s", address)
             self.remove_client((stream, address))
@@ -906,16 +949,28 @@ class SaltMessageServer(salt.ext.tornado.tcpserver.TCPServer, object):
         """
         Shutdown the whole server
         """
-        if self._shutting_down:
+        salt.utils.versions.warn_until(
+            "Phosphorus",
+            "Please stop calling {0}.{1}.shutdown() and instead call {0}.{1}.close()".format(
+                __name__, self.__class__.__name__
+            ),
+        )
+        self.close()
+
+    def close(self):
+        """
+        Close the server
+        """
+        if self._closing:
             return
-        self._shutting_down = True
+        self._closing = True
         for item in self.clients:
             client, address = item
             client.close()
             self.remove_client(item)
         try:
             self.stop()
-        except socket.error as exc:
+        except OSError as exc:
             if exc.errno != 9:
                 raise
 
@@ -931,15 +986,25 @@ if USE_LOAD_BALANCER:
         """
 
         def __init__(self, socket_queue, message_handler, *args, **kwargs):
-            super(LoadBalancerWorker, self).__init__(message_handler, *args, **kwargs)
+            super().__init__(message_handler, *args, **kwargs)
             self.socket_queue = socket_queue
             self._stop = threading.Event()
             self.thread = threading.Thread(target=self.socket_queue_thread)
             self.thread.start()
 
         def stop(self):
+            salt.utils.versions.warn_until(
+                "Phosphorus",
+                "Please stop calling {0}.{1}.stop() and instead call {0}.{1}.close()".format(
+                    __name__, self.__class__.__name__
+                ),
+            )
+            self.close()
+
+        def close(self):
             self._stop.set()
             self.thread.join()
+            super().close()
 
         def socket_queue_thread(self):
             try:
@@ -967,7 +1032,7 @@ class TCPClientKeepAlive(salt.ext.tornado.tcpclient.TCPClient):
 
     def __init__(self, opts, resolver=None):
         self.opts = opts
-        super(TCPClientKeepAlive, self).__init__(resolver=resolver)
+        super().__init__(resolver=resolver)
 
     def _create_stream(
         self, max_buffer_size, af, addr, **kwargs
@@ -997,9 +1062,13 @@ class SaltMessageClientPool(salt.transport.MessageClientPool):
     """
 
     def __init__(self, opts, args=None, kwargs=None):
-        super(SaltMessageClientPool, self).__init__(
-            SaltMessageClient, opts, args=args, kwargs=kwargs
-        )
+        super().__init__(SaltMessageClient, opts, args=args, kwargs=kwargs)
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.close()
 
     # pylint: disable=W1701
     def __del__(self):
@@ -1017,8 +1086,7 @@ class SaltMessageClientPool(salt.transport.MessageClientPool):
         futures = []
         for message_client in self.message_clients:
             futures.append(message_client.connect())
-        for future in futures:
-            yield future
+        yield futures
         raise salt.ext.tornado.gen.Return(None)
 
     def on_recv(self, *args, **kwargs):
@@ -1037,7 +1105,7 @@ class SaltMessageClientPool(salt.transport.MessageClientPool):
 # TODO consolidate with IPCClient
 # TODO: limit in-flight messages.
 # TODO: singleton? Something to not re-create the tcp connection so much
-class SaltMessageClient(object):
+class SaltMessageClient:
     """
     Low-level message sending client
     """
@@ -1082,6 +1150,8 @@ class SaltMessageClient(object):
         self._stream_return_future = salt.ext.tornado.concurrent.Future()
         self.io_loop.spawn_callback(self._stream_return)
 
+        self.backoff = opts.get("tcp_reconnect_backoff", 1)
+
     def _stop_io_loop(self):
         if self.io_loop is not None:
             self.io_loop.stop()
@@ -1160,7 +1230,6 @@ class SaltMessageClient(object):
 
         return future
 
-    # TODO: tcp backoff opts
     @salt.ext.tornado.gen.coroutine
     def _connect(self):
         """
@@ -1191,9 +1260,15 @@ class SaltMessageClient(object):
                 self._connecting_future.set_result(True)
                 break
             except Exception as exc:  # pylint: disable=broad-except
-                log.warning("TCP Message Client encountered an exception %r", exc)
-                yield salt.ext.tornado.gen.sleep(1)  # TODO: backoff
-                # self._connecting_future.set_exception(e)
+                log.warning(
+                    "TCP Message Client encountered an exception while connecting to %s:%s: %r, will reconnect in %d seconds",
+                    self.host,
+                    self.port,
+                    exc,
+                    self.backoff,
+                )
+                yield salt.ext.tornado.gen.sleep(self.backoff)
+                # self._connecting_future.set_exception(exc)
 
     @salt.ext.tornado.gen.coroutine
     def _stream_return(self):
@@ -1212,10 +1287,9 @@ class SaltMessageClient(object):
                     wire_bytes = yield self._read_until_future
                     unpacker.feed(wire_bytes)
                     for framed_msg in unpacker:
-                        if six.PY3:
-                            framed_msg = salt.transport.frame.decode_embedded_strs(
-                                framed_msg
-                            )
+                        framed_msg = salt.transport.frame.decode_embedded_strs(
+                            framed_msg
+                        )
                         header = framed_msg["head"]
                         body = framed_msg["body"]
                         message_id = header.get("mid")
@@ -1237,7 +1311,7 @@ class SaltMessageClient(object):
                         self.host,
                         self.port,
                     )
-                    for future in six.itervalues(self.send_future_map):
+                    for future in self.send_future_map.values():
                         future.set_exception(e)
                     self.send_future_map = {}
                     if self._closing:
@@ -1259,7 +1333,7 @@ class SaltMessageClient(object):
                         raise SaltClientError
                 except Exception as e:  # pylint: disable=broad-except
                     log.error("Exception parsing response", exc_info=True)
-                    for future in six.itervalues(self.send_future_map):
+                    for future in self.send_future_map.values():
                         future.set_exception(e)
                     self.send_future_map = {}
                     if self._closing:
@@ -1335,22 +1409,42 @@ class SaltMessageClient(object):
         timeout = self.send_timeout_map.pop(message_id)
         self.io_loop.remove_timeout(timeout)
 
-    def timeout_message(self, message_id):
+    def timeout_message(self, message_id, msg):
         if message_id in self.send_timeout_map:
             del self.send_timeout_map[message_id]
         if message_id in self.send_future_map:
-            self.send_future_map.pop(message_id).set_exception(
-                SaltReqTimeoutError("Message timed out")
-            )
+            future = self.send_future_map.pop(message_id)
+            # In a race condition the message might have been sent by the time
+            # we're timing it out. Make sure the future is not None
+            if future is not None:
+                if future.attempts < future.tries:
+                    future.attempts += 1
 
-    def send(self, msg, timeout=None, callback=None, raw=False):
+                    log.debug(
+                        "SaltReqTimeoutError, retrying. (%s/%s)",
+                        future.attempts,
+                        future.tries,
+                    )
+                    self.send(
+                        msg, timeout=future.timeout, tries=future.tries, future=future,
+                    )
+
+                else:
+                    future.set_exception(SaltReqTimeoutError("Message timed out"))
+
+    def send(self, msg, timeout=None, callback=None, raw=False, future=None, tries=3):
         """
         Send given message, and return a future
         """
         message_id = self._message_id()
         header = {"mid": message_id}
 
-        future = salt.ext.tornado.concurrent.Future()
+        if future is None:
+            future = salt.ext.tornado.concurrent.Future()
+            future.tries = tries
+            future.attempts = 0
+            future.timeout = timeout
+
         if callback is not None:
 
             def handle_future(future):
@@ -1366,7 +1460,7 @@ class SaltMessageClient(object):
 
         if timeout is not None:
             send_timeout = self.io_loop.call_later(
-                timeout, self.timeout_message, message_id
+                timeout, self.timeout_message, message_id, msg
             )
             self.send_timeout_map[message_id] = send_timeout
 
@@ -1379,7 +1473,7 @@ class SaltMessageClient(object):
         return future
 
 
-class Subscriber(object):
+class Subscriber:
     """
     Client object for use with the TCP publisher server
     """
@@ -1413,19 +1507,20 @@ class Subscriber(object):
     # pylint: enable=W1701
 
 
-class PubServer(salt.ext.tornado.tcpserver.TCPServer, object):
+class PubServer(salt.ext.tornado.tcpserver.TCPServer):
     """
     TCP publisher
     """
 
-    def __init__(self, opts, io_loop=None):
-        super(PubServer, self).__init__(ssl_options=opts.get("ssl"))
+    def __init__(self, opts, io_loop=None, pack_publish=lambda _: _):
+        super().__init__(ssl_options=opts.get("ssl"))
         self.io_loop = io_loop
         self.opts = opts
         self._closing = False
         self.clients = set()
         self.aes_funcs = salt.master.AESFuncs(self.opts)
         self.present = {}
+        self.event = None
         self.presence_events = False
         if self.opts.get("presence_events", False):
             tcp_only = True
@@ -1442,11 +1537,23 @@ class PubServer(salt.ext.tornado.tcpserver.TCPServer, object):
             self.event = salt.utils.event.get_event(
                 "master", opts=self.opts, listen=False
             )
+        else:
+            self.event = None
+        self._pack_publish = pack_publish
+
+    def pack_publish(self, package):
+        return self._pack_publish(package)
 
     def close(self):
         if self._closing:
             return
         self._closing = True
+        if self.event is not None:
+            self.event.destroy()
+            self.event = None
+        if self.aes_funcs is not None:
+            self.aes_funcs.destroy()
+            self.aes_funcs = None
 
     # pylint: disable=W1701
     def __del__(self):
@@ -1508,10 +1615,7 @@ class PubServer(salt.ext.tornado.tcpserver.TCPServer, object):
                 wire_bytes = yield client._read_until_future
                 unpacker.feed(wire_bytes)
                 for framed_msg in unpacker:
-                    if six.PY3:
-                        framed_msg = salt.transport.frame.decode_embedded_strs(
-                            framed_msg
-                        )
+                    framed_msg = salt.transport.frame.decode_embedded_strs(framed_msg)
                     body = framed_msg["body"]
                     if body["enc"] != "aes":
                         # We only accept 'aes' encoded messages for 'id'
@@ -1520,8 +1624,7 @@ class PubServer(salt.ext.tornado.tcpserver.TCPServer, object):
                         self.opts, salt.master.SMaster.secrets["aes"]["secret"].value
                     )
                     load = crypticle.loads(body["load"])
-                    if six.PY3:
-                        load = salt.transport.frame.decode_embedded_strs(load)
+                    load = salt.transport.frame.decode_embedded_strs(load)
                     if not self.aes_funcs.verify_minion(load["id"], load["tok"]):
                         continue
                     client.id_ = load["id"]
@@ -1547,6 +1650,7 @@ class PubServer(salt.ext.tornado.tcpserver.TCPServer, object):
     # TODO: ACK the publish through IPC
     @salt.ext.tornado.gen.coroutine
     def publish_payload(self, package, _):
+        package = self.pack_publish(package)
         log.debug("TCP PubServer sending payload: %s", package)
         payload = salt.transport.frame.frame_msg(package["payload"])
 
@@ -1624,7 +1728,9 @@ class TCPPubServerChannel(salt.transport.server.PubServerChannel):
             self.io_loop = salt.ext.tornado.ioloop.IOLoop.current()
 
         # Spin up the publisher
-        pub_server = PubServer(self.opts, io_loop=self.io_loop)
+        pub_server = PubServer(
+            self.opts, io_loop=self.io_loop, pack_publish=self.pack_publish
+        )
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
         _set_tcp_keepalive(sock, self.opts)
@@ -1654,6 +1760,8 @@ class TCPPubServerChannel(salt.transport.server.PubServerChannel):
             self.io_loop.start()
         except (KeyboardInterrupt, SystemExit):
             salt.log.setup.shutdown_multiprocessing_logging()
+        finally:
+            pull_sock.close()
 
     def pre_fork(self, process_manager, kwargs=None):
         """
@@ -1663,12 +1771,12 @@ class TCPPubServerChannel(salt.transport.server.PubServerChannel):
         """
         process_manager.add_process(self._publish_daemon, kwargs=kwargs)
 
-    def publish(self, load):
+    def pack_publish(self, load):
         """
         Publish "load" to minions
         """
         payload = {"enc": "aes"}
-
+        load["serial"] = salt.master.SMaster.get_serial()
         crypticle = salt.crypt.Crypticle(
             self.opts, salt.master.SMaster.secrets["aes"]["secret"].value
         )
@@ -1677,23 +1785,11 @@ class TCPPubServerChannel(salt.transport.server.PubServerChannel):
             master_pem_path = os.path.join(self.opts["pki_dir"], "master.pem")
             log.debug("Signing data packet")
             payload["sig"] = salt.crypt.sign_message(master_pem_path, payload["load"])
-        # Use the Salt IPC server
-        if self.opts.get("ipc_mode", "") == "tcp":
-            pull_uri = int(self.opts.get("tcp_master_publish_pull", 4514))
-        else:
-            pull_uri = os.path.join(self.opts["sock_dir"], "publish_pull.ipc")
-        # TODO: switch to the actual asynchronous interface
-        # pub_sock = salt.transport.ipc.IPCMessageClient(self.opts, io_loop=self.io_loop)
-        pub_sock = salt.utils.asynchronous.SyncWrapper(
-            salt.transport.ipc.IPCMessageClient, (pull_uri,), loop_kwarg="io_loop",
-        )
-        pub_sock.connect()
-
         int_payload = {"payload": self.serial.dumps(payload)}
 
         # add some targeting stuff for lists only (for now)
         if load["tgt_type"] == "list" and not self.opts.get("order_masters", False):
-            if isinstance(load["tgt"], six.string_types):
+            if isinstance(load["tgt"], str):
                 # Fetch a list of minions that match
                 _res = self.ckminions.check_minions(
                     load["tgt"], tgt_type=load["tgt_type"]
@@ -1705,5 +1801,22 @@ class TCPPubServerChannel(salt.transport.server.PubServerChannel):
                 int_payload["topic_lst"] = match_ids
             else:
                 int_payload["topic_lst"] = load["tgt"]
+        return int_payload
+
+    def publish(self, load):
+        """
+        Publish "load" to minions
+        """
+        # Use the Salt IPC server
+        if self.opts.get("ipc_mode", "") == "tcp":
+            pull_uri = int(self.opts.get("tcp_master_publish_pull", 4514))
+        else:
+            pull_uri = os.path.join(self.opts["sock_dir"], "publish_pull.ipc")
+        # TODO: switch to the actual asynchronous interface
+        # pub_sock = salt.transport.ipc.IPCMessageClient(self.opts, io_loop=self.io_loop)
+        pub_sock = salt.utils.asynchronous.SyncWrapper(
+            salt.transport.ipc.IPCMessageClient, (pull_uri,), loop_kwarg="io_loop",
+        )
+        pub_sock.connect()
         # Send it over IPC!
-        pub_sock.send(int_payload)
+        pub_sock.send(load)
