@@ -1,28 +1,20 @@
-# -*- coding: utf-8 -*-
 """
 Zeromq transport classes
 """
-
-# Import Python Libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import copy
 import errno
 import hashlib
 import logging
 import os
 import signal
-import socket
 import sys
 import threading
+import uuid
 import weakref
 from random import randint
 
-# Import Salt Libs
 import salt.auth
 import salt.crypt
-
-# Import Tornado Libs
 import salt.ext.tornado
 import salt.ext.tornado.concurrent
 import salt.ext.tornado.gen
@@ -45,7 +37,6 @@ import zmq.eventloop.ioloop
 import zmq.eventloop.zmqstream
 from salt._compat import ipaddress
 from salt.exceptions import SaltException, SaltReqTimeoutError
-from salt.ext import six
 from salt.utils.zeromq import (
     LIBZMQ_VERSION_INFO,
     ZMQ_VERSION_INFO,
@@ -62,7 +53,6 @@ except ImportError:
     HAS_ZMQ_MONITOR = False
 
 
-# Import third party libs
 try:
     from M2Crypto import RSA
 
@@ -72,7 +62,8 @@ except ImportError:
     try:
         from Cryptodome.Cipher import PKCS1_OAEP
     except ImportError:
-        from Crypto.Cipher import PKCS1_OAEP
+        from Crypto.Cipher import PKCS1_OAEP  # nosec
+
 
 log = logging.getLogger(__name__)
 
@@ -85,12 +76,12 @@ def _get_master_uri(master_ip, master_port, source_ip=None, source_port=None):
     rc = zmq_connect(socket, "tcp://192.168.1.17:5555;192.168.1.1:5555"); assert (rc == 0);
     Source: http://api.zeromq.org/4-1:zmq-tcp
     """
+
     from salt.utils.zeromq import ip_bracket
 
     master_uri = "tcp://{master_ip}:{master_port}".format(
         master_ip=ip_bracket(master_ip), master_port=master_port
     )
-
     if source_ip or source_port:
         if LIBZMQ_VERSION_INFO >= (4, 1, 6) and ZMQ_VERSION_INFO >= (16, 0, 1):
             # The source:port syntax for ZeroMQ has been added in libzmq 4.1.6
@@ -221,6 +212,20 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
             setattr(result, key, copy.deepcopy(self.__dict__[key], memo))
         return result
 
+    @classmethod
+    def force_close_all_instances(cls):
+        """
+        Will force close all instances
+
+        ZMQ can hang on quit if left to deconstruct on its own.
+        This because is deconstructs out of order.
+
+        :return: None
+        """
+        for weak_dict in list(cls.instance_map.values()):
+            for instance in list(weak_dict.values()):
+                instance.close()
+
     @classmethod
     def __key(cls, opts, **kwargs):
         return (
@@ -306,7 +311,7 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
             self._refcount = 1
         try:
             self.close()
-        except socket.error as exc:
+        except OSError as exc:
             if exc.errno != errno.EBADF:
                 # If its not a bad file descriptor error, raise
                 raise
@@ -334,22 +339,27 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
         return {
             "enc": self.crypt,
             "load": load,
+            "version": 2,
         }
 
     @salt.ext.tornado.gen.coroutine
     def crypted_transfer_decode_dictentry(
         self, load, dictkey=None, tries=3, timeout=60
     ):
+        nonce = uuid.uuid4().hex
+        load["nonce"] = nonce
         if not self.auth.authenticated:
             # Return control back to the caller, continue when authentication succeeds
             yield self.auth.authenticate()
-        # Return control to the caller. When send() completes, resume by populating ret with the Future.result
+
+        # Return control to the caller. When send() completes, resume by
+        # populating ret with the Future.result
         ret = yield self.message_client.send(
             self._package_load(self.auth.crypticle.dumps(load)),
             timeout=timeout,
             tries=tries,
         )
-        key = self.auth.get_keys()
+
         if "key" not in ret:
             # Reauth in the case our key is deleted on the master side.
             yield self.auth.authenticate()
@@ -358,16 +368,36 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
                 timeout=timeout,
                 tries=tries,
             )
+
+        key = self.auth.get_keys()
         if HAS_M2:
             aes = key.private_decrypt(ret["key"], RSA.pkcs1_oaep_padding)
         else:
             cipher = PKCS1_OAEP.new(key)
             aes = cipher.decrypt(ret["key"])
+
+        # Decrypt using the public key.
         pcrypt = salt.crypt.Crypticle(self.opts, aes)
-        data = pcrypt.loads(ret[dictkey])
-        if six.PY3:
-            data = salt.transport.frame.decode_embedded_strs(data)
-        raise salt.ext.tornado.gen.Return(data)
+        signed_msg = pcrypt.loads(ret[dictkey])
+
+        # Validate the master's signature.
+        master_pubkey_path = os.path.join(self.opts["pki_dir"], "minion_master.pub")
+        if not salt.crypt.verify_signature(
+            master_pubkey_path, signed_msg["data"], signed_msg["sig"]
+        ):
+            raise salt.crypt.AuthenticationError(
+                "Pillar payload signature failed to validate."
+            )
+
+        # Make sure the signed key matches the key we used to decrypt the data.
+        data = salt.payload.Serial({}).loads(signed_msg["data"])
+        if data["key"] != ret["key"]:
+            raise salt.crypt.AuthenticationError("Key verification failed.")
+
+        # Validate the nonce.
+        if data["nonce"] != nonce:
+            raise salt.crypt.AuthenticationError("Pillar nonce verification failed.")
+        raise salt.ext.tornado.gen.Return(data["pillar"])
 
     @salt.ext.tornado.gen.coroutine
     def _crypted_transfer(self, load, tries=3, timeout=60, raw=False):
@@ -384,6 +414,9 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
         :param int tries: The number of times to make before failure
         :param int timeout: The number of seconds on a response before failing
         """
+        nonce = uuid.uuid4().hex
+        if load and isinstance(load, dict):
+            load["nonce"] = nonce
 
         @salt.ext.tornado.gen.coroutine
         def _do_transfer():
@@ -398,8 +431,8 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
             # communication, we do not subscribe to return events, we just
             # upload the results to the master
             if data:
-                data = self.auth.crypticle.loads(data, raw)
-            if six.PY3 and not raw:
+                data = self.auth.crypticle.loads(data, raw, nonce)
+            if not raw:
                 data = salt.transport.frame.decode_embedded_strs(data)
             raise salt.ext.tornado.gen.Return(data)
 
@@ -464,6 +497,7 @@ class AsyncZeroMQPubChannel(
         self.opts = opts
         self.ttype = "zeromq"
         self.io_loop = kwargs.get("io_loop")
+        self._closing = False
 
         if self.io_loop is None:
             install_zmq()
@@ -543,16 +577,16 @@ class AsyncZeroMQPubChannel(
             self._monitor.start_io_loop(self.io_loop)
 
     def close(self):
+        if self._closing is True:
+            return
+
+        self._closing = True
+
         if hasattr(self, "_monitor") and self._monitor is not None:
             self._monitor.stop()
             self._monitor = None
         if hasattr(self, "_stream"):
-            if ZMQ_VERSION_INFO < (14, 3, 0):
-                # stream.close() doesn't work properly on pyzmq < 14.3.0
-                self._stream.io_loop.remove_handler(self._stream.socket)
-                self._stream.socket.close(0)
-            else:
-                self._stream.close(0)
+            self._stream.close(0)
         elif hasattr(self, "_socket"):
             self._socket.close(0)
         if hasattr(self, "context") and self.context.closed is False:
@@ -563,6 +597,11 @@ class AsyncZeroMQPubChannel(
         self.close()
 
     # pylint: enable=W1701
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.close()
 
     # TODO: this is the time to see if we are connected, maybe use the req channel to guess?
     @salt.ext.tornado.gen.coroutine
@@ -622,7 +661,7 @@ class AsyncZeroMQPubChannel(
         else:
             raise Exception(
                 (
-                    "Invalid number of messages ({0}) in zeromq pub"
+                    "Invalid number of messages ({}) in zeromq pub"
                     "message from master"
                 ).format(len(messages_len))
             )
@@ -666,6 +705,8 @@ class ZeroMQReqServerChannel(
     def __init__(self, opts):
         salt.transport.server.ReqServerChannel.__init__(self, opts)
         self._closing = False
+        self._monitor = None
+        self._w_monitor = None
 
     def zmq_device(self):
         """
@@ -692,11 +733,11 @@ class ZeroMQReqServerChannel(
             os.nice(self.opts["mworker_queue_niceness"])
 
         if self.opts.get("ipc_mode", "") == "tcp":
-            self.w_uri = "tcp://127.0.0.1:{0}".format(
+            self.w_uri = "tcp://127.0.0.1:{}".format(
                 self.opts.get("tcp_master_workers", 4515)
             )
         else:
-            self.w_uri = "ipc://{0}".format(
+            self.w_uri = "ipc://{}".format(
                 os.path.join(self.opts["sock_dir"], "workers.ipc")
             )
 
@@ -712,7 +753,7 @@ class ZeroMQReqServerChannel(
             except zmq.ZMQError as exc:
                 if exc.errno == errno.EINTR:
                     continue
-                six.reraise(*sys.exc_info())
+                raise
             except (KeyboardInterrupt, SystemExit):
                 break
 
@@ -724,7 +765,6 @@ class ZeroMQReqServerChannel(
             return
         log.info("MWorkerQueue under PID %s is closing", os.getpid())
         self._closing = True
-        # pylint: disable=E0203
         if getattr(self, "_monitor", None) is not None:
             self._monitor.stop()
             self._monitor = None
@@ -741,7 +781,6 @@ class ZeroMQReqServerChannel(
             self._socket.close()
         if hasattr(self, "context") and self.context.closed is False:
             self.context.term()
-        # pylint: enable=E0203
 
     def pre_fork(self, process_manager):
         """
@@ -785,11 +824,11 @@ class ZeroMQReqServerChannel(
         self._start_zmq_monitor()
 
         if self.opts.get("ipc_mode", "") == "tcp":
-            self.w_uri = "tcp://127.0.0.1:{0}".format(
+            self.w_uri = "tcp://127.0.0.1:{}".format(
                 self.opts.get("tcp_master_workers", 4515)
             )
         else:
-            self.w_uri = "ipc://{0}".format(
+            self.w_uri = "ipc://{}".format(
                 os.path.join(self.opts["sock_dir"], "workers.ipc")
             )
         log.info("Worker binding to socket %s", self.w_uri)
@@ -843,23 +882,35 @@ class ZeroMQReqServerChannel(
 
         try:
             id_ = payload["load"].get("id", "")
-            if str("\0") in id_:
+            if "\0" in id_:
                 log.error("Payload contains an id with a null byte: %s", payload)
                 stream.send(self.serial.dumps("bad load: id contains a null byte"))
                 raise salt.ext.tornado.gen.Return()
         except TypeError:
             log.error("Payload contains non-string id: %s", payload)
             stream.send(
-                self.serial.dumps("bad load: id {0} is not a string".format(id_))
+                self.serial.dumps("bad load: id {} is not a string".format(id_))
             )
             raise salt.ext.tornado.gen.Return()
 
+        version = 0
+        if "version" in payload:
+            version = payload["version"]
+
+        sign_messages = False
+        if version > 1:
+            sign_messages = True
+
         # intercept the "_auth" commands, since the main daemon shouldn't know
         # anything about our key auth
         if payload["enc"] == "clear" and payload.get("load", {}).get("cmd") == "_auth":
-            stream.send(self.serial.dumps(self._auth(payload["load"])))
+            stream.send(self.serial.dumps(self._auth(payload["load"], sign_messages)))
             raise salt.ext.tornado.gen.Return()
 
+        nonce = None
+        if version > 1:
+            nonce = payload["load"].pop("nonce", None)
+
         # TODO: test
         try:
             # Take the payload_handler function that was registered when we created the channel
@@ -875,11 +926,13 @@ class ZeroMQReqServerChannel(
         if req_fun == "send_clear":
             stream.send(self.serial.dumps(ret))
         elif req_fun == "send":
-            stream.send(self.serial.dumps(self.crypticle.dumps(ret)))
+            stream.send(self.serial.dumps(self.crypticle.dumps(ret, nonce)))
         elif req_fun == "send_private":
             stream.send(
                 self.serial.dumps(
-                    self._encrypt_private(ret, req_opts["key"], req_opts["tgt"],)
+                    self._encrypt_private(
+                        ret, req_opts["key"], req_opts["tgt"], nonce, sign_messages,
+                    )
                 )
             )
         else:
@@ -893,7 +946,7 @@ class ZeroMQReqServerChannel(
         signal.signal(signal.SIGTERM, self._handle_signals)
 
     def _handle_signals(self, signum, sigframe):
-        msg = "{0} received a ".format(self.__class__.__name__)
+        msg = "{} received a ".format(self.__class__.__name__)
         if signum == signal.SIGINT:
             msg += "SIGINT"
         elif signum == signal.SIGTERM:
@@ -985,11 +1038,11 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
         pull_sock.setsockopt(zmq.LINGER, -1)
 
         if self.opts.get("ipc_mode", "") == "tcp":
-            pull_uri = "tcp://127.0.0.1:{0}".format(
+            pull_uri = "tcp://127.0.0.1:{}".format(
                 self.opts.get("tcp_master_publish_pull", 4514)
             )
         else:
-            pull_uri = "ipc://{0}".format(
+            pull_uri = "ipc://{}".format(
                 os.path.join(self.opts["sock_dir"], "publish_pull.ipc")
             )
         salt.utils.zeromq.check_ipc_path_max_len(pull_uri)
@@ -1010,13 +1063,13 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
                 try:
                     log.debug("Publish daemon getting data from puller %s", pull_uri)
                     package = pull_sock.recv()
+                    package = self.pack_publish(self.serial.loads(package))
                     log.debug("Publish daemon received payload. size=%d", len(package))
 
                     unpacked_package = salt.payload.unpackage(package)
-                    if six.PY3:
-                        unpacked_package = salt.transport.frame.decode_embedded_strs(
-                            unpacked_package
-                        )
+                    unpacked_package = salt.transport.frame.decode_embedded_strs(
+                        unpacked_package
+                    )
                     payload = unpacked_package["payload"]
                     log.trace("Accepted unpacked package from puller")
                     if self.opts["zmq_filtering"]:
@@ -1061,7 +1114,7 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
                 except zmq.ZMQError as exc:
                     if exc.errno == errno.EINTR:
                         continue
-                    six.reraise(*sys.exc_info())
+                    raise
 
         except KeyboardInterrupt:
             log.trace("Publish daemon caught Keyboard interupt, tearing down")
@@ -1103,15 +1156,15 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
         """
         if self.pub_sock:
             self.pub_close()
-        ctx = zmq.Context.instance()
-        self._sock_data.sock = ctx.socket(zmq.PUSH)
+        self._sock_data._ctx = zmq.Context.instance()
+        self._sock_data.sock = self._sock_data._ctx.socket(zmq.PUSH)
         self.pub_sock.setsockopt(zmq.LINGER, -1)
         if self.opts.get("ipc_mode", "") == "tcp":
-            pull_uri = "tcp://127.0.0.1:{0}".format(
+            pull_uri = "tcp://127.0.0.1:{}".format(
                 self.opts.get("tcp_master_publish_pull", 4514)
             )
         else:
-            pull_uri = "ipc://{0}".format(
+            pull_uri = "ipc://{}".format(
                 os.path.join(self.opts["sock_dir"], "publish_pull.ipc")
             )
         log.debug("Connecting to pub server: %s", pull_uri)
@@ -1126,8 +1179,10 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
         if hasattr(self._sock_data, "sock"):
             self._sock_data.sock.close()
             delattr(self._sock_data, "sock")
+            if hasattr(self._sock_data, "_ctx"):
+                self._sock_data._ctx.destroy()
 
-    def publish(self, load):
+    def pack_publish(self, load):
         """
         Publish "load" to minions. This send the load to the publisher daemon
         process with does the actual sending to minions.
@@ -1135,6 +1190,8 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
         :param dict load: A load to be sent across the wire to minions
         """
         payload = {"enc": "aes"}
+        load["serial"] = salt.master.SMaster.get_serial()
+
         crypticle = salt.crypt.Crypticle(
             self.opts, salt.master.SMaster.secrets["aes"]["secret"].value
         )
@@ -1165,8 +1222,18 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
             load.get("jid", None),
             len(payload),
         )
+        return payload
+
+    def publish(self, load):
+        """
+        Publish "load" to minions. This send the load to the publisher daemon
+        process with does the actual sending to minions.
+
+        :param dict load: A load to be sent across the wire to minions
+        """
         if not self.pub_sock:
             self.pub_connect()
+        payload = self.serial.dumps(load)
         self.pub_sock.send(payload)
         log.debug("Sent payload to publish daemon.")
 
@@ -1177,10 +1244,8 @@ class AsyncReqMessageClientPool(salt.transport.MessageClientPool):
     """
 
     def __init__(self, opts, args=None, kwargs=None):
-        super(AsyncReqMessageClientPool, self).__init__(
-            AsyncReqMessageClient, opts, args=args, kwargs=kwargs
-        )
         self._closing = False
+        super().__init__(AsyncReqMessageClient, opts, args=args, kwargs=kwargs)
 
     def close(self):
         if self._closing:
@@ -1195,15 +1260,15 @@ class AsyncReqMessageClientPool(salt.transport.MessageClientPool):
         message_clients = sorted(self.message_clients, key=lambda x: len(x.send_queue))
         return message_clients[0].send(*args, **kwargs)
 
-    # pylint: disable=W1701
-    def __del__(self):
-        self.close()
+    def __enter__(self):
+        return self
 
-    # pylint: enable=W1701
+    def __exit__(self, *args):
+        self.close()
 
 
 # TODO: unit tests!
-class AsyncReqMessageClient(object):
+class AsyncReqMessageClient:
     """
     This class wraps the underlying zeromq REQ socket and gives a future-based
     interface to sending and recieving messages. This works around the primary
@@ -1407,7 +1472,7 @@ class AsyncReqMessageClient(object):
         return future
 
 
-class ZeroMQSocketMonitor(object):
+class ZeroMQSocketMonitor:
     __EVENT_MAP = None
 
     def __init__(self, socket):
