@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Approximate the Unix find(1) command and return a list of paths that
 meet the specified criteria.
 
@@ -18,6 +18,9 @@ and/or actions:
     delete [= file-types]               # default type = 'f'
     exec    = command [arg ...]         # where {} is replaced by pathname
     print  [= print-opts]
+and/or depth criteria:
+   maxdepth = maximum depth to transverse in path
+   mindepth = minimum depth to transverse before checking files or directories
 
 The default action is 'print=path'.
 
@@ -71,39 +74,48 @@ the following:
 
     group: group name
     md5:   MD5 digest of file contents
-    mode:  file permissions (as integer)
+    mode:  file permissions (as as integer)
     mtime: last modification time (as time_t)
     name:  file basename
     path:  file absolute path
     size:  file size in bytes
     type:  file type
     user:  user name
-'''
+"""
 
 # Import python libs
-from __future__ import print_function
+from __future__ import absolute_import, print_function, unicode_literals
+
 import logging
 import os
 import re
+import shutil
 import stat
 import sys
 import time
-import shlex
-import shutil
-from subprocess import Popen, PIPE
+from subprocess import PIPE, Popen
+
+import salt.defaults.exitcodes
+
+# Import salt libs
+import salt.utils.args
+import salt.utils.hashutils
+import salt.utils.path
+import salt.utils.stringutils
+
+# Import 3rd-party libs
+from salt.ext import six
+from salt.utils.filebuffer import BufferedReader
+
 try:
     import grp
     import pwd
+
     # TODO: grp and pwd are both used in the code, we better make sure that
     # that code never gets run if importing them does not succeed
 except ImportError:
     pass
 
-# Import salt libs
-import salt.exitcodes
-import salt.utils
-from salt._compat import MAX_SIZE
-from salt.utils.filebuffer import BufferedReader
 
 # Set up logger
 log = logging.getLogger(__name__)
@@ -112,22 +124,25 @@ _REQUIRES_PATH = 1
 _REQUIRES_STAT = 2
 _REQUIRES_CONTENTS = 4
 
-_FILE_TYPES = {'b': stat.S_IFBLK,
-               'c': stat.S_IFCHR,
-               'd': stat.S_IFDIR,
-               'f': stat.S_IFREG,
-               'l': stat.S_IFLNK,
-               'p': stat.S_IFIFO,
-               's': stat.S_IFSOCK,
-               stat.S_IFBLK: 'b',
-               stat.S_IFCHR: 'c',
-               stat.S_IFDIR: 'd',
-               stat.S_IFREG: 'f',
-               stat.S_IFLNK: 'l',
-               stat.S_IFIFO: 'p',
-               stat.S_IFSOCK: 's'}
+_FILE_TYPES = {
+    "b": stat.S_IFBLK,
+    "c": stat.S_IFCHR,
+    "d": stat.S_IFDIR,
+    "f": stat.S_IFREG,
+    "l": stat.S_IFLNK,
+    "p": stat.S_IFIFO,
+    "s": stat.S_IFSOCK,
+    stat.S_IFBLK: "b",
+    stat.S_IFCHR: "c",
+    stat.S_IFDIR: "d",
+    stat.S_IFREG: "f",
+    stat.S_IFLNK: "l",
+    stat.S_IFIFO: "p",
+    stat.S_IFSOCK: "s",
+}
 
-_INTERVAL_REGEX = re.compile(r'''
+_INTERVAL_REGEX = re.compile(
+    r"""
                              ^\s*
                              (?P<modifier>[+-]?)
                              (?: (?P<week>   \d+ (?:\.\d*)? ) \s* [wW]  )? \s*
@@ -136,12 +151,15 @@ _INTERVAL_REGEX = re.compile(r'''
                              (?: (?P<minute> \d+ (?:\.\d*)? ) \s* [mM]  )? \s*
                              (?: (?P<second> \d+ (?:\.\d*)? ) \s* [sS]  )? \s*
                              $
-                             ''',
-                             flags=re.VERBOSE)
+                             """,
+    flags=re.VERBOSE,
+)
+
+_PATH_DEPTH_IGNORED = (os.path.sep, os.path.curdir, os.path.pardir)
 
 
 def _parse_interval(value):
-    '''
+    """
     Convert an interval string like 1w3d6h into the number of seconds, time
     resolution (1 unit of the smallest specified time unit) and the modifier(
     '+', '-', or '').
@@ -150,41 +168,45 @@ def _parse_interval(value):
         h = hour
         m = minute
         s = second
-    '''
-    match = _INTERVAL_REGEX.match(str(value))
+    """
+    match = _INTERVAL_REGEX.match(six.text_type(value))
     if match is None:
-        raise ValueError('invalid time interval: {0!r}'.format(value))
+        raise ValueError("invalid time interval: '{0}'".format(value))
 
     result = 0
     resolution = None
-    for name, multiplier in [('second', 1),
-                             ('minute', 60),
-                             ('hour', 60 * 60),
-                             ('day', 60 * 60 * 24),
-                             ('week', 60 * 60 * 24 * 7)]:
+    for name, multiplier in [
+        ("second", 1),
+        ("minute", 60),
+        ("hour", 60 * 60),
+        ("day", 60 * 60 * 24),
+        ("week", 60 * 60 * 24 * 7),
+    ]:
         if match.group(name) is not None:
             result += float(match.group(name)) * multiplier
             if resolution is None:
                 resolution = multiplier
 
-    return result, resolution, match.group('modifier')
+    return result, resolution, match.group("modifier")
 
 
 def _parse_size(value):
     scalar = value.strip()
 
-    if scalar.startswith(('-', '+')):
+    if scalar.startswith(("-", "+")):
         style = scalar[0]
         scalar = scalar[1:]
     else:
-        style = '='
+        style = "="
 
-    if len(scalar) > 0:
-        multiplier = {'b': 2 ** 0,
-                      'k': 2 ** 10,
-                      'm': 2 ** 20,
-                      'g': 2 ** 30,
-                      't': 2 ** 40}.get(scalar[-1].lower())
+    if scalar:
+        multiplier = {
+            "b": 2 ** 0,
+            "k": 2 ** 10,
+            "m": 2 ** 20,
+            "g": 2 ** 30,
+            "t": 2 ** 40,
+        }.get(scalar[-1].lower())
         if multiplier:
             scalar = scalar[:-1].strip()
         else:
@@ -200,12 +222,12 @@ def _parse_size(value):
         except ValueError:
             raise ValueError('invalid size: "{0}"'.format(value))
 
-    if style == '-':
+    if style == "-":
         min_size = 0
         max_size = num
-    elif style == '+':
+    elif style == "+":
         min_size = num
-        max_size = MAX_SIZE
+        max_size = six.MAXSIZE
     else:
         min_size = num
         max_size = num + multiplier - 1
@@ -214,50 +236,54 @@ def _parse_size(value):
 
 
 class Option(object):
-    '''
+    """
     Abstract base class for all find options.
-    '''
+    """
+
     def requires(self):
         return _REQUIRES_PATH
 
 
 class NameOption(Option):
-    '''
+    """
     Match files with a case-sensitive glob filename pattern.
     Note: this is the 'basename' portion of a pathname.
     The option name is 'name', e.g. {'name' : '*.txt'}.
-    '''
+    """
+
     def __init__(self, key, value):
-        self.regex = re.compile(value.replace('.', '\\.')
-                                     .replace('?', '.?')
-                                     .replace('*', '.*') + '$')
+        self.regex = re.compile(
+            value.replace(".", "\\.").replace("?", ".?").replace("*", ".*") + "$"
+        )
 
     def match(self, dirname, filename, fstat):
         return self.regex.match(filename)
 
 
 class InameOption(Option):
-    '''
+    """
     Match files with a case-insensitive glob filename pattern.
     Note: this is the 'basename' portion of a pathname.
     The option name is 'iname', e.g. {'iname' : '*.TXT'}.
-    '''
+    """
+
     def __init__(self, key, value):
-        self.regex = re.compile(value.replace('.', '\\.')
-                                     .replace('?', '.?')
-                                     .replace('*', '.*') + '$',
-                                re.IGNORECASE)
+        self.regex = re.compile(
+            value.replace(".", "\\.").replace("?", ".?").replace("*", ".*") + "$",
+            re.IGNORECASE,
+        )
 
     def match(self, dirname, filename, fstat):
         return self.regex.match(filename)
 
 
 class RegexOption(Option):
-    '''
+    """
     Match files with a case-sensitive regular expression.
     Note: this is the 'basename' portion of a pathname.
     The option name is 'regex', e.g. {'regex' : '.*\\.txt'}.
-    '''
+    """
+
     def __init__(self, key, value):
         try:
             self.regex = re.compile(value)
@@ -269,11 +295,12 @@ class RegexOption(Option):
 
 
 class IregexOption(Option):
-    '''
+    """
     Match files with a case-insensitive regular expression.
     Note: this is the 'basename' portion of a pathname.
     The option name is 'iregex', e.g. {'iregex' : '.*\\.txt'}.
-    '''
+    """
+
     def __init__(self, key, value):
         try:
             self.regex = re.compile(value, re.IGNORECASE)
@@ -285,7 +312,7 @@ class IregexOption(Option):
 
 
 class TypeOption(Option):
-    '''
+    """
     Match files by their file type(s).
     The file type(s) are specified as an optionally comma and/or space
     separated list of letters.
@@ -297,10 +324,11 @@ class TypeOption(Option):
         p = FIFO (named pipe)
         s = socket
     The option name is 'type', e.g. {'type' : 'd'} or {'type' : 'bc'}.
-    '''
+    """
+
     def __init__(self, key, value):
         # remove whitespace and commas
-        value = "".join(value.strip().replace(',', '').split())
+        value = "".join(value.strip().replace(",", "").split())
         self.ftypes = set()
         for ftype in value:
             try:
@@ -316,15 +344,16 @@ class TypeOption(Option):
 
 
 class OwnerOption(Option):
-    '''
+    """
     Match files by their owner name(s) and/or uid(s), e.g. 'root'.
     The names are a space and/or comma separated list of names and/or integers.
     A match occurs when the file's uid matches any user specified.
     The option name is 'owner', e.g. {'owner' : 'root'}.
-    '''
+    """
+
     def __init__(self, key, value):
         self.uids = set()
-        for name in value.replace(',', ' ').split():
+        for name in value.replace(",", " ").split():
             if name.isdigit():
                 self.uids.add(int(name))
             else:
@@ -341,20 +370,21 @@ class OwnerOption(Option):
 
 
 class GroupOption(Option):
-    '''
+    """
     Match files by their group name(s) and/or uid(s), e.g. 'admin'.
     The names are a space and/or comma separated list of names and/or integers.
     A match occurs when the file's gid matches any group specified.
     The option name is 'group', e.g. {'group' : 'admin'}.
-    '''
+    """
+
     def __init__(self, key, value):
         self.gids = set()
-        for name in value.replace(',', ' ').split():
+        for name in value.replace(",", " ").split():
             if name.isdigit():
                 self.gids.add(int(name))
             else:
                 try:
-                    self.gids.add(grp.getgrnam(value).gr_gid)
+                    self.gids.add(grp.getgrnam(name).gr_gid)
                 except KeyError:
                     raise ValueError('no such group "{0}"'.format(name))
 
@@ -366,7 +396,7 @@ class GroupOption(Option):
 
 
 class SizeOption(Option):
-    '''
+    """
     Match files by their size.
     Prefix the size with '-' to find files the specified size and smaller.
     Prefix the size with '+' to find files the specified size and larger.
@@ -378,7 +408,8 @@ class SizeOption(Option):
         g = gigabytes
         t = terabytes
     The option name is 'size', e.g. {'size' : '+1G'}.
-    '''
+    """
+
     def __init__(self, key, value):
         self.min_size, self.max_size = _parse_size(value)
 
@@ -390,18 +421,19 @@ class SizeOption(Option):
 
 
 class MtimeOption(Option):
-    '''
+    """
     Match files modified since the specified time.
     The option name is 'mtime', e.g. {'mtime' : '3d'}.
     The value format is [<num>w] [<num>[d]] [<num>h] [<num>m] [<num>s]
-    where num is an integer or float and the case-insenstive suffixes are:
+    where num is an integer or float and the case-insensitive suffixes are:
         w = week
         d = day
         h = hour
         m = minute
         s = second
     Whitespace is ignored in the value.
-    '''
+    """
+
     def __init__(self, key, value):
         secs, resolution, modifier = _parse_interval(value)
         self.mtime = time.time() - int(secs / resolution) * resolution
@@ -411,16 +443,17 @@ class MtimeOption(Option):
         return _REQUIRES_STAT
 
     def match(self, dirname, filename, fstat):
-        if self.modifier == '-':
+        if self.modifier == "-":
             return fstat[stat.ST_MTIME] >= self.mtime
         else:
             return fstat[stat.ST_MTIME] <= self.mtime
 
 
 class GrepOption(Option):
-    '''Match files when a pattern occurs within the file.
+    """Match files when a pattern occurs within the file.
     The option name is 'grep', e.g. {'grep' : '(foo)|(bar}'}.
-    '''
+    """
+
     def __init__(self, key, value):
         try:
             self.regex = re.compile(value)
@@ -434,7 +467,7 @@ class GrepOption(Option):
         if not stat.S_ISREG(fstat[stat.ST_MODE]):
             return None
         dfilename = os.path.join(dirname, filename)
-        with BufferedReader(dfilename, mode='rb') as bread:
+        with BufferedReader(dfilename, mode="rb") as bread:
             for chunk in bread:
                 if self.regex.search(chunk):
                     return dfilename
@@ -442,7 +475,7 @@ class GrepOption(Option):
 
 
 class PrintOption(Option):
-    '''
+    """
     Return information about a matched file.
     Print options are specified as a comma and/or space separated list of
     one or more of the following:
@@ -455,56 +488,56 @@ class PrintOption(Option):
         size   = file size in bytes
         type   = file type
         user   = user name
-    '''
+    """
+
     def __init__(self, key, value):
         self.need_stat = False
         self.print_title = False
         self.fmt = []
-        for arg in value.replace(',', ' ').split():
+        for arg in value.replace(",", " ").split():
             self.fmt.append(arg)
-            if arg not in ['name', 'path']:
+            if arg not in ["name", "path"]:
                 self.need_stat = True
-        if len(self.fmt) == 0:
-            self.fmt.append('path')
+        if not self.fmt:
+            self.fmt.append("path")
 
     def requires(self):
         return _REQUIRES_STAT if self.need_stat else _REQUIRES_PATH
 
-    def execute(self, fullpath, fstat):
+    def execute(self, fullpath, fstat, test=False):
         result = []
         for arg in self.fmt:
-            if arg == 'path':
+            if arg == "path":
                 result.append(fullpath)
-            elif arg == 'name':
+            elif arg == "name":
                 result.append(os.path.basename(fullpath))
-            elif arg == 'size':
+            elif arg == "size":
                 result.append(fstat[stat.ST_SIZE])
-            elif arg == 'type':
-                result.append(
-                    _FILE_TYPES.get(stat.S_IFMT(fstat[stat.ST_MODE]), '?')
-                )
-            elif arg == 'mode':
-                result.append(fstat[stat.ST_MODE])
-            elif arg == 'mtime':
+            elif arg == "type":
+                result.append(_FILE_TYPES.get(stat.S_IFMT(fstat[stat.ST_MODE]), "?"))
+            elif arg == "mode":
+                # PY3 compatibility: Use radix value 8 on int type-cast explicitly
+                result.append(int(oct(fstat[stat.ST_MODE])[-3:], 8))
+            elif arg == "mtime":
                 result.append(fstat[stat.ST_MTIME])
-            elif arg == 'user':
+            elif arg == "user":
                 uid = fstat[stat.ST_UID]
                 try:
                     result.append(pwd.getpwuid(uid).pw_name)
                 except KeyError:
                     result.append(uid)
-            elif arg == 'group':
+            elif arg == "group":
                 gid = fstat[stat.ST_GID]
                 try:
                     result.append(grp.getgrgid(gid).gr_name)
                 except KeyError:
                     result.append(gid)
-            elif arg == 'md5':
+            elif arg == "md5":
                 if stat.S_ISREG(fstat[stat.ST_MODE]):
-                    md5digest = salt.utils.get_hash(fullpath, 'md5')
+                    md5digest = salt.utils.hashutils.get_hash(fullpath, "md5")
                     result.append(md5digest)
                 else:
-                    result.append('')
+                    result.append("")
 
         if len(result) == 1:
             return result[0]
@@ -513,7 +546,7 @@ class PrintOption(Option):
 
 
 class DeleteOption(TypeOption):
-    '''
+    """
     Deletes matched file.
     Delete options are one or more of the following:
         a: all file types
@@ -524,11 +557,12 @@ class DeleteOption(TypeOption):
         f: plain file
         l: symlink
         s: socket
-    '''
+    """
+
     def __init__(self, key, value):
-        if 'a' in value:
-            value = 'bcdpfls'
-        super(self.__class__, self).__init__(key, value)
+        if "a" in value:
+            value = "bcdpfls"
+        super(DeleteOption, self).__init__(key, value)
 
     def execute(self, fullpath, fstat, test=False):
         if test:
@@ -544,53 +578,64 @@ class DeleteOption(TypeOption):
 
 
 class ExecOption(Option):
-    '''
+    """
     Execute the given command, {} replaced by filename.
     Quote the {} if commands might include whitespace.
-    '''
+    """
+
     def __init__(self, key, value):
         self.command = value
 
     def execute(self, fullpath, fstat, test=False):
         try:
-            command = self.command.replace('{}', fullpath)
-            print(shlex.split(command))
-            p = Popen(shlex.split(command),
-                      stdout=PIPE,
-                      stderr=PIPE)
+            command = self.command.replace("{}", fullpath)
+            print(salt.utils.args.shlex_split(command))
+            p = Popen(salt.utils.args.shlex_split(command), stdout=PIPE, stderr=PIPE)
             (out, err) = p.communicate()
             if err:
                 log.error(
-                    'Error running command: {0}\n\n{1}'.format(
+                    "Error running command: %s\n\n%s",
                     command,
-                    err))
-            return "{0}:\n{1}\n".format(command, out)
+                    salt.utils.stringutils.to_str(err),
+                )
+            return "{0}:\n{1}\n".format(command, salt.utils.stringutils.to_str(out))
 
-        except Exception, e:
-            log.error(
-                'Exception while executing command "{0}":\n\n{1}'.format(
-                    command,
-                    e))
-            return '{0}: Failed'.format(fullpath)
+        except Exception as e:  # pylint: disable=broad-except
+            log.error('Exception while executing command "%s":\n\n%s', command, e)
+            return "{0}: Failed".format(fullpath)
 
 
 class Finder(object):
     def __init__(self, options):
         self.actions = []
-        criteria = {_REQUIRES_PATH: list(),
-                    _REQUIRES_STAT: list(),
-                    _REQUIRES_CONTENTS: list()}
-        for key, value in options.items():
-            if key.startswith('_'):
+        self.maxdepth = None
+        self.mindepth = 0
+        self.test = False
+        criteria = {
+            _REQUIRES_PATH: list(),
+            _REQUIRES_STAT: list(),
+            _REQUIRES_CONTENTS: list(),
+        }
+        if "mindepth" in options:
+            self.mindepth = options["mindepth"]
+            del options["mindepth"]
+        if "maxdepth" in options:
+            self.maxdepth = options["maxdepth"]
+            del options["maxdepth"]
+        if "test" in options:
+            self.test = options["test"]
+            del options["test"]
+        for key, value in six.iteritems(options):
+            if key.startswith("_"):
                 # this is a passthrough object, continue
                 continue
-            if value is None or len(str(value)) == 0:
+            if not value:
                 raise ValueError('missing value for "{0}" option'.format(key))
             try:
                 obj = globals()[key.title() + "Option"](key, value)
             except KeyError:
                 raise ValueError('invalid option "{0}"'.format(key))
-            if hasattr(obj, 'match'):
+            if hasattr(obj, "match"):
                 requires = obj.requires()
                 if requires & _REQUIRES_CONTENTS:
                     criteria[_REQUIRES_CONTENTS].append(obj)
@@ -598,50 +643,88 @@ class Finder(object):
                     criteria[_REQUIRES_STAT].append(obj)
                 else:
                     criteria[_REQUIRES_PATH].append(obj)
-            if hasattr(obj, 'execute'):
+            if hasattr(obj, "execute"):
                 self.actions.append(obj)
-        if len(self.actions) == 0:
-            self.actions.append(PrintOption('print', ''))
+        if not self.actions:
+            self.actions.append(PrintOption("print", ""))
         # order criteria so that least expensive checks are done first
-        self.criteria = criteria[_REQUIRES_PATH] + \
-                        criteria[_REQUIRES_STAT] + \
-                        criteria[_REQUIRES_CONTENTS]
+        self.criteria = (
+            criteria[_REQUIRES_PATH]
+            + criteria[_REQUIRES_STAT]
+            + criteria[_REQUIRES_CONTENTS]
+        )
 
     def find(self, path):
-        '''
+        """
         Generate filenames in path that satisfy criteria specified in
         the constructor.
         This method is a generator and should be repeatedly called
         until there are no more results.
-        '''
-        for dirpath, dirs, files in os.walk(path):
-            for name in dirs + files:
-                fstat = None
-                matches = True
-                fullpath = None
-                for criterion in self.criteria:
-                    if fstat is None and criterion.requires() & _REQUIRES_STAT:
-                        fullpath = os.path.join(dirpath, name)
-                        fstat = os.stat(fullpath)
-                    if not criterion.match(dirpath, name, fstat):
-                        matches = False
-                        break
-                if matches:
-                    if fullpath is None:
-                        fullpath = os.path.join(dirpath, name)
-                    for action in self.actions:
-                        if (fstat is None and
-                            action.requires() & _REQUIRES_STAT):
-                            fstat = os.stat(fullpath)
-                        result = action.execute(fullpath, fstat)
-                        if result is not None:
+        """
+        if self.mindepth < 1:
+            dirpath, name = os.path.split(path)
+            match, fstat = self._check_criteria(dirpath, name, path)
+            if match:
+                for result in self._perform_actions(path, fstat=fstat):
+                    yield result
+
+        for dirpath, dirs, files in salt.utils.path.os_walk(path):
+            relpath = os.path.relpath(dirpath, path)
+            depth = path_depth(relpath) + 1
+            if depth >= self.mindepth and (
+                self.maxdepth is None or self.maxdepth >= depth
+            ):
+                for name in dirs + files:
+                    fullpath = os.path.join(dirpath, name)
+                    match, fstat = self._check_criteria(dirpath, name, fullpath)
+                    if match:
+                        for result in self._perform_actions(fullpath, fstat=fstat):
                             yield result
 
+            if self.maxdepth is not None and depth > self.maxdepth:
+                dirs[:] = []
+
+    def _check_criteria(self, dirpath, name, fullpath, fstat=None):
+        match = True
+        for criterion in self.criteria:
+            if fstat is None and criterion.requires() & _REQUIRES_STAT:
+                try:
+                    fstat = os.stat(fullpath)
+                except OSError:
+                    fstat = os.lstat(fullpath)
+            if not criterion.match(dirpath, name, fstat):
+                match = False
+                break
+        return match, fstat
+
+    def _perform_actions(self, fullpath, fstat=None):
+        for action in self.actions:
+            if fstat is None and action.requires() & _REQUIRES_STAT:
+                try:
+                    fstat = os.stat(fullpath)
+                except OSError:
+                    fstat = os.lstat(fullpath)
+            result = action.execute(fullpath, fstat, test=self.test)
+            if result is not None:
+                yield result
+
+
+def path_depth(path):
+    depth = 0
+    head = path
+    while True:
+        head, tail = os.path.split(head)
+        if not tail and (not head or head in _PATH_DEPTH_IGNORED):
+            break
+        if tail and tail not in _PATH_DEPTH_IGNORED:
+            depth += 1
+    return depth
+
 
 def find(path, options):
-    '''
+    """
     WRITEME
-    '''
+    """
     finder = Finder(options)
     for path in finder.find(path):
         yield path
@@ -649,23 +732,24 @@ def find(path, options):
 
 def _main():
     if len(sys.argv) < 2:
-        sys.stderr.write('usage: {0} path [options]\n'.format(sys.argv[0]))
-        sys.exit(salt.exitcodes.EX_USAGE)
+        sys.stderr.write("usage: {0} path [options]\n".format(sys.argv[0]))
+        sys.exit(salt.defaults.exitcodes.EX_USAGE)
 
     path = sys.argv[1]
     criteria = {}
 
     for arg in sys.argv[2:]:
-        key, value = arg.split('=')
+        key, value = arg.split("=")
         criteria[key] = value
     try:
         finder = Finder(criteria)
     except ValueError as ex:
-        sys.stderr.write('error: {0}\n'.format(ex))
-        sys.exit(salt.exitcodes.EX_GENERIC)
+        sys.stderr.write("error: {0}\n".format(ex))
+        sys.exit(salt.defaults.exitcodes.EX_GENERIC)
 
     for result in finder.find(path):
         print(result)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     _main()
