@@ -1,23 +1,26 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Connection library for GitHub
-'''
+"""
 
 # Import Python libs
-from __future__ import absolute_import
-import json
-import salt.utils.http
+from __future__ import absolute_import, print_function, unicode_literals
+
 import logging
 
-# Import 3rd-party libs
-import salt.ext.six as six
+import salt.utils.http
 
+# Import Salt libs
+import salt.utils.json
+
+# Import 3rd-party libs
+from salt.ext import six
 
 log = logging.getLogger(__name__)
 
 
 def get_user_pubkeys(users):
-    '''
+    """
     Retrieve a set of public keys from GitHub for the specified list of users.
     Expects input in list format. Optionally, a value in the list may be a dict
     whose value is a list of key IDs to be returned. If this is not done, then
@@ -37,9 +40,9 @@ def get_user_pubkeys(users):
             'user2',
             'user3',
         ]
-    '''
+    """
     if not isinstance(users, list):
-        return {'Error': 'A list of users is expected'}
+        return {"Error": "A list of users is expected"}
 
     ret = {}
     for user in users:
@@ -49,22 +52,17 @@ def get_user_pubkeys(users):
             key_ids = user[tmp_user]
             user = tmp_user
 
-        url = 'https://api.github.com/users/{0}/keys'.format(user)
-        result = salt.utils.http.query(
-            url,
-            'GET',
-            decode=False,
-            text=True,
-        )
+        url = "https://api.github.com/users/{0}/keys".format(user)
+        result = salt.utils.http.query(url, "GET", decode=False, text=True,)
 
-        keys = json.loads(result['text'])
+        keys = salt.utils.json.loads(result["text"])
 
         ret[user] = {}
         for key in keys:
-            if len(key_ids) > 0:
-                if str(key['id']) in key_ids:
-                    ret[user][key['id']] = key['key']
+            if key_ids:
+                if six.text_type(key["id"]) in key_ids:
+                    ret[user][key["id"]] = key["key"]
             else:
-                ret[user][key['id']] = key['key']
+                ret[user][key["id"]] = key["key"]
 
     return ret
