@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 Jinja loading utils to enable a more powerful backend for jinja templates
 """
 
-# Import python libs
-from __future__ import absolute_import, unicode_literals
 
 import atexit
 import logging
@@ -12,6 +9,7 @@ import os.path
 import pipes
 import pprint
 import re
+import time
 import uuid
 import warnings
 from collections.abc import Hashable
@@ -19,7 +17,6 @@ from functools import wraps
 from xml.dom import minidom
 from xml.etree.ElementTree import Element, SubElement, tostring
 
-# Import third party libs
 import jinja2
 import salt.fileclient
 import salt.utils.data
@@ -32,10 +29,7 @@ from jinja2 import BaseLoader, Markup, TemplateNotFound, nodes
 from jinja2.environment import TemplateModule
 from jinja2.exceptions import TemplateRuntimeError
 from jinja2.ext import Extension
-
-# Import salt libs
 from salt.exceptions import TemplateError
-from salt.ext import six
 from salt.utils.decorators.jinja import jinja_filter, jinja_global, jinja_test
 from salt.utils.odict import OrderedDict
 from salt.utils.versions import LooseVersion
@@ -195,7 +189,7 @@ class SaltCacheLoader(BaseLoader):
                             return False
 
                     return contents, filepath, uptodate
-            except IOError:
+            except OSError:
                 # there is no file under current path
                 continue
         # pylint: enable=cell-var-from-loop
@@ -224,24 +218,24 @@ class PrintableDict(OrderedDict):
 
     def __str__(self):
         output = []
-        for key, value in six.iteritems(self):
-            if isinstance(value, six.string_types):
+        for key, value in self.items():
+            if isinstance(value, str):
                 # keeps quotes around strings
                 # pylint: disable=repr-flag-used-in-string
-                output.append("{0!r}: {1!r}".format(key, value))
+                output.append("{!r}: {!r}".format(key, value))
                 # pylint: enable=repr-flag-used-in-string
             else:
                 # let default output
-                output.append("{0!r}: {1!s}".format(key, value))
+                output.append("{!r}: {!s}".format(key, value))
         return "{" + ", ".join(output) + "}"
 
     def __repr__(self):  # pylint: disable=W0221
         output = []
-        for key, value in six.iteritems(self):
+        for key, value in self.items():
             # Raw string formatter required here because this is a repr
             # function.
             # pylint: disable=repr-flag-used-in-string
-            output.append("{0!r}: {1!r}".format(key, value))
+            output.append("{!r}: {!r}".format(key, value))
             # pylint: enable=repr-flag-used-in-string
         return "{" + ", ".join(output) + "}"
 
@@ -341,9 +335,9 @@ def to_bool(val):
         return False
     if isinstance(val, bool):
         return val
-    if isinstance(val, (six.text_type, six.string_types)):
+    if isinstance(val, (str, (str,))):
         return val.lower() in ("yes", "1", "true")
-    if isinstance(val, six.integer_types):
+    if isinstance(val, int):
         return val > 0
     if not isinstance(val, Hashable):
         return len(val) > 0
@@ -393,13 +387,13 @@ def indent(s, width=4, first=False, blank=False, indentfirst=None):
 
 
 @jinja_filter("tojson")
-def tojson(val, indent=None):
+def tojson(val, indent=None, **options):
     """
-    Implementation of tojson filter (only present in Jinja 2.9 and later). If
-    Jinja 2.9 or later is installed, then the upstream version of this filter
-    will be used.
+    Implementation of tojson filter (only present in Jinja 2.9 and later).
+    Unlike the Jinja built-in filter, this allows arbitrary options to be
+    passed in to the underlying JSON library.
     """
-    options = {"ensure_ascii": True}
+    options.setdefault("ensure_ascii", True)
     if indent is not None:
         options["indent"] = indent
     return (
@@ -529,7 +523,7 @@ def uuid_(val):
 
         f4efeff8-c219-578a-bad7-3dc280612ec8
     """
-    return six.text_type(uuid.uuid5(GLOBAL_UUID, salt.utils.stringutils.to_str(val)))
+    return str(uuid.uuid5(GLOBAL_UUID, salt.utils.stringutils.to_str(val)))
 
 
 ### List-related filters
@@ -719,7 +713,7 @@ def show_full_context(ctx):
     )
 
 
-class SerializerExtension(Extension, object):
+class SerializerExtension(Extension):
     '''
     Yaml and Json manipulation.
 
@@ -893,10 +887,11 @@ class SerializerExtension(Extension, object):
         "import_json",
         "load_text",
         "import_text",
+        "profile",
     }
 
     def __init__(self, environment):
-        super(SerializerExtension, self).__init__(environment)
+        super().__init__(environment)
         self.environment.filters.update(
             {
                 "yaml": self.format_yaml,
@@ -928,7 +923,7 @@ class SerializerExtension(Extension, object):
         def explore(data):
             if isinstance(data, (dict, OrderedDict)):
                 return PrintableDict(
-                    [(key, explore(value)) for key, value in six.iteritems(data)]
+                    [(key, explore(value)) for key, value in data.items()]
                 )
             elif isinstance(data, (list, tuple, set)):
                 return data.__class__([explore(value) for value in data])
@@ -949,7 +944,7 @@ class SerializerExtension(Extension, object):
         yaml_txt = salt.utils.yaml.safe_dump(
             value, default_flow_style=flow_style
         ).strip()
-        if yaml_txt.endswith(str("\n...")):  # future lint: disable=blacklisted-function
+        if yaml_txt.endswith("\n..."):  # future lint: disable=blacklisted-function
             yaml_txt = yaml_txt[: len(yaml_txt) - 4]
         try:
             return Markup(yaml_txt)
@@ -990,11 +985,11 @@ class SerializerExtension(Extension, object):
                 else:
                     sub = Element(tag)
                 if isinstance(attrs, (str, int, bool, float)):
-                    sub.text = six.text_type(attrs)
+                    sub.text = str(attrs)
                     continue
                 if isinstance(attrs, dict):
                     sub.attrib = {
-                        attr: six.text_type(val)
+                        attr: str(val)
                         for attr, val in attrs.items()
                         if not isinstance(val, (dict, list))
                     }
@@ -1017,7 +1012,7 @@ class SerializerExtension(Extension, object):
 
     def load_yaml(self, value):
         if isinstance(value, TemplateModule):
-            value = six.text_type(value)
+            value = str(value)
         try:
             return salt.utils.data.decode(salt.utils.yaml.safe_load(value))
         except salt.utils.yaml.YAMLError as exc:
@@ -1030,41 +1025,42 @@ class SerializerExtension(Extension, object):
             except AttributeError:
                 # No context information available in the exception, fall back
                 # to the stringified version of the exception.
-                msg += six.text_type(exc)
+                msg += str(exc)
             else:
-                msg += "{0}\n".format(problem)
+                msg += "{}\n".format(problem)
                 msg += salt.utils.stringutils.get_context(
                     buf, line, marker="    <======================"
                 )
             raise TemplateRuntimeError(msg)
         except AttributeError:
-            raise TemplateRuntimeError("Unable to load yaml from {0}".format(value))
+            raise TemplateRuntimeError("Unable to load yaml from {}".format(value))
 
     def load_json(self, value):
         if isinstance(value, TemplateModule):
-            value = six.text_type(value)
+            value = str(value)
         try:
             return salt.utils.json.loads(value)
         except (ValueError, TypeError, AttributeError):
-            raise TemplateRuntimeError("Unable to load json from {0}".format(value))
+            raise TemplateRuntimeError("Unable to load json from {}".format(value))
 
     def load_text(self, value):
         if isinstance(value, TemplateModule):
-            value = six.text_type(value)
+            value = str(value)
 
         return value
 
     _load_parsers = {"load_yaml", "load_json", "load_text"}
+    _import_parsers = {"import_yaml", "import_json", "import_text"}
 
     def parse(self, parser):
-        if parser.stream.current.value == "import_yaml":
-            return self.parse_yaml(parser)
-        elif parser.stream.current.value == "import_json":
-            return self.parse_json(parser)
-        elif parser.stream.current.value == "import_text":
-            return self.parse_text(parser)
-        elif parser.stream.current.value in self._load_parsers:
+        if parser.stream.current.value in self._load_parsers:
             return self.parse_load(parser)
+        elif parser.stream.current.value in self._import_parsers:
+            return self.parse_import(
+                parser, parser.stream.current.value.split("_", 1)[1]
+            )
+        elif parser.stream.current.value == "profile":
+            return self.parse_profile(parser)
 
         parser.fail(
             "Unknown format " + parser.stream.current.value,
@@ -1072,11 +1068,56 @@ class SerializerExtension(Extension, object):
         )
 
     # pylint: disable=E1120,E1121
+    def parse_profile(self, parser):
+        lineno = next(parser.stream).lineno
+        parser.stream.expect("name:as")
+        label = parser.parse_expression()
+        body = parser.parse_statements(["name:endprofile"], drop_needle=True)
+        return self._parse_profile_block(parser, label, "profile block", body, lineno)
+
+    def _create_profile_id(self, parser):
+        return "_salt_profile_{}".format(parser.free_identifier().name)
+
+    def _profile_start(self, label, source):
+        return (label, source, time.time())
+
+    def _profile_end(self, label, source, previous_time):
+        log.profile(
+            "Time (in seconds) to render {} '{}': {}".format(
+                source, label, time.time() - previous_time
+            )
+        )
+
+    def _parse_profile_block(self, parser, label, source, body, lineno):
+        profile_id = self._create_profile_id(parser)
+        ret = (
+            [
+                nodes.Assign(
+                    nodes.Name(profile_id, "store").set_lineno(lineno),
+                    self.call_method(
+                        "_profile_start",
+                        dyn_args=nodes.List([label, nodes.Const(source)]).set_lineno(
+                            lineno
+                        ),
+                    ).set_lineno(lineno),
+                ).set_lineno(lineno),
+            ]
+            + body
+            + [
+                nodes.ExprStmt(
+                    self.call_method(
+                        "_profile_end", dyn_args=nodes.Name(profile_id, "load")
+                    ),
+                ).set_lineno(lineno),
+            ]
+        )
+        return ret
+
     def parse_load(self, parser):
         filter_name = parser.stream.current.value
         lineno = next(parser.stream).lineno
         if filter_name not in self.environment.filters:
-            parser.fail("Unable to parse {0}".format(filter_name), lineno)
+            parser.fail("Unable to parse {}".format(filter_name), lineno)
 
         parser.stream.expect("name:as")
         target = parser.parse_assign_target()
@@ -1104,58 +1145,18 @@ class SerializerExtension(Extension, object):
             ).set_lineno(lineno),
         ]
 
-    def parse_yaml(self, parser):
+    def parse_import(self, parser, converter):
         import_node = parser.parse_import()
         target = import_node.target
         lineno = import_node.lineno
 
-        return [
+        body = [
             import_node,
             nodes.Assign(
                 nodes.Name(target, "store").set_lineno(lineno),
                 nodes.Filter(
                     nodes.Name(target, "load").set_lineno(lineno),
-                    "load_yaml",
-                    [],
-                    [],
-                    None,
-                    None,
-                ).set_lineno(lineno),
-            ).set_lineno(lineno),
-        ]
-
-    def parse_json(self, parser):
-        import_node = parser.parse_import()
-        target = import_node.target
-        lineno = import_node.lineno
-
-        return [
-            import_node,
-            nodes.Assign(
-                nodes.Name(target, "store").set_lineno(lineno),
-                nodes.Filter(
-                    nodes.Name(target, "load").set_lineno(lineno),
-                    "load_json",
-                    [],
-                    [],
-                    None,
-                    None,
-                ).set_lineno(lineno),
-            ).set_lineno(lineno),
-        ]
-
-    def parse_text(self, parser):
-        import_node = parser.parse_import()
-        target = import_node.target
-        lineno = import_node.lineno
-
-        return [
-            import_node,
-            nodes.Assign(
-                nodes.Name(target, "store").set_lineno(lineno),
-                nodes.Filter(
-                    nodes.Name(target, "load").set_lineno(lineno),
-                    "load_text",
+                    "load_{}".format(converter),
                     [],
                     [],
                     None,
@@ -1163,5 +1164,8 @@ class SerializerExtension(Extension, object):
                 ).set_lineno(lineno),
             ).set_lineno(lineno),
         ]
+        return self._parse_profile_block(
+            parser, import_node.template, "import_{}".format(converter), body, lineno
+        )
 
     # pylint: enable=E1120,E1121
