@@ -1,11 +1,6 @@
-# -*- coding: utf-8 -*-
 """
 Common functions for working with RPM packages
 """
-
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import collections
 import datetime
 import logging
@@ -15,9 +10,6 @@ import subprocess
 import salt.utils.path
 import salt.utils.stringutils
 
-# Import 3rd-party libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 # These arches compiled from the rpmUtils.arch python module source
@@ -61,8 +53,7 @@ def get_osarch():
     """
     if salt.utils.path.which("rpm"):
         ret = subprocess.Popen(
-            'rpm --eval "%{_host_cpu}"',
-            shell=True,
+            ["rpm", "--eval", "%{_host_cpu}"],
             close_fds=True,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
@@ -102,7 +93,7 @@ def resolve_name(name, arch, osarch=None):
         osarch = get_osarch()
 
     if not check_32(arch, osarch) and arch not in (osarch, "noarch"):
-        name += ".{0}".format(arch)
+        name += ".{}".format(arch)
     return name
 
 
@@ -120,7 +111,7 @@ def parse_pkginfo(line, osarch=None):
 
     name = resolve_name(name, arch, osarch)
     if release:
-        version += "-{0}".format(release)
+        version += "-{}".format(release)
     if epoch not in ("(none)", "0"):
         version = ":".join((epoch, version))
 
@@ -146,10 +137,10 @@ def combine_comments(comments):
         comments = [comments]
     ret = []
     for comment in comments:
-        if not isinstance(comment, six.string_types):
+        if not isinstance(comment, str):
             comment = str(comment)
         # Normalize for any spaces (or lack thereof) after the #
-        ret.append("# {0}\n".format(comment.lstrip("#").lstrip()))
+        ret.append("# {}\n".format(comment.lstrip("#").lstrip()))
     return "".join(ret)
 
 
@@ -171,7 +162,7 @@ def version_to_evr(verstring):
     idx_e = verstring.find(":")
     if idx_e != -1:
         try:
-            epoch = six.text_type(int(verstring[:idx_e]))
+            epoch = str(int(verstring[:idx_e]))
         except ValueError:
             # look, garbage in the epoch field, how fun, kill it
             epoch = "0"  # this is our fallback, deal
