@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 Functions for daemonizing and otherwise modifying running processes
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals, with_statement
 
 import contextlib
 import copy
@@ -24,16 +21,12 @@ import threading
 import time
 import types
 
-# Import salt libs
 import salt.defaults.exitcodes
 import salt.log.setup
 import salt.utils.files
 import salt.utils.path
 import salt.utils.platform
 import salt.utils.versions
-
-# Import 3rd-party libs
-from salt.ext import six
 from salt.ext.six.moves import queue, range
 from salt.ext.tornado import gen
 from salt.log.mixins import NewStyleClassMixIn
@@ -177,13 +170,13 @@ def notify_systemd():
             if notify_socket:
                 # Handle abstract namespace socket
                 if notify_socket.startswith("@"):
-                    notify_socket = "\0{0}".format(notify_socket[1:])
+                    notify_socket = "\0{}".format(notify_socket[1:])
                 try:
                     sock = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM)
                     sock.connect(notify_socket)
-                    sock.sendall("READY=1".encode())
+                    sock.sendall(b"READY=1")
                     sock.close()
-                except socket.error:
+                except OSError:
                     return systemd_notify_call("--ready")
                 return True
         return False
@@ -325,7 +318,7 @@ def set_pidfile(pidfile, user):
     try:
         with salt.utils.files.fopen(pidfile, "w+") as ofile:
             ofile.write(str(os.getpid()))  # future lint: disable=blacklisted-function
-    except IOError:
+    except OSError:
         pass
 
     log.debug("Created pidfile: %s", pidfile)
@@ -342,7 +335,7 @@ def set_pidfile(pidfile, user):
         # groups = [g.gr_gid for g in grp.getgrall() if user in g.gr_mem]
     except (KeyError, IndexError):
         sys.stderr.write(
-            "Failed to set the pid to user: {0}. The user is not "
+            "Failed to set the pid to user: {}. The user is not "
             "available.\n".format(user)
         )
         sys.exit(salt.defaults.exitcodes.EX_NOUSER)
@@ -354,11 +347,11 @@ def set_pidfile(pidfile, user):
     try:
         os.chown(pidfile, uid, gid)
     except OSError as err:
-        msg = "Failed to set the ownership of PID file {0} to user {1}.".format(
+        msg = "Failed to set the ownership of PID file {} to user {}.".format(
             pidfile, user
         )
         log.debug("%s Traceback follows:", msg, exc_info=True)
-        sys.stderr.write("{0}\n".format(msg))
+        sys.stderr.write("{}\n".format(msg))
         sys.exit(err.errno)
     log.debug("Chowned pidfile: %s to user: %s", pidfile, user)
 
@@ -378,7 +371,7 @@ def get_pidfile(pidfile):
         with salt.utils.files.fopen(pidfile) as pdf:
             pid = pdf.read().strip()
         return int(pid)
-    except (OSError, IOError, TypeError, ValueError):
+    except (OSError, TypeError, ValueError):
         return -1
 
 
@@ -409,7 +402,7 @@ def os_is_running(pid):
     """
     Use OS facilities to determine if a process is running
     """
-    if isinstance(pid, six.string_types):
+    if isinstance(pid, str):
         pid = int(pid)
     if HAS_PSUTIL:
         return psutil.pid_exists(pid)
@@ -421,7 +414,7 @@ def os_is_running(pid):
             return False
 
 
-class ThreadPool(object):
+class ThreadPool:
     """
     This is a very VERY basic threadpool implementation
     This was made instead of using multiprocessing ThreadPool because
@@ -493,7 +486,7 @@ class ThreadPool(object):
                 log.debug(err, exc_info=True)
 
 
-class ProcessManager(object):
+class ProcessManager:
     """
     A class which will manage processes that should be running
     """
@@ -553,12 +546,12 @@ class ProcessManager(object):
         # create a nicer name for the debug log
         if name is None:
             if isinstance(tgt, types.FunctionType):
-                name = "{0}.{1}".format(tgt.__module__, tgt.__name__,)
+                name = "{}.{}".format(tgt.__module__, tgt.__name__,)
             else:
-                name = "{0}{1}.{2}".format(
+                name = "{}{}.{}".format(
                     tgt.__module__,
-                    ".{0}".format(tgt.__class__)
-                    if six.text_type(tgt.__class__) != "<type 'type'>"
+                    ".{}".format(tgt.__class__)
+                    if str(tgt.__class__) != "<type 'type'>"
                     else "",
                     tgt.__name__,
                 )
@@ -592,12 +585,21 @@ class ProcessManager(object):
         """
         if self._restart_processes is False:
             return
-        log.info(
-            "Process %s (%s) died with exit status %s, restarting...",
-            self._process_map[pid]["tgt"],
-            pid,
-            self._process_map[pid]["Process"].exitcode,
-        )
+        exit = self._process_map[pid]["Process"].exitcode
+        if exit > 0:
+            log.info(
+                "Process %s (%s) died with exit status %s, restarting...",
+                self._process_map[pid]["tgt"],
+                pid,
+                self._process_map[pid]["Process"].exitcode,
+            )
+        else:
+            log.debug(
+                "Process %s (%s) died with exit status %s, restarting...",
+                self._process_map[pid]["tgt"],
+                pid,
+                self._process_map[pid]["Process"].exitcode,
+            )
         # don't block, the process is already dead
         self._process_map[pid]["Process"].join(1)
 
@@ -629,7 +631,7 @@ class ProcessManager(object):
             # with the tree option will not be able to find them.
             return
 
-        for pid in six.iterkeys(self._process_map.copy()):
+        for pid in self._process_map.copy().keys():
             try:
                 os.kill(pid, signal_)
             except OSError as exc:
@@ -672,7 +674,7 @@ class ProcessManager(object):
             # OSError is raised if a signal handler is called (SIGTERM) during os.wait
             except OSError:
                 break
-            except IOError as exc:  # pylint: disable=duplicate-except
+            except OSError as exc:  # pylint: disable=duplicate-except
                 # IOError with errno of EINTR (4) may be raised
                 # when using time.sleep() on Windows.
                 if exc.errno != errno.EINTR:
@@ -684,7 +686,7 @@ class ProcessManager(object):
         Check the children once
         """
         if self._restart_processes is True:
-            for pid, mapping in six.iteritems(self._process_map):
+            for pid, mapping in self._process_map.items():
                 if not mapping["Process"].is_alive():
                     log.trace("Process restart of %s", pid)
                     self.restart_process(pid)
@@ -715,17 +717,17 @@ class ProcessManager(object):
                 # We want to avoid this.
                 return
             with salt.utils.files.fopen(os.devnull, "wb") as devnull:
-                for pid, p_map in six.iteritems(self._process_map):
+                for pid, p_map in self._process_map.items():
                     # On Windows, we need to explicitly terminate sub-processes
                     # because the processes don't have a sigterm handler.
                     subprocess.call(
-                        ["taskkill", "/F", "/T", "/PID", six.text_type(pid)],
+                        ["taskkill", "/F", "/T", "/PID", str(pid)],
                         stdout=devnull,
                         stderr=devnull,
                     )
                     p_map["Process"].terminate()
         else:
-            for pid, p_map in six.iteritems(self._process_map.copy()):
+            for pid, p_map in self._process_map.copy().items():
                 log.trace("Terminating pid %s: %s", pid, p_map["Process"])
                 if args:
                     # escalate the signal to the process
@@ -749,7 +751,7 @@ class ProcessManager(object):
 
         log.trace("Waiting to kill process manager children")
         while self._process_map and time.time() < end_time:
-            for pid, p_map in six.iteritems(self._process_map.copy()):
+            for pid, p_map in self._process_map.copy().items():
                 log.trace("Joining pid %s: %s", pid, p_map["Process"])
                 p_map["Process"].join(0)
 
@@ -765,7 +767,7 @@ class ProcessManager(object):
         kill_iterations = 2
         while kill_iterations >= 0:
             kill_iterations -= 1
-            for pid, p_map in six.iteritems(self._process_map.copy()):
+            for pid, p_map in self._process_map.copy().items():
                 if not p_map["Process"].is_alive():
                     # The process is no longer alive, remove it from the process map dictionary
                     try:
@@ -795,7 +797,7 @@ class ProcessManager(object):
                 log.info(
                     "Some processes failed to respect the KILL signal: %s",
                     "; ".join(
-                        "Process: {0} (Pid: {1})".format(v["Process"], k)
+                        "Process: {} (Pid: {})".format(v["Process"], k)
                         for (  # pylint: disable=str-format-in-logging
                             k,
                             v,
@@ -809,7 +811,7 @@ class ProcessManager(object):
                 log.warning(
                     "Failed to kill the following processes: %s",
                     "; ".join(
-                        "Process: {0} (Pid: {1})".format(v["Process"], k)
+                        "Process: {} (Pid: {})".format(v["Process"], k)
                         for (  # pylint: disable=str-format-in-logging
                             k,
                             v,
@@ -826,7 +828,7 @@ class Process(multiprocessing.Process, NewStyleClassMixIn):
     def __init__(self, *args, **kwargs):
         log_queue = kwargs.pop("log_queue", None)
         log_queue_level = kwargs.pop("log_queue_level", None)
-        super(Process, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         if salt.utils.platform.is_windows():
             # On Windows, subclasses should call super if they define
             # __setstate__ and/or __getstate__
@@ -885,6 +887,11 @@ class Process(multiprocessing.Process, NewStyleClassMixIn):
             "_finalize_methods": self._finalize_methods,
         }
 
+    def join(self, *args, **kwargs):  # pylint: disable=arguments-differ
+        super().join(*args, **kwargs)
+        self._after_fork_methods = None
+        self._finalize_methods = None
+
     def _setup_process_logging(self):
         salt.log.setup.setup_multiprocessing_logging(self.log_queue)
 
@@ -895,9 +902,9 @@ class Process(multiprocessing.Process, NewStyleClassMixIn):
                 method(*args, **kwargs)
             try:
                 return run_func()
-            except SystemExit:
+            except SystemExit:  # pylint: disable=try-except-raise
                 # These are handled by multiprocessing.Process._bootstrap()
-                six.reraise(*sys.exc_info())
+                raise
             except Exception as exc:  # pylint: disable=broad-except
                 log.error(
                     "An un-handled exception from the multiprocessing process "
@@ -908,7 +915,7 @@ class Process(multiprocessing.Process, NewStyleClassMixIn):
                 # Re-raise the exception. multiprocessing.Process will write it to
                 # sys.stderr and set the proper exitcode and we have already logged
                 # it above.
-                six.reraise(*sys.exc_info())
+                raise
             finally:
                 for method, args, kwargs in self._finalize_methods:
                     method(*args, **kwargs)
@@ -929,12 +936,12 @@ class MultiprocessingProcess(Process):
             "after {{date}}.".format(name=__name__),
             stacklevel=3,
         )
-        super(MultiprocessingProcess, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
 class SignalHandlingProcess(Process):
     def __init__(self, *args, **kwargs):
-        super(SignalHandlingProcess, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._signal_handled = multiprocessing.Event()
         self._after_fork_methods.append(
             (SignalHandlingProcess._setup_signals, [self], {})
@@ -951,7 +958,7 @@ class SignalHandlingProcess(Process):
         self._signal_handled.set()
         signal.signal(signal.SIGTERM, signal.SIG_IGN)
         signal.signal(signal.SIGINT, signal.SIG_IGN)
-        msg = "{0} received a ".format(self.__class__.__name__)
+        msg = "{} received a ".format(self.__class__.__name__)
         if signum == signal.SIGINT:
             msg += "SIGINT"
         elif signum == signal.SIGTERM:
@@ -984,7 +991,7 @@ class SignalHandlingProcess(Process):
 
     def start(self):
         with default_signals(signal.SIGINT, signal.SIGTERM):
-            super(SignalHandlingProcess, self).start()
+            super().start()
 
 
 class SignalHandlingMultiprocessingProcess(SignalHandlingProcess):
@@ -1000,7 +1007,7 @@ class SignalHandlingMultiprocessingProcess(SignalHandlingProcess):
             "will go away after {{date}}.".format(name=__name__),
             stacklevel=3,
         )
-        super(SignalHandlingMultiprocessingProcess, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
 @contextlib.contextmanager
@@ -1028,7 +1035,7 @@ def default_signals(*signals):
     del old_signals
 
 
-class SubprocessList(object):
+class SubprocessList:
     def __init__(self, processes=None, lock=None):
         if processes is None:
             self.processes = []
@@ -1038,11 +1045,13 @@ class SubprocessList(object):
             self.lock = multiprocessing.Lock()
         else:
             self.lock = lock
+        self.count = 0
 
     def add(self, proc):
         with self.lock:
             self.processes.append(proc)
             log.debug("Subprocess %s added", proc.name)
+            self.count += 1
 
     def cleanup(self):
         with self.lock:
@@ -1051,4 +1060,5 @@ class SubprocessList(object):
                     continue
                 proc.join()
                 self.processes.remove(proc)
+                self.count -= 1
                 log.debug("Subprocess %s cleaned up", proc.name)
