@@ -1,28 +1,30 @@
-# -*- coding: utf-8 -*-
 """
 Basic functions for accessing the SDB interface
 
 For configuration options, see the docs for specific sdb
 modules.
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 # Import python libs
 import random
 
 # Import salt libs
 import salt.loader
+from salt.exceptions import SaltInvocationError
 from salt.ext.six import string_types
 from salt.ext.six.moves import range
 
 
-def sdb_get(uri, opts, utils=None):
+def sdb_get(uri, opts, utils=None, strict=False):
     """
     Get a value from a db, using a uri in the form of ``sdb://<profile>/<key>``. If
-    the uri provided does not start with ``sdb://``, then it will be returned as-is.
+    the uri provided is not valid, then it will be returned as-is, unless ``strict=True`` was passed.
     """
     if not isinstance(uri, string_types) or not uri.startswith("sdb://"):
-        return uri
+        if strict:
+            raise SaltInvocationError('SDB uri must start with "sdb://"')
+        else:
+            return uri
 
     if utils is None:
         utils = salt.loader.utils(opts)
@@ -31,15 +33,27 @@ def sdb_get(uri, opts, utils=None):
     indx = uri.find("/", sdlen)
 
     if (indx == -1) or not uri[(indx + 1) :]:
-        return uri
+        if strict:
+            raise SaltInvocationError(
+                "SDB uri must have a profile name as a first part of the uri before the /"
+            )
+        else:
+            return uri
 
     profile = opts.get(uri[sdlen:indx], {})
     if not profile:
         profile = opts.get("pillar", {}).get(uri[sdlen:indx], {})
     if "driver" not in profile:
-        return uri
+        if strict:
+            raise SaltInvocationError(
+                'SDB profile "{}" wasnt found in the minion configuration'.format(
+                    uri[sdlen:indx]
+                )
+            )
+        else:
+            return uri
 
-    fun = "{0}.get".format(profile["driver"])
+    fun = "{}.get".format(profile["driver"])
     query = uri[indx + 1 :]
 
     loaded_db = salt.loader.sdb(opts, fun, utils=utils)
@@ -70,7 +84,7 @@ def sdb_set(uri, value, opts, utils=None):
     if "driver" not in profile:
         return False
 
-    fun = "{0}.set".format(profile["driver"])
+    fun = "{}.set".format(profile["driver"])
     query = uri[indx + 1 :]
 
     loaded_db = salt.loader.sdb(opts, fun, utils=utils)
@@ -101,7 +115,7 @@ def sdb_delete(uri, opts, utils=None):
     if "driver" not in profile:
         return False
 
-    fun = "{0}.delete".format(profile["driver"])
+    fun = "{}.delete".format(profile["driver"])
     query = uri[indx + 1 :]
 
     loaded_db = salt.loader.sdb(opts, fun, utils=utils)
