@@ -1116,9 +1116,7 @@ class WindowsUpdateAgent:
 
         try:
             log.debug(cmd)
-            p = subprocess.Popen(
-                cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE
-            )
+            p = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
             return p.communicate()
 
         except OSError as exc:
